@@ -33,6 +33,8 @@
 // HEVC
 #define CODEC_MAX_NUM_REF_FRAME_HEVC        15
 #define CODEC_NUM_REF_FRAME_HEVC_WP         3       // number of reference frames used for weighted prediction
+#define CODEC_HEVC_MAX_QP                   51
+#define CODEC_HEVC_MIN_QP_LP                10
 #define HEVC_NUM_MAX_TILE_ROW               22
 #define HEVC_NUM_MAX_TILE_COLUMN            20
 #define CODECHAL_HEVC_MAX_NUM_SLICES_LVL_6  600
@@ -43,6 +45,8 @@
 #define CODECHAL_HEVC_FRAME_HEADER_SIZE     8192
 #define CODECHAL_HEVC_MAX_LCU_SIZE_G10      64
 #define CODECHAL_ENCODE_RECYCLED_BUFFER_NUM 6
+#define CODECHAL_ENCODE_HEVC_MIN_STREAM_BUFFER_ALIGNMENT     4096
+#define CODECHAL_ENCODE_HEVC_MI_COPY_MEM_MEM_CMD_ALIGNMENT 4
 
 #define CODECHAL_HEVC_BRC_MAX_QUALITY_LAYER   16
 #define CODECHAL_HEVC_BRC_MAX_TEMPORAL_LAYER  3
@@ -57,6 +61,7 @@
 #define HEVC_BRC_PAK_STATISTCS_SIZE              32
 
 #define CODECHAL_VDENC_HEVC_BRC_HUC_STATUS_REENCODE_MASK     (1<<31)
+#define CODECHAL_VDENC_HEVC_BRC_HISTORY_BUF_SIZE             964
 
 #define CODECHAL_HEVC_I_SLICE          2
 #define CODECHAL_HEVC_P_SLICE          1
@@ -74,6 +79,11 @@
 #define ENCODE_VDENC_HEVC_PADDING_DW_SIZE       8
 #define CODECHAL_ENCODE_HEVC_MAX_NUM_DIRTYRECT  16
 
+#define ENCODE_HEVC_MAX_16K_PIC_WIDTH 16384
+#define ENCODE_HEVC_MAX_16K_PIC_HEIGHT 16384
+#define CODECHAL_ENCODE_HEVC_NUM_MAX_VDENC_L0_REF_G10 3  // multiref, hevc vdenc
+#define CODECHAL_ENCODE_HEVC_NUM_MAX_VDENC_L1_REF_G10 3  // multiref, hevc vdenc
+
 // HEVC DP
 #define ENCODE_DP_HEVC_NUM_MAX_VME_L0_REF_G9  3
 #define ENCODE_DP_HEVC_NUM_MAX_VME_L1_REF_G9  1
@@ -479,7 +489,9 @@ typedef struct _CODEC_HEVC_ENCODE_SEQUENCE_PARAMS
             uint32_t    RGBEncodingEnable                   : 1;
             uint32_t    PrimaryChannelForRGBEncoding        : 2;
             uint32_t    SecondaryChannelForRGBEncoding      : 2;
-            uint32_t                                        : 15;  // [0]
+            uint32_t    RGBInputStudioRange                 : 1;
+            uint32_t    ConvertedYUVStudioRange             : 1;
+            uint32_t                                        : 13;  // [0]
         };
         uint32_t    EncodeTools;
     };
@@ -937,6 +949,23 @@ typedef struct _CODEC_HEVC_ENCODE_PICTURE_PARAMS
     } DownScaleRatio;
 
     uint8_t QpModulationStrength;
+
+    /*! \brief StatusReportEnable
+    *
+    *  Request features to be enabled at status report.
+    *  FrameStats: FRAME_STATS_INFO enabled in ENCODE_QUERY_STATUS_PARAMS.
+    *  BlockStats: BLOCK_STATS_INFO enabled in ENCODE_QUERY_STATUS_PARAMS.
+    */
+    union
+    {
+        struct
+        {
+            uint16_t FrameStats : 1;
+            uint16_t BlockStats : 1;
+            uint16_t reserved : 14;
+        } fields;
+        uint16_t value;
+    } StatusReportEnable;
 } CODEC_HEVC_ENCODE_PICTURE_PARAMS, *PCODEC_HEVC_ENCODE_PICTURE_PARAMS;
 
 /*! \brief Slice-level parameters of a compressed picture for HEVC encoding.
