@@ -515,6 +515,16 @@ typedef enum _VPHAL_COLORPACK
 } VPHAL_COLORPACK,
     *PVPHAL_COLORPACK;
 
+//!
+//! \brief VEBOX 3DLut interpolation mode
+//!
+typedef enum _VPHAL_3DLUT_INTERPOLATION
+{
+    VPHAL_3DLUT_INTERPOLATION_DEFAULT      = 0,     //!< Default 3DLUT interpolation method.
+    VPHAL_3DLUT_INTERPOLATION_TRILINEAR    = 1,     //!< 3DLUT trilinear interpolation method.
+    VPHAL_3DLUT_INTERPOLATION_TETRAHEDRAL  = 2      //!< 3DLUT tetrahedral interpolation method.
+} VPHAL_3DLUT_INTERPOLATION;
+
 //!
 //! \brief   Output Pipe Mode enum
 //! \details The output pipe that writes the RenderTarget surface
@@ -841,9 +851,10 @@ typedef struct _VPHAL_STE_PARAMS
 //!
 typedef struct _VPHAL_STD_PARAMS
 {
-    uint32_t           paraSizeInBytes = 0;
-    void              *param           = nullptr;
-    unsigned long long sysMem          = 0;
+    uint32_t           paraSizeInBytes  = 0;
+    void              *param            = nullptr;
+    unsigned long long sysMem           = 0;
+    bool               bOutputSkinScore = false;
 } VPHAL_STD_PARAMS, *PVPHAL_STD_PARAMS;
 
 //!
@@ -889,6 +900,8 @@ typedef struct _VPHAL_3DLUT_PARAMS
     uint32_t       ChannelMapping     = 0;        // Channel Mapping for the 3DLUT input to 3DLUT output.
     uint16_t       BitDepthPerChannel = 0;        // Bit Depth Per Channel(4 channels for 3DLUT).
     uint16_t       ByteCountPerEntry  = 0;        // Byte Count Per Entry including reserved bytes.
+
+    VPHAL_3DLUT_INTERPOLATION InterpolationMethod = VPHAL_3DLUT_INTERPOLATION_DEFAULT;  // VEBox 3DLut interpolation mode
 } VPHAL_3DLUT_PARAMS, *PVPHAL_3DLUT_PARAMS;
 
 //!
@@ -1034,6 +1047,8 @@ struct VPHAL_RENDER_PARAMS
     bool bNonFirstFrame     = false;  // first frame or not: first frame false, otherwise true considering zeromemory parameters.
     bool bOptimizeCpuTiming = false;  //!< Optimize Cpu Timing
 
+    bool bForceToRender = false;  // Force to render to perform scaling.
+
     VPHAL_RENDER_PARAMS() : uSrcCount(0),
                             pSrc(),
                             uDstCount(0),
