@@ -1167,6 +1167,7 @@ MOS_STATUS CodechalDecodeVp8::SetFrameStates()
         {
             CodechalResLock ResourceLock(m_osInterface, &m_resDataBuffer);
             auto bitstreamBuffer = (uint8_t*)ResourceLock.Lock(CodechalResLock::readOnly);
+            CODECHAL_DECODE_CHK_NULL_RETURN(bitstreamBuffer);
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(ParseFrameHead(bitstreamBuffer + m_dataOffset, m_dataSize));
         }
@@ -1176,6 +1177,7 @@ MOS_STATUS CodechalDecodeVp8::SetFrameStates()
 
             CodechalResLock ResourceLock(m_osInterface, &m_resTmpBitstreamBuffer);
             auto bitstreamBuffer = (uint8_t*)ResourceLock.Lock(CodechalResLock::readOnly);
+            CODECHAL_DECODE_CHK_NULL_RETURN(bitstreamBuffer);
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(ParseFrameHead(bitstreamBuffer, m_dataSize));
         }
@@ -1563,6 +1565,7 @@ CodechalDecodeVp8::CodechalDecodeVp8(
     MOS_ZeroMemory(&m_resSyncObjectWaContextInUse, sizeof(m_resSyncObjectWaContextInUse));
     MOS_ZeroMemory(&m_resSyncObjectVideoContextInUse, sizeof(m_resSyncObjectVideoContextInUse));
     MOS_ZeroMemory(&m_vp8FrameHead, sizeof(m_vp8FrameHead));
+    m_hwInterface = hwInterface;
 }
 
 #if USE_CODECHAL_DEBUG_TOOL
