@@ -311,13 +311,14 @@ bool VphalSfcState::IsSFCUncompressedWriteNeeded(
     }
 
     byteInpixel = pRenderTarget->OsResource.pGmmResInfo->GetBitsPerPixel() >> 3;
-#endif // !EMUL
 
     if (byteInpixel == 0)
     {
         VPHAL_RENDER_NORMALMESSAGE("surface format is not a valid format for sfc");
         return false;
     }
+#endif  // !EMUL
+
     uint32_t writeAlignInWidth  = 32 / byteInpixel;
     uint32_t writeAlignInHeight = 8;
 
@@ -326,6 +327,13 @@ bool VphalSfcState::IsSFCUncompressedWriteNeeded(
         (pRenderTarget->rcSrc.left % writeAlignInWidth) ||
         ((pRenderTarget->rcSrc.right - pRenderTarget->rcSrc.left) % writeAlignInWidth))
     {
+        // full Frame Write don't need decompression as it will not hit the compressed write limitation
+        if ((pRenderTarget->rcSrc.bottom - pRenderTarget->rcSrc.top) == pRenderTarget->dwHeight &&
+            (pRenderTarget->rcSrc.right - pRenderTarget->rcSrc.left) == pRenderTarget->dwWidth)
+        {
+            return false;
+        }
+
         VPHAL_RENDER_NORMALMESSAGE(
             "SFC Render Target Uncompressed write needed, \
             pRenderTarget->rcSrc.top % d, \
@@ -577,12 +585,6 @@ VPHAL_OUTPUT_PIPE_MODE VphalSfcState::GetOutputPipe(
             IsSFCUncompressedWriteNeeded(pRenderTarget))
         {
 
-            m_osInterface->pfnSyncOnResource(
-                m_osInterface,
-                &pRenderTarget->OsResource,
-                MOS_GPU_CONTEXT_VEBOX,
-                true);
-
             eStatus = m_osInterface->pfnGetResourceInfo(m_osInterface, &pRenderTarget->OsResource, &details);
 
             if (eStatus != MOS_STATUS_SUCCESS)
@@ -1796,6 +1798,12 @@ MOS_STATUS VphalSfcState::SendSfcCmd(
         pCmdBuffer,
         m_renderData.SfcStateParams,
         &OutSurfaceParam));
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if ((&OutSurfaceParam)->pOsResource)
+    {
+        (m_renderData.pSfcPipeOutSurface)->oldCacheSetting = ((&OutSurfaceParam)->pOsResource->memObjCtrlState.DwordValue >> 1) & 0x0000003f;
+    }
+#endif
 
     // Send SFC_AVS_STATE command
     VPHAL_RENDER_CHK_STATUS(pSfcInterface->AddSfcAvsState(
