@@ -28,7 +28,7 @@
 #define __VPHAL_RENDER_VEBOX_BASE_H__
 
 #include "mos_os.h"
-#include "renderhal.h"
+#include "renderhal_legacy.h"
 #include "mhw_vebox.h"
 #include "vphal.h"
 #include "vphal_render_renderstate.h"
@@ -64,6 +64,7 @@
 #define NOISE_LOWTEMPORALPIXELDIFF_THRESHOLD_DEFAULT    6
 #define NOISE_TEMPORALPIXELDIFF_THRESHOLD_DEFAULT       12
 #define NOISE_SUMABSTEMPORALDIFF_THRESHOLD_DEFAULT      128
+#define RESOLUTION_THRESHOLD                            2073600                  //!< The size of 1080P
 
 //!
 //! \brief Spatial Denoise Definitions
@@ -1247,7 +1248,12 @@ public:
 
     virtual bool IsIECPEnabled()
     {
-        return GetLastExecRenderData()->bIECP;
+        PVPHAL_VEBOX_RENDER_DATA pRenderData = GetLastExecRenderData();
+        VPHAL_RENDER_CHK_NULL_NO_STATUS(pRenderData);
+
+        return pRenderData->bIECP;
+    finish:
+        return false;
     }
     virtual bool IsQueryVarianceEnabled() {return false;}
 
@@ -1280,6 +1286,11 @@ protected:
     virtual MOS_STATUS VeboxSetDNDIParams(
         PVPHAL_SURFACE              pSrcSurface);
 
+    virtual bool IsDnDisabled()
+    {
+        return false;
+    }
+
     //!
     //! \brief    Vebox Set FMD parameter
     //! \details  Set up the FMD parameters for DNDI State
