@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2018, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -30,6 +30,7 @@
 #include "mhw_vdbox_vdenc_generic.h"
 #include "mhw_vdbox_vdenc_hwcmd_g11_X.h"
 #include "mhw_vdbox_g11_X.h"
+#include "mos_interface.h"
 
 #define MHW_VDBOX_PICWIDTH_1920                                               1920
 #define MHW_VDBOX_PICWIDTH_3840                                               3840
@@ -242,8 +243,8 @@ public:
         MHW_MI_CHK_NULL(skuTable);
 
         MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-        /* It will be better to remove this code when this file is upstreamed */
-        if (MEDIA_IS_SKU(skuTable, FtrSimulationMode))
+
+        if (this->m_osInterface->bSimIsActive)
         {
             // Disable RowStore Cache on simulation by default
             userFeatureData.u32Data = 1;
@@ -258,7 +259,8 @@ public:
         MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_ROWSTORE_CACHE_DISABLE_ID,
-            &userFeatureData);
+            &userFeatureData,
+            this->m_osInterface->pOsContext);
 #endif // _DEBUG || _RELEASE_INTERNAL
         this->m_rowstoreCachingSupported = userFeatureData.i32Data ? false : true;
 
@@ -269,7 +271,8 @@ public:
             MOS_UserFeature_ReadValue_ID(
                 nullptr,
                 __MEDIA_USER_FEATURE_VALUE_VDENCROWSTORECACHE_DISABLE_ID,
-                &userFeatureData);
+                &userFeatureData,
+                this->m_osInterface->pOsContext);
 #endif // _DEBUG || _RELEASE_INTERNAL
             this->m_vdencRowStoreCache.bSupported = userFeatureData.i32Data ? false : true;
         }
@@ -440,12 +443,47 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS GetVdencPrimitiveCommandsDataSize(
+        uint32_t                        mode,
+        uint32_t                        *commandsSize,
+        uint32_t                        *patchListSize)
+    {
+        MHW_FUNCTION_ENTER;
+
+        uint32_t            maxSize = 0;
+        uint32_t            patchListMaxSize = 0;
+        uint32_t            standard = CodecHal_GetStandardFromMode(mode);
+
+        if (standard == CODECHAL_AVC)
+        {
+            maxSize =
+                TVdencCmds::VDENC_WEIGHTSOFFSETS_STATE_CMD::byteSize +
+                TVdencCmds::VDENC_WALKER_STATE_CMD::byteSize +
+                TVdencCmds::VD_PIPELINE_FLUSH_CMD::byteSize;
+
+            patchListMaxSize = VDENC_PIPE_BUF_ADDR_STATE_CMD_NUMBER_OF_ADDRESSES;
+        }
+        else
+        {
+            MHW_ASSERTMESSAGE("Unsupported encode mode.");
+            *commandsSize  = 0;
+            *patchListSize = 0;
+            return MOS_STATUS_UNKNOWN;
+        }
+
+        *commandsSize  = maxSize;
+        *patchListSize = patchListMaxSize;
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     MOS_STATUS AddVdencPipeModeSelectCmd(
         PMOS_COMMAND_BUFFER                  cmdBuffer,
         PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS   params)
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
  
@@ -470,7 +508,7 @@ public:
         // can add a DDI flag to control if needed
         cmd.DW1.OutputRangeControlAfterColorSpaceConversion = 1;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -529,7 +567,7 @@ public:
             cmd.RowStoreScratchBuffer.BufferPictureFields.DW0.CacheSelect = TVdencCmds::VDENC_Surface_Control_Bits_CMD::CACHE_SELECT_UNNAMED1;
             cmd.RowStoreScratchBuffer.LowerAddress.DW0.Value              = this->m_vdencRowStoreCache.dwAddress << 6;
         }
-        else if (params->presVdencIntraRowStoreScratchBuffer != nullptr)
+        else if (!Mos_ResourceIsNull(params->presVdencIntraRowStoreScratchBuffer))
         {
             cmd.RowStoreScratchBuffer.BufferPictureFields.DW0.MemoryObjectControlState =
                 this->m_cacheabilitySettings[MOS_CODEC_RESOURCE_USAGE_VDENC_ROW_STORE_BUFFER_CODEC].Value;
@@ -963,7 +1001,7 @@ public:
         // Hence it's a dummy CL for us. Histogram stats start from 4th CL onwards. 
         cmd.DW61.WeightsHistogramStreamoutOffset = 3 * MHW_CACHELINE_SIZE;
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -974,6 +1012,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->psSurface);
@@ -1004,7 +1043,7 @@ public:
         cmd.Dwords25.DW2.YOffsetForUCb            = cmd.Dwords25.DW3.YOffsetForVCr =
             MOS_ALIGN_CEIL(params->psSurface->UPlaneOffset.iYOffset, MHW_VDBOX_MFX_RAW_UV_PLANE_ALIGNMENT_GEN9);
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1015,6 +1054,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->psSurface);
@@ -1070,6 +1110,13 @@ public:
         if (cmd.Dwords25.DW1.SurfaceFormat == vdencSurfaceFormatY416Variant ||
             cmd.Dwords25.DW1.SurfaceFormat == vdencSurfaceFormatAyuvVariant)
         {
+            /* Y410/Y416 Reconstructed format handling */
+            if (cmd.Dwords25.DW1.SurfaceFormat == vdencSurfaceFormatY416Variant)
+                cmd.Dwords25.DW1.SurfacePitch = params->psSurface->dwPitch / 2 - 1;
+            /* AYUV Reconstructed format handling */
+            if (cmd.Dwords25.DW1.SurfaceFormat == vdencSurfaceFormatAyuvVariant)
+                cmd.Dwords25.DW1.SurfacePitch = params->psSurface->dwPitch / 4 - 1;
+
             cmd.Dwords25.DW2.YOffsetForUCb = params->dwReconSurfHeight;
             cmd.Dwords25.DW3.YOffsetForVCr = params->dwReconSurfHeight << 1;
         }
@@ -1079,7 +1126,7 @@ public:
             cmd.Dwords25.DW2.YOffsetForUCb = cmd.Dwords25.DW3.YOffsetForVCr = params->dwReconSurfHeight;
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1091,6 +1138,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->psSurface);
@@ -1152,7 +1200,7 @@ public:
             cmd.Dwords69.DW2.YOffsetForUCb = cmd.Dwords69.DW3.YOffsetForVCr = params->psSurface->UPlaneOffset.iYOffset;
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1197,7 +1245,7 @@ public:
         if (avcPicParams->CodingType != I_TYPE)
         {
             cmd.DW2.BidirectionalWeight              = 0x20;
-            cmd.DW4.SubPelMode                       = 3;
+            cmd.DW4.SubPelMode                       = (avcPicParams->bEnableSubPelMode) ? avcPicParams->SubPelMode : 3;
             cmd.DW4.BmeDisableForFbrMessage          = 1;
             cmd.DW4.InterSadMeasureAdjustment        = 2;
             cmd.DW5.CrePrefetchEnable                = 1;
@@ -1251,7 +1299,7 @@ public:
             cmd.DW5.MbSliceThresholdValue            = params->dwMbSlcThresholdValue;
         }
 
-        cmd.DW6.SliceMacroblockHeightMinusOne        = params->wSlcHeightInMb - 1;
+        cmd.DW6.SliceMacroblockHeightMinusOne        = params->wPicHeightInMb - 1;
 
         cmd.DW8.LumaIntraPartitionMask               = avcPicParams->transform_8x8_mode_flag ? 0 : TVdencCmds::VDENC_IMG_STATE_CMD::LUMA_INTRA_PARTITION_MASK_UNNAMED2;
 
@@ -1310,11 +1358,24 @@ public:
         // Rolling-I settings
         if ((avcPicParams->CodingType != I_TYPE) && (avcPicParams->EnableRollingIntraRefresh != ROLLING_I_DISABLED))
         {
-            cmd.DW21.IntraRefreshEnableRollingIEnable = avcPicParams->EnableRollingIntraRefresh != ROLLING_I_DISABLED ? 1 : 0;        // 0->Row based ; 1->Column based
-            cmd.DW21.IntraRefreshMode                 = avcPicParams->EnableRollingIntraRefresh == ROLLING_I_ROW ? 0 : 1;
+            cmd.DW21.IntraRefreshEnableRollingIEnable = avcPicParams->EnableRollingIntraRefresh != ROLLING_I_DISABLED ? 1 : 0;
+            cmd.DW21.IntraRefreshMode                 = avcPicParams->EnableRollingIntraRefresh == ROLLING_I_ROW ? 0 : 1;        // 0->Row based ; 1->Column based
             cmd.DW21.IntraRefreshMBPos                = avcPicParams->IntraRefreshMBNum;
             cmd.DW21.IntraRefreshMBSizeMinusOne       = avcPicParams->IntraRefreshUnitinMB;
             cmd.DW21.QpAdjustmentForRollingI          = avcPicParams->IntraRefreshQPDelta;
+
+            auto waTable = this->m_osInterface->pfnGetWaTable(this->m_osInterface);
+            MHW_MI_CHK_NULL(waTable);
+
+            // WA to prevent error propagation from top-right direction.
+            // Disable prediction modes 3, 7 for 4x4
+            // and modes 0, 2, 3, 4, 5, 7 for 8x8 (due to filtering)
+            if (avcPicParams->EnableRollingIntraRefresh == ROLLING_I_COLUMN &&
+                MEDIA_IS_WA(waTable, Wa_18011246551))
+            {
+                cmd.DW17.AvcIntra4X4ModeMask = 0x88;
+                cmd.DW17.AvcIntra8X8ModeMask = 0xBD;
+            }
         }
 
         // Setting MinMaxQP values if they are presented
@@ -1339,9 +1400,9 @@ public:
 
             for (uint8_t i = 0; i < avcPicParams->NumROI; i++)
             {
-                int8_t dQpRoi = avcPicParams->ROI[i].PriorityLevelOrDQp;
+                int8_t dQpRoi = avcPicParams->ROIDistinctDeltaQp[i];
 
-                // clip delta qp roi to VDEnc supported range 
+                // clip delta qp roi to VDEnc supported range
                 priorityLevelOrDQp[i] = (char)CodecHal_Clip3(
                     ENCODE_VDENC_AVC_MIN_ROI_DELTA_QP_G9, ENCODE_VDENC_AVC_MAX_ROI_DELTA_QP_G9, dQpRoi);
             }
@@ -1354,11 +1415,32 @@ public:
             cmd.DW30.RoiQpAdjustmentForZone3 = priorityLevelOrDQp[2];
         }
 
-        if (params->bVdencBRCEnabled && avcPicParams->NumDirtyROI && params->bVdencStreamInEnabled)
+        if (avcSeqParams->RateControlMethod != RATECONTROL_CQP)
+        {
+            cmd.DW30.QpAdjustmentForShapeBestIntra4X4Winner = 0;
+            cmd.DW30.QpAdjustmentForShapeBestIntra8X8Winner = 0;
+            cmd.DW30.QpAdjustmentForShapeBestIntra16X16Winner = 0;
+
+            cmd.DW31.BestdistortionQpAdjustmentForZone0 = 0;
+            cmd.DW31.BestdistortionQpAdjustmentForZone1 = 1;
+            cmd.DW31.BestdistortionQpAdjustmentForZone2 = 2;
+            cmd.DW31.BestdistortionQpAdjustmentForZone3 = 3;
+        }
+
+        if (avcPicParams->EnableRollingIntraRefresh == ROLLING_I_DISABLED && params->bVdencStreamInEnabled &&
+            (avcPicParams->NumDirtyROI && params->bVdencBRCEnabled || avcPicParams->NumROI && avcPicParams->bNativeROI ||
+                (avcPicParams->TargetFrameSize > 0 && !avcSeqParams->LookaheadDepth)))  // TCBRC (for AdaptiveRegionBoost)
         {
             cmd.DW34.RoiEnable = true;
         }
 
+        // non-native ROI in ForceQP mode (VDEnc StreamIn filled by HuC in BRC mode and by UMD driver in CQP) or MBQP
+        if (avcPicParams->EnableRollingIntraRefresh == ROLLING_I_DISABLED && params->bVdencStreamInEnabled &&
+            avcPicParams->NumROI && !avcPicParams->bNativeROI)
+        {
+            cmd.DW34.MbLevelQpEnable = true;
+        }
+
         if (params->bVdencStreamInEnabled)
         {
             cmd.DW34.FwdPredictor0MvEnable = 1;
@@ -1370,7 +1452,7 @@ public:
             return MOS_STATUS_NULL_POINTER;
         }
 
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(this->m_osInterface, cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1381,6 +1463,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
 
@@ -1556,7 +1639,7 @@ public:
             }
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1567,6 +1650,7 @@ public:
     {
         MHW_FUNCTION_ENTER;
 
+        MHW_MI_CHK_NULL(this->m_osInterface);
         MHW_MI_CHK_NULL(cmdBuffer);
         MHW_MI_CHK_NULL(params);
         MHW_MI_CHK_NULL(params->pAvcPicParams);
@@ -1595,7 +1679,7 @@ public:
             cmd.DW2.OffsetForwardReference2  = 0;
         }
 
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(this->m_osInterface->pfnAddCommand(cmdBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1652,7 +1736,7 @@ public:
             return MOS_STATUS_NULL_POINTER;
         }
 
-        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
+        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(this->m_osInterface, cmdBuffer, batchBuffer, &cmd, sizeof(cmd)));
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1672,6 +1756,18 @@ public:
     {
         return MOS_STATUS_SUCCESS;
     }
+
+    PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS CreateMhwVdboxPipeModeSelectParams()
+    {
+        PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS pipeModeSelectParams = MOS_New(MHW_VDBOX_PIPE_MODE_SELECT_PARAMS_G11);
+
+        return pipeModeSelectParams;
+    }
+
+    void ReleaseMhwVdboxPipeModeSelectParams(PMHW_VDBOX_PIPE_MODE_SELECT_PARAMS pipeModeSelectParams) 
+    {
+        MOS_Delete(pipeModeSelectParams);
+    }
 };
 
 //!  MHW Vdbox Vdenc interface for Gen11 ICL
