@@ -414,7 +414,21 @@ VAStatus DdiEncodeAV1::ParseSeqParams(void *ptr)
     av1SeqParams->GopPicSize    = seqParams->intra_period;
     av1SeqParams->GopRefDist    = seqParams->ip_period;
  
-    av1SeqParams->RateControlMethod = VARC2HalRC(m_encodeCtx->uiRCMethod);
+    switch ((uint32_t)m_encodeCtx->uiRCMethod)
+    {
+    case VA_RC_TCBRC:
+    case VA_RC_VBR:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_VBR;
+        break;
+    case VA_RC_CQP:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CQP;
+        break;
+    case VA_RC_ICQ:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CQL;
+        break;
+    default:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CBR;
+    }
 
     /* the bits_per_second is only used when the target bit_rate is not initialized */
     if (av1SeqParams->TargetBitRate[0] == 0)
@@ -929,7 +943,10 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
 
     if (VA_RC_CBR == m_encodeCtx->uiRCMethod)
     {
-        seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        if(vaEncMiscParamRC->target_percentage != 0)
+            seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        else
+            seqParams->TargetBitRate[temporalId] = bitRate; // Default 100 percent
         seqParams->MaxBitRate                = seqParams->TargetBitRate[temporalId];
         seqParams->MinBitRate                = seqParams->TargetBitRate[temporalId];
         seqParams->RateControlMethod         = RATECONTROL_CBR;
@@ -944,7 +961,10 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
     }
     else if (VA_RC_VBR == m_encodeCtx->uiRCMethod)
     {
-        seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100; //VBR target bits;
+        if(vaEncMiscParamRC->target_percentage != 0)
+            seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        else
+            seqParams->TargetBitRate[temporalId] = bitRate;
         seqParams->MaxBitRate = bitRate;
         seqParams->MinBitRate = 0;
         seqParams->RateControlMethod = RATECONTROL_VBR;
@@ -960,6 +980,19 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
             savedMaxBitRate[temporalId] = bitRate;
         }
     }
+    else if (VA_RC_ICQ == m_encodeCtx->uiRCMethod)
+    {   
+        seqParams->RateControlMethod = RATECONTROL_CQL;
+        seqParams->ICQQualityFactor = vaEncMiscParamRC->quality_factor;
+        if (savedQualityFactor != seqParams->ICQQualityFactor)
+        {
+            if (savedQualityFactor != 0)
+            {
+                seqParams->SeqFlags.fields.ResetBRC |= 0x01;
+            }
+            savedQualityFactor = seqParams->ICQQualityFactor;
+        }
+    }
 
     /* the reset flag in RC will be considered. */
     seqParams->SeqFlags.fields.ResetBRC |= vaEncMiscParamRC->rc_flags.bits.reset;
