@@ -33,7 +33,9 @@
 #include "hwinfo_linux.h"
 #include "codechal_memdecomp.h"
 #include "media_interfaces_codechal.h"
+#include "media_interfaces_codechal_next.h"
 #include "media_interfaces_mmd.h"
+#include "cm_device_rt.h"
 
 typedef MediaDdiFactoryNoArg<DdiEncodeBase> DdiEncodeFactory;
 
@@ -276,23 +278,26 @@ VAStatus DdiEncode_CreateContext(
     mosCtx.m_cmdBufMgr     = mediaDrvCtx->m_cmdBufMgr;
     mosCtx.fd              = mediaDrvCtx->fd;
     mosCtx.iDeviceId       = mediaDrvCtx->iDeviceId;
-    mosCtx.SkuTable        = mediaDrvCtx->SkuTable;
-    mosCtx.WaTable         = mediaDrvCtx->WaTable;
-    mosCtx.gtSystemInfo    = *mediaDrvCtx->pGtSystemInfo;
-    mosCtx.platform        = mediaDrvCtx->platform;
+    mosCtx.m_skuTable      = mediaDrvCtx->SkuTable;
+    mosCtx.m_waTable       = mediaDrvCtx->WaTable;
+    mosCtx.m_gtSystemInfo  = *mediaDrvCtx->pGtSystemInfo;
+    mosCtx.m_platform      = mediaDrvCtx->platform;
 
     mosCtx.ppMediaMemDecompState = &mediaDrvCtx->pMediaMemDecompState;
     mosCtx.pfnMemoryDecompress   = mediaDrvCtx->pfnMemoryDecompress;
     mosCtx.pfnMediaMemoryCopy    = mediaDrvCtx->pfnMediaMemoryCopy;
     mosCtx.pfnMediaMemoryCopy2D  = mediaDrvCtx->pfnMediaMemoryCopy2D;
-    mosCtx.pPerfData             = (PERF_DATA *)MOS_AllocAndZeroMemory(sizeof(PERF_DATA));
-    mosCtx.gtSystemInfo          = *mediaDrvCtx->pGtSystemInfo;
+    mosCtx.ppMediaCopyState      = &mediaDrvCtx->pMediaCopyState;
+    mosCtx.m_gtSystemInfo          = *mediaDrvCtx->pGtSystemInfo;
     mosCtx.m_auxTableMgr         = mediaDrvCtx->m_auxTableMgr;
     mosCtx.pGmmClientContext     = mediaDrvCtx->pGmmClientContext;
 
     mosCtx.m_osDeviceContext     = mediaDrvCtx->m_osDeviceContext;
     mosCtx.m_apoMosEnabled       = mediaDrvCtx->m_apoMosEnabled;
 
+    mosCtx.m_userSettingPtr      = mediaDrvCtx->m_userSettingPtr;
+
+    mosCtx.pPerfData             = (PERF_DATA *)MOS_AllocAndZeroMemory(sizeof(PERF_DATA));
     if (nullptr == mosCtx.pPerfData)
     {
         vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
@@ -338,10 +343,19 @@ VAStatus DdiEncode_CreateContext(
         nullptr);
     if (pCodecHal == nullptr)
     {
-        // add anything necessary here to free the resource
-        vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
-        DdiEncodeCleanUp(encCtx);
-        return vaStatus;
+        pCodecHal = CodechalDeviceNext::CreateFactory(
+            nullptr,
+            &mosCtx,
+            &standardInfo,
+            nullptr);
+
+        if (nullptr == pCodecHal)
+        {
+            // add anything necessary here to free the resource
+            vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
+            DdiEncodeCleanUp(encCtx);
+            return vaStatus;
+        }
     }
 
     encCtx->pCodecHal = pCodecHal;
@@ -469,8 +483,11 @@ VAStatus DdiEncode_DestroyContext(VADriverContextP ctx, VAContextID context)
         }
     }
 
-    MOS_FreeMemory(codecHal->GetOsInterface()->pOsContext->pPerfData);
-    codecHal->GetOsInterface()->pOsContext->pPerfData = nullptr;
+    if (codecHal->GetOsInterface() && codecHal->GetOsInterface()->pOsContext)
+    {
+        MOS_FreeMemory(codecHal->GetOsInterface()->pOsContext->pPerfData);
+        codecHal->GetOsInterface()->pOsContext->pPerfData = nullptr;
+    }
 
     // destroy codechal
     codecHal->Destroy();
@@ -571,6 +588,12 @@ VAStatus DdiEncode_RenderPicture(
     VABufferID      *buffers,
     int32_t          num_buffers)
 {
+    VAStatus        vaStatus                  = VA_STATUS_SUCCESS;
+    int32_t         numOfBuffers              = num_buffers;
+    int32_t         priority                  = 0;
+    int32_t         priorityIndexInBuffers    = -1;
+    bool            updatePriority            = false;
+
     PERF_UTILITY_AUTO(__FUNCTION__, PERF_ENCODE, PERF_LEVEL_DDI);
 
     DDI_FUNCTION_ENTER();
@@ -582,7 +605,22 @@ VAStatus DdiEncode_RenderPicture(
     DDI_CHK_NULL(encCtx, "nullptr encCtx", VA_STATUS_ERROR_INVALID_CONTEXT);
     DDI_CHK_NULL(encCtx->m_encode, "nullptr encCtx->m_encode", VA_STATUS_ERROR_INVALID_CONTEXT);
 
-    VAStatus vaStatus = encCtx->m_encode->RenderPicture(ctx, context, buffers, num_buffers);
+    priorityIndexInBuffers = DdiMedia_GetGpuPriority(ctx, buffers, numOfBuffers, &updatePriority, &priority);
+    if (priorityIndexInBuffers != -1)
+    {
+        if(updatePriority)
+        {
+            vaStatus = DdiEncode_SetGpuPriority(encCtx, priority);
+            if(vaStatus != VA_STATUS_SUCCESS)
+                return vaStatus;
+        }
+        MovePriorityBufferIdToEnd(buffers, priorityIndexInBuffers, numOfBuffers);
+        numOfBuffers--;
+    }
+    if (numOfBuffers == 0)
+        return vaStatus;
+
+    vaStatus = encCtx->m_encode->RenderPicture(ctx, context, buffers, numOfBuffers);
     DDI_FUNCTION_EXIT(vaStatus);
     return vaStatus;
 }
@@ -684,6 +722,7 @@ VAStatus DdiEncode_MfeSubmit(
         }
 
         CodechalEncoderState *encoder = dynamic_cast<CodechalEncoderState *>(encodeContext->pCodecHal);
+        DDI_CHK_NULL(encoder, "nullptr encoder", VA_STATUS_ERROR_INVALID_CONTEXT);
 
         encodeMfeContext->mfeEncodeSharedState->encoders.push_back(encoder);
 
@@ -709,6 +748,8 @@ VAStatus DdiEncode_MfeSubmit(
         }
 
         CodechalEncoderState *encoder = dynamic_cast<CodechalEncoderState *>(encodeContext->pCodecHal);
+        DDI_CHK_NULL(encoder, "nullptr encoder", VA_STATUS_ERROR_INVALID_CONTEXT);
+
         status = encoder->Execute(&encodeContext->EncodeParams);
         if (MOS_STATUS_SUCCESS != status)
         {
@@ -720,3 +761,37 @@ VAStatus DdiEncode_MfeSubmit(
     return VA_STATUS_SUCCESS;
 }
 
+VAStatus DdiEncode_SetGpuPriority(
+    PDDI_ENCODE_CONTEXT encCtx,
+    int32_t             priority
+)
+{
+    DDI_CHK_NULL(encCtx, "nullptr encCtx", VA_STATUS_ERROR_INVALID_CONTEXT);
+
+    if(encCtx->pCodecHal != nullptr)
+    {
+        PMOS_INTERFACE osInterface = encCtx->pCodecHal->GetOsInterface();
+        DDI_CHK_NULL(osInterface, "nullptr osInterface.", VA_STATUS_ERROR_ALLOCATION_FAILED);
+
+        //Set Gpu priority for encoder
+        osInterface->pfnSetGpuPriority(osInterface, priority);
+
+        //Get the CMRT osInterface of encode
+        CodechalEncoderState *encoder = dynamic_cast<CodechalEncoderState *>(encCtx->pCodecHal);
+        DDI_CHK_NULL(encoder, "nullptr encoder", VA_STATUS_ERROR_INVALID_CONTEXT);
+
+        if(encoder->m_cmDev != nullptr)
+        {
+            //Set Gpu priority for CMRT OsInterface
+            CmDeviceRTBase *cm_device = dynamic_cast<CmDeviceRTBase *>(encoder->m_cmDev);
+            DDI_CHK_NULL(cm_device, "nullptr cm_device", VA_STATUS_ERROR_INVALID_PARAMETER);
+
+            PCM_HAL_STATE cm_hal_state = cm_device->GetHalState();
+            if(cm_hal_state->osInterface != nullptr)
+                cm_hal_state->osInterface->pfnSetGpuPriority(cm_hal_state->osInterface, priority);
+        }
+    }
+
+    return VA_STATUS_SUCCESS;
+}
+
