@@ -97,9 +97,9 @@ void write_bitdepth_colorspace_sampling(uint32_t codecProfile,
         (codecProfile == VP9_PROFILE_3))
     {
         /* sub_sampling_x/y */
-        /* Currently the sub_sampling_x = 0, sub_sampling_y = 1 */
+        /* Currently the sub_sampling_x = 0, sub_sampling_y = 0 */
+        vp9_wb_write_bit(wb, 0);
         vp9_wb_write_bit(wb, 0);
-        vp9_wb_write_bit(wb, 1);
         vp9_wb_write_bit(wb, 0); // unused
     }
 }
@@ -429,96 +429,15 @@ bool Vp9WriteUncompressHeader(struct _DDI_ENCODE_CONTEXT *ddiEncContext,
         vp9_wb_write_bit(wb, 0);
     }
 
+    headerBitoffset->bit_offset_segmentation = wb->bit_offset;
     vp9_wb_write_bit(wb, picParam->PicFlags.fields.segmentation_enabled);
     if (picParam->PicFlags.fields.segmentation_enabled)
     {
-        int i;
-
-#define VP9_MAX_PROB    255
-        vp9_wb_write_bit(wb, picParam->PicFlags.fields.segmentation_update_map);
-        headerBitoffset->bit_offset_segmentation = wb->bit_offset;
-        if (picParam->PicFlags.fields.segmentation_update_map)
-        {
-            /* write the seg_tree_probs */
-            /* segment_tree_probs/segment_pred_probs are not passed.
-             * So the hard-coded prob is writen
-             */
-            for (i = 0; i < 7; i++)
-            {
-                vp9_wb_write_bit(wb, 1);
-                vp9_wb_write_literal(wb, VP9_MAX_PROB, 8);
-            }
-
-            vp9_wb_write_bit(wb, picParam->PicFlags.fields.segmentation_temporal_update);
-            if (picParam->PicFlags.fields.segmentation_temporal_update)
-            {
-                for (i = 0; i < 3; i++)
-                {
-                    vp9_wb_write_bit(wb, 1);
-                    vp9_wb_write_literal(wb, VP9_MAX_PROB, 8);
-                }
-            }
-        }
-
-        /* write the segment_data info */
-        if (segParams == NULL)
-        {
-            vp9_wb_write_bit(wb, 0);
-        }
-        else
-        {
-            CODEC_VP9_ENCODE_SEG_PARAMS *seg_data;
-            int seg_delta;
-
-            /* update_data */
-            vp9_wb_write_bit(wb, 1);
-            /* abs_delta should be zero */
-            vp9_wb_write_bit(wb, 0);
-            for (i = 0; i < 8; i++)
-            {
-                seg_data = &segParams->SegData[i];
-
-                /* The segment qindex delta */
-                /* This check is skipped */
-                /* if (seg_data->SegmentQIndexDelta != 0) */
-                if (1)
-                {
-                    vp9_wb_write_bit(wb, 1);
-                    seg_delta = seg_data->SegmentQIndexDelta;
-                    vp9_wb_write_literal(wb, abs(seg_delta), 8);
-                    vp9_wb_write_bit(wb, seg_delta < 0);
-                }
-                else
-                {
-                    vp9_wb_write_bit(wb, 0);
-                }
-
-                /* The segment lf delta */
-                /* if (seg_data->SegmentLFLevelDelta != 0) */
-                if (1)
-                {
-                    vp9_wb_write_bit(wb, 1);
-                    seg_delta = seg_data->SegmentLFLevelDelta;
-                    vp9_wb_write_literal(wb, abs(seg_delta), 6);
-                    vp9_wb_write_bit(wb, seg_delta < 0);
-                }
-                else
-                {
-                    vp9_wb_write_bit(wb, 0);
-                }
-
-                /* segment reference flag */
-                vp9_wb_write_bit(wb, seg_data->SegmentFlags.fields.SegmentReferenceEnabled);
-                if (seg_data->SegmentFlags.fields.SegmentReferenceEnabled)
-                {
-                    vp9_wb_write_literal(wb, seg_data->SegmentFlags.fields.SegmentReference, 2);
-                }
-
-                /* segment skip flag */
-                vp9_wb_write_bit(wb, seg_data->SegmentFlags.fields.SegmentSkipped);
-            }
-        }
+        // Segmentation syntax will be filled by HW, need leave dummy here.
+        vp9_wb_write_bit(wb, 0);
+        vp9_wb_write_bit(wb, 0);
     }
+    headerBitoffset->bit_size_segmentation = wb->bit_offset - headerBitoffset->bit_offset_segmentation;
 
     /* write tile info */
     {
