@@ -25,7 +25,7 @@
 //! \details  Linux-specific Render Engine state heap management interfaces
 //!
 #include "mos_os.h"
-#include "renderhal.h"
+#include "renderhal_legacy.h"
 
 void RenderHal_SetupPrologParams(
     PRENDERHAL_INTERFACE              renderHal,
@@ -242,6 +242,7 @@ MOS_STATUS RenderHal_SetSurfaceStateToken(
 
     SURFACE_STATE_TOKEN_COMMON *pTokenState = (SURFACE_STATE_TOKEN_COMMON*)pSurfaceStateToken;
     PMOS_INTERFACE pOsInterface = pRenderHal->pOsInterface;
+    MHW_MI_CHK_NULL(pOsInterface);
     PMOS_RESOURCE  pOsResource  = &(pParams->pOsSurface->OsResource);
 
     int32_t  iAllocationIndex =  pOsInterface->pfnGetResourceAllocationIndex(pOsInterface, pOsResource);
@@ -441,6 +442,19 @@ MOS_STATUS RenderHal_AddDebugControl(
     return MOS_STATUS_SUCCESS;
 }
 
+//!
+//! \brief    Init Special Interface
+//! \details  Initializes RenderHal Interface structure, responsible for HW
+//!           abstraction of HW Rendering Engine for CM(MDF) and VP.
+//! \param    PRENDERHAL_INTERFACE pRenderHal
+//!           [in] Pointer to RenderHal Interface Structure
+//!
+void RenderHal_InitInterfaceEx_Legacy(PRENDERHAL_INTERFACE_LEGACY pRenderHal)
+{
+    RenderHal_InitInterfaceEx(pRenderHal);
+    return;
+}
+
 //!
 //! \brief    Init Special Interface
 //! \details  Initializes RenderHal Interface structure, responsible for HW
