@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -28,6 +28,7 @@
 #include "encode_av1_vdenc_feature_manager_xe_hpm.h"
 #include "encode_av1_brc_init_packet.h"
 #include "encode_av1_brc_update_packet.h"
+#include "encode_av1_pak_integrate_packet.h"
 #include "codechal_debug.h"
 
 namespace encode {
@@ -53,53 +54,26 @@ MOS_STATUS Av1VdencPipelineXe_Hpm::Init(void *settings)
 
     Av1BrcInitPkt* brcInitpkt = MOS_New(Av1BrcInitPkt, this, task, m_hwInterface);
     RegisterPacket(Av1HucBrcInit, brcInitpkt);
-    brcInitpkt->Init();
+    ENCODE_CHK_STATUS_RETURN(brcInitpkt->Init());
 
     Av1BrcUpdatePkt* brcUpdatepkt = MOS_New(Av1BrcUpdatePkt, this, task, m_hwInterface);
     RegisterPacket(Av1HucBrcUpdate, brcUpdatepkt);
-    brcUpdatepkt->Init();
+    ENCODE_CHK_STATUS_RETURN(brcUpdatepkt->Init());
 
     Av1VdencPktXe_Hpm *av1Vdencpkt = MOS_New(Av1VdencPktXe_Hpm, this, task, m_hwInterface);
     RegisterPacket(Av1VdencPacket, av1Vdencpkt);
-    av1Vdencpkt->Init();
+    ENCODE_CHK_STATUS_RETURN(av1Vdencpkt->Init());
+
+    if (m_dualEncEnable)
+    {
+        Av1PakIntegratePkt *av1PakIntPkt = MOS_New(Av1PakIntegratePkt, this, task, m_hwInterface);
+        RegisterPacket(Av1PakIntegrate, av1PakIntPkt);
+        ENCODE_CHK_STATUS_RETURN(av1PakIntPkt->Init());
+    }
 
     Av1BackAnnotationPkt *av1BackAnnotationpkt = MOS_New(Av1BackAnnotationPkt, this, task, m_hwInterface);
     RegisterPacket(Av1BackAnnotation, av1BackAnnotationpkt);
-    av1BackAnnotationpkt->Init();
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPipelineXe_Hpm::Initialize(void *settings)
-{
-    ENCODE_FUNC_CALL();
-
-    CodechalSetting *codecSettings = (CodechalSetting *)settings;
-    ENCODE_CHK_NULL_RETURN(m_hwInterface);
-    ENCODE_CHK_STATUS_RETURN(m_hwInterface->Initialize(codecSettings));
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipelineXe_M_Base::Initialize(settings));
-
-    CODECHAL_DEBUG_TOOL
-    (
-        if (m_debugInterface != nullptr)
-        {
-            MOS_Delete(m_debugInterface);
-        }
-        m_debugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_debugInterface);
-        ENCODE_CHK_NULL_RETURN(m_mediaCopyWrapper);
-        ENCODE_CHK_STATUS_RETURN(
-            m_debugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper->GetMediaCopyState()));
-
-        if (m_statusReportDebugInterface != nullptr)
-        {
-            MOS_Delete(m_statusReportDebugInterface);
-        }
-        m_statusReportDebugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_statusReportDebugInterface);
-        ENCODE_CHK_STATUS_RETURN(
-            m_statusReportDebugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper->GetMediaCopyState()));
-    );
+    ENCODE_CHK_STATUS_RETURN(av1BackAnnotationpkt->Init());
 
     return MOS_STATUS_SUCCESS;
 }
