@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -27,6 +27,7 @@
 #include "mos_solo_generic.h"
 #include "mhw_mi_itf.h"
 #include "mhw_vdbox_g12_X.h"
+#include "hal_oca_interface_next.h"
 
 namespace encode
 {
@@ -106,15 +107,6 @@ namespace encode
             m_basicFeature->m_bitstreamDecoderEncoderLineRowstoreReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
         }
 
-        // Bistream decode Tile Line rowstore buffer
-        if (!m_avpItf->IsBufferRowstoreCacheEnabled(mhw::vdbox::avp::bsdTileLineBuffer))
-        {
-            ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::bsdTileLineBuffer, &avpBufSizeParam));
-            allocParams.dwBytes                                      = avpBufSizeParam.bufferSize;
-            allocParams.pBufName                                     = "Bitstream Decoder Encoder Tile Line Rowstore Read Write buffer";
-            m_basicFeature->m_bitstreamDecoderEncoderTileLineRowstoreReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
-        }
-
         // Intra Prediction Tile Line Rowstore Read/Write Buffer
         ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::intraPredLineBuffer, &avpBufSizeParam));
         allocParams.dwBytes = avpBufSizeParam.bufferSize;
@@ -163,78 +155,6 @@ namespace encode
             m_basicFeature->m_deblockerFilterLineReadWriteVBuffer = m_allocator->AllocateResource(allocParams, false);
         }
 
-        // Deblocker Filter Tile Line Read/Write Y Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::deblockTileLineYBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "Deblocker Filter Tile Line Read Write Y Buffer";
-        m_basicFeature->m_deblockerFilterTileLineReadWriteYBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // Deblocker Filter Tile Line Read/Write U Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::deblockTileLineUBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "Deblocker Filter Tile Line Read Write U Buffer";
-        m_basicFeature->m_deblockerFilterTileLineReadWriteUBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // Deblocker Filter Tile Line Read/Write V Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::deblockTileLineVBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "Deblocker Filter Tile Line Read Write V Buffer";
-        m_basicFeature->m_deblockerFilterTileLineReadWriteVBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // Deblocker Filter Tile Column Read/Write Y Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::deblockTileColYBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "Deblocker Filter Tile Column Read Write Y Buffer";
-        m_basicFeature->m_deblockerFilterTileColumnReadWriteYBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // Deblocker Filter Tile Column Read/Write U Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::deblockTileColUBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "Deblocker Filter Tile Column Read Write U Buffer";
-        m_basicFeature->m_deblockerFilterTileColumnReadWriteUBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // Deblocker Filter Tile Column Read/Write V Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::deblockTileColVBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "Deblocker Filter Tile Column Read Write V Buffer";
-        m_basicFeature->m_deblockerFilterTileColumnReadWriteVBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // CDEF Filter Line Read/Write Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::cdefLineBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "CDEF Filter Line Read Write Buffer";
-        m_basicFeature->m_cdefFilterLineReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // CDEF Filter Tile Line Read/Write Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::cdefTileLineBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "CDEF Filter Tile Line Read Write Buffer";
-        m_basicFeature->m_cdefFilterTileLineReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // CDEF Filter Tile Column Read/Write Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::cdefTileColBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "CDEF Filter Tile Column Read Write Buffer";
-        m_basicFeature->m_cdefFilterTileColumnReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // CDEF Filter Meta Tile Line Read Write Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::cdefMetaTileLineBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "CDEF Filter Meta Tile Line Read Write Buffer";
-        m_basicFeature->m_cdefFilterMetaTileLineReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // CDEF Filter Meta Tile Column Read Write Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::cdefMetaTileColBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "CDEF Filter Meta Tile Column Read Write Buffer";
-        m_basicFeature->m_cdefFilterMetaTileColumnReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
-
-        // CDEF Filter Top Left Corner Read Write Buffer
-        ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::cdefTopLeftCornerBuffer, &avpBufSizeParam));
-        allocParams.dwBytes = avpBufSizeParam.bufferSize;
-        allocParams.pBufName = "CDEF Filter Top Left Corner Read Write Buffer";
-        m_basicFeature->m_cdefFilterTopLeftCornerReadWriteBuffer = m_allocator->AllocateResource(allocParams, false);
-
         // Decoded Frame Status/Error Buffer Base Address
         ENCODE_CHK_STATUS_RETURN(m_avpItf->GetAvpBufSize(mhw::vdbox::avp::frameStatusErrBuffer, &avpBufSizeParam));
         allocParams.dwBytes = avpBufSizeParam.bufferSize;
@@ -269,11 +189,14 @@ namespace encode
         allocParamsForBuffer2D.dwWidth            = MOS_ALIGN_CEIL(m_basicFeature->m_frameWidth, av1SuperBlockWidth);
         allocParamsForBuffer2D.dwHeight           = MOS_ALIGN_CEIL(m_basicFeature->m_frameHeight, av1SuperBlockHeight);
 
+#ifdef _MMC_SUPPORTED
+        ENCODE_CHK_NULL_RETURN(m_mmcState);
         if (m_mmcState->IsMmcEnabled() && m_basicFeature->m_reconSurface.bCompressible)
         {
             allocParamsForBuffer2D.CompressionMode = MOS_MMC_MC;
             allocParamsForBuffer2D.bIsCompressible = true;
         }
+#endif
         if (m_basicFeature->m_is10Bit)
         {
             // This is temporary fix for Sim specific ( Grits Utility) issue, HW has no restriction for current platform
@@ -285,17 +208,6 @@ namespace encode
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS Av1VdencPktXe_M_Base::Prepare()
-    {
-        ENCODE_FUNC_CALL();
-
-        Av1VdencPkt::Prepare();
-
-        m_basicFeature->m_ref.SetPostCdefAsEncRef(true);
-
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS Av1VdencPktXe_M_Base::Submit(
         MOS_COMMAND_BUFFER* commandBuffer,
         uint8_t packetPhase)
@@ -325,17 +237,20 @@ namespace encode
 
         ENCODE_CHK_STATUS_RETURN(PatchTileLevelCommands(cmdBuffer, packetPhase));
 
+        ENCODE_CHK_STATUS_RETURN(PrepareHWMetaData(&cmdBuffer));
+
         ENCODE_CHK_STATUS_RETURN(Mos_Solo_PostProcessEncode(m_osInterface, &m_basicFeature->m_resBitstreamBuffer, &m_basicFeature->m_reconSurface));
 
     #if MHW_HWCMDPARSER_ENABLED
         auto instance = mhw::HwcmdParser::GetInstance();
         if (instance)
         {
-            instance->ParseCmdBuf(cmdBuffer.pCmdBase, cmdBuffer.iOffset / sizeof(uint32_t));
+            instance->ParseCmdBuf(IGFX_UNKNOWN, cmdBuffer.pCmdBase, cmdBuffer.iOffset / sizeof(uint32_t));
         }
     #endif
 #if USE_CODECHAL_DEBUG_TOOL
         ENCODE_CHK_STATUS_RETURN(DumpStatistics());
+        ENCODE_CHK_STATUS_RETURN(Av1VdencPkt::DumpInput());
 #endif  // USE_CODECHAL_DEBUG_TOOL
         return MOS_STATUS_SUCCESS;
     }
@@ -357,32 +272,45 @@ namespace encode
             ENCODE_CHK_STATUS_RETURN(SendPrologCmds(cmdBuffer));
         }
 
+        if (m_pipeline->GetPipeNum() >= 2)
+        {
+            auto scalability = m_pipeline->GetMediaScalability();
+
+            ENCODE_CHK_STATUS_RETURN(scalability->SyncPipe(syncOtherPipesForOne, 0, &cmdBuffer));
+        }
+
         ENCODE_CHK_STATUS_RETURN(AddCondBBEndFor2ndPass(cmdBuffer));
 
+        if(m_pipeline->GetPipeNum() >= 2 && m_pipeline->IsFirstPipe())
+        {
+            PMOS_RESOURCE bsSizeBuf = m_basicFeature->m_recycleBuf->GetBuffer(PakInfo, 0);
+            ENCODE_CHK_NULL_RETURN(bsSizeBuf);
+            // clear bitstream size buffer at first tile
+            auto &miStoreDataParams            = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
+            miStoreDataParams                  = {};
+            miStoreDataParams.pOsResource      = bsSizeBuf;
+            miStoreDataParams.dwResourceOffset = 0;
+            miStoreDataParams.dwValue          = 0;
+            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(&cmdBuffer));
+        }
+
         if (m_pipeline->IsFirstPipe())
         {
             ENCODE_CHK_STATUS_RETURN(StartStatusReport(statusReportMfx, &cmdBuffer));
         }
+        else{
+            // add perf record for other pipes - first pipe perf record within StartStatusReport
+            MediaPerfProfiler *perfProfiler = MediaPerfProfiler::Instance();
+            ENCODE_CHK_NULL_RETURN(perfProfiler);
+            ENCODE_CHK_STATUS_RETURN(perfProfiler->AddPerfCollectStartCmd(
+                (void *)m_pipeline, m_osInterface, m_miItf, &cmdBuffer));
+        }
 
         ENCODE_CHK_STATUS_RETURN(AddPictureVdencCommands(cmdBuffer));
 
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS Av1VdencPktXe_M_Base::AddPictureVdencCommands(MOS_COMMAND_BUFFER &cmdBuffer)
-    {
-        ENCODE_FUNC_CALL();
-
-        SETPAR_AND_ADDCMD(VDENC_CONTROL_STATE, m_vdencItf, &cmdBuffer);
-        SETPAR_AND_ADDCMD(VDENC_PIPE_MODE_SELECT, m_vdencItf, &cmdBuffer);
-        SETPAR_AND_ADDCMD(VDENC_SRC_SURFACE_STATE, m_vdencItf, &cmdBuffer);
-        SETPAR_AND_ADDCMD(VDENC_REF_SURFACE_STATE, m_vdencItf, &cmdBuffer);
-        SETPAR_AND_ADDCMD(VDENC_DS_REF_SURFACE_STATE, m_vdencItf, &cmdBuffer);
-        SETPAR_AND_ADDCMD(VDENC_PIPE_BUF_ADDR_STATE, m_vdencItf, &cmdBuffer);
-
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS Av1VdencPktXe_M_Base::Construct3rdLevelBatch()
     {
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
@@ -402,10 +330,6 @@ namespace encode
         ENCODE_FUNC_CALL();
 
         RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, SetCurrentTile, tileRow, tileCol, m_pipeline);
-        if ((m_pipeline->GetPipeNum() > 1) && (tileCol != m_pipeline->GetCurrentPipe()))
-        {
-            return MOS_STATUS_SUCCESS;
-        }
 
         // Begin patching tile level batch cmds
         MOS_COMMAND_BUFFER constructTileBatchBuf = {};
@@ -425,6 +349,16 @@ namespace encode
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(&cmdBuffer, tileLevelBatchBuffer));
 
             tempCmdBuffer = &constructTileBatchBuf;
+            MHW_MI_MMIOREGISTERS mmioRegister;
+            if (m_vdencItf->ConvertToMiRegister(MHW_VDBOX_NODE_1, mmioRegister))
+            {
+                HalOcaInterfaceNext::On1stLevelBBStart(
+                    *tempCmdBuffer,
+                    (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext,
+                    m_osInterface->CurrentGpuContextHandle,
+                    m_miItf,
+                    mmioRegister);
+            }
         }
 
         auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
@@ -438,13 +372,20 @@ namespace encode
         ENCODE_CHK_STATUS_RETURN(AddAllCmds_AVP_SURFACE_STATE(tempCmdBuffer));
         SETPAR_AND_ADDCMD(AVP_PIPE_BUF_ADDR_STATE, m_avpItf, tempCmdBuffer);
         SETPAR_AND_ADDCMD(AVP_IND_OBJ_BASE_ADDR_STATE, m_avpItf, tempCmdBuffer);
+        bool firstTileInGroup = false;
         if (brcFeature->IsBRCEnabled())
         {
-            bool firstTileInGroup = false;
             uint32_t tileGroupIdx = 0;
             RUN_FEATURE_INTERFACE_NO_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, IsFirstTileInGroup, firstTileInGroup, tileGroupIdx);
             vdenc2ndLevelBatchBuffer->dwOffset = firstTileInGroup? slbbData.avpPicStateOffset : slbbData.secondAvpPicStateOffset;
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+            HalOcaInterfaceNext::OnSubLevelBBStart(
+                *tempCmdBuffer,
+                m_osInterface->pOsContext,
+                &vdenc2ndLevelBatchBuffer->OsResource,
+                vdenc2ndLevelBatchBuffer->dwOffset,
+                false,
+                slbbData.slbSize - vdenc2ndLevelBatchBuffer->dwOffset);
         }
         else
         {
@@ -455,6 +396,13 @@ namespace encode
         {
             vdenc2ndLevelBatchBuffer->dwOffset = slbbData.avpSegmentStateOffset;
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+            HalOcaInterfaceNext::OnSubLevelBBStart(
+                *tempCmdBuffer,
+                m_osInterface->pOsContext,
+                &vdenc2ndLevelBatchBuffer->OsResource,
+                vdenc2ndLevelBatchBuffer->dwOffset,
+                false,
+                slbbData.vdencCmd1Offset - vdenc2ndLevelBatchBuffer->dwOffset);
         }
         else
         {
@@ -470,6 +418,13 @@ namespace encode
         {
             vdenc2ndLevelBatchBuffer->dwOffset = slbbData.vdencCmd1Offset;
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+            HalOcaInterfaceNext::OnSubLevelBBStart(
+                *tempCmdBuffer,
+                m_osInterface->pOsContext,
+                &vdenc2ndLevelBatchBuffer->OsResource,
+                vdenc2ndLevelBatchBuffer->dwOffset,
+                false,
+                slbbData.vdencCmd2Offset - vdenc2ndLevelBatchBuffer->dwOffset);
         }
         else
         {
@@ -480,6 +435,13 @@ namespace encode
         {
             vdenc2ndLevelBatchBuffer->dwOffset = slbbData.vdencCmd2Offset;
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(tempCmdBuffer, vdenc2ndLevelBatchBuffer));
+            HalOcaInterfaceNext::OnSubLevelBBStart(
+                *tempCmdBuffer,
+                m_osInterface->pOsContext,
+                &vdenc2ndLevelBatchBuffer->OsResource,
+                vdenc2ndLevelBatchBuffer->dwOffset,
+                false,
+                (firstTileInGroup ? slbbData.avpPicStateOffset : slbbData.secondAvpPicStateOffset) - vdenc2ndLevelBatchBuffer->dwOffset);
         }
         else
         {
@@ -501,31 +463,51 @@ namespace encode
             tileLevelBatchBuffer->iCurrent = constructTileBatchBuf.iOffset;
             tileLevelBatchBuffer->iRemaining = constructTileBatchBuf.iRemaining;
             ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, tileLevelBatchBuffer));
+            HalOcaInterfaceNext::OnSubLevelBBStart(
+                cmdBuffer,
+                m_osInterface->pOsContext,
+                &tempCmdBuffer->OsResource,
+                0,
+                false,
+                tempCmdBuffer->iOffset);
+            HalOcaInterfaceNext::On1stLevelBBEnd(*tempCmdBuffer, *m_osInterface);
         }
 
     #if MHW_HWCMDPARSER_ENABLED
         auto instance = mhw::HwcmdParser::GetInstance();
         if (instance)
         {
-            instance->ParseCmdBuf(tempCmdBuffer->pCmdBase, tempCmdBuffer->iOffset / sizeof(uint32_t));
+            instance->ParseCmdBuf(IGFX_UNKNOWN, tempCmdBuffer->pCmdBase, tempCmdBuffer->iOffset / sizeof(uint32_t));
         }
     #endif
 
 #if USE_CODECHAL_DEBUG_TOOL
+        std::string             name           = std::to_string(tileRow) + std::to_string(tileCol) + std::to_string(tileRowPass) + "_TILE_CMD_BUFFER";
         CodechalDebugInterface* debugInterface = m_pipeline->GetDebugInterface();
         ENCODE_CHK_NULL_RETURN(debugInterface);
 
         ENCODE_CHK_STATUS_RETURN(debugInterface->DumpCmdBuffer(
             &constructTileBatchBuf,
             CODECHAL_NUM_MEDIA_STATES,
-            "_TILE_CMD_BUFFER"));
+            name.c_str()));
 #endif
 
         // End patching tile level batch cmds
         RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, EndPatchTileLevelBatch);
 
-        ENCODE_CHK_STATUS_RETURN(ReadPakMmioRegisters(&cmdBuffer, tileRow == 0 && tileCol == 0));
-
+        if (tileRowPass != 1) // for dummy tile, donnot calculate tile size into frame size.
+        {
+            if (m_pipeline->GetPipeNum() > 1)
+            {
+                ENCODE_CHK_STATUS_RETURN(ReadPakMmioRegistersAtomic(&cmdBuffer));
+            }
+            else
+            {
+                ENCODE_CHK_STATUS_RETURN(ReadPakMmioRegisters(&cmdBuffer, tileRow == 0 && tileCol == 0));
+            }
+        }
+        ENCODE_CHK_STATUS_RETURN(PrepareHWMetaDataFromStreamoutTileLevel(&cmdBuffer, tileCol, tileRow));
+        
         return MOS_STATUS_SUCCESS;
     }
 
@@ -570,14 +552,54 @@ namespace encode
         uint16_t numTileRows = 1;
         RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileRowColumns, numTileRows, numTileColumns);
 
-        for (uint32_t tileRow = 0; tileRow < numTileRows; tileRow++)
+        ENCODE_CHK_NULL_RETURN(m_pipeline);
+        ENCODE_CHK_NULL_RETURN(m_av1PicParams);
+        if (!m_pipeline->IsDualEncEnabled())
         {
-            for (uint32_t tileCol = 0; tileCol < numTileColumns; tileCol++)
+            for (uint32_t tileRow = 0; tileRow < numTileRows; tileRow++)
             {
+                for (uint32_t tileCol = 0; tileCol < numTileColumns; tileCol++)
+                {
+                    ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
+                        cmdBuffer,
+                        tileRow,
+                        tileCol));
+                }
+            }
+        }
+        else
+        {
+            if(numTileRows != 1)  // dual encode only support column based workload submission
+            {
+                ENCODE_ASSERTMESSAGE("dual encode cannot support multi rows submission yet.");
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
+            uint8_t dummyIdx = 0;
+            RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetDummyIdx, dummyIdx);
+            if (m_pipeline->GetCurrentPipe() == 0)
+            {
+                for (auto i = 0; i < dummyIdx; i++)
+                {
+                    ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
+                        cmdBuffer,
+                        0,
+                        i));
+                }
                 ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
                     cmdBuffer,
-                    tileRow,
-                    tileCol));
+                    0,
+                    dummyIdx,
+                    1));
+            }
+            else
+            {
+                for (auto i = dummyIdx; i < numTileColumns; i++)
+                {
+                    ENCODE_CHK_STATUS_RETURN(AddOneTileCommands(
+                        cmdBuffer,
+                        0,
+                        i));
+                }
             }
         }
 
@@ -590,7 +612,21 @@ namespace encode
         auto scalability = m_pipeline->GetMediaScalability();
         ENCODE_CHK_STATUS_RETURN(scalability->SyncPipe(syncOnePipeWaitOthers, 0, &cmdBuffer));
 
-        ENCODE_CHK_STATUS_RETURN(EndStatusReport(statusReportMfx, &cmdBuffer));
+        if (m_pipeline->IsFirstPipe()) 
+        {
+            for (auto i = 0; i < m_pipeline->GetPipeNum(); ++i)
+            {
+                ENCODE_CHK_STATUS_RETURN(scalability->ResetSemaphore(syncOnePipeWaitOthers, i, &cmdBuffer));
+            }
+            ENCODE_CHK_STATUS_RETURN(EndStatusReport(statusReportMfx, &cmdBuffer));
+        }
+        else{
+            // add perf record for other pipes - first pipe perf record within EndStatusReport
+            MediaPerfProfiler *perfProfiler = MediaPerfProfiler::Instance();
+            ENCODE_CHK_NULL_RETURN(perfProfiler);
+            ENCODE_CHK_STATUS_RETURN(perfProfiler->AddPerfCollectEndCmd(
+                (void *)m_pipeline, m_osInterface, m_miItf, &cmdBuffer));
+        }
         auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
         ENCODE_CHK_NULL_RETURN(brcFeature);
 
@@ -607,6 +643,11 @@ namespace encode
             ENCODE_CHK_STATUS_RETURN(MediaPacket::UpdateStatusReportNext(statusReportGlobalCount, &cmdBuffer));
         }
 
+        if (m_pipeline->IsDualEncEnabled())
+        {
+            SETPAR_AND_ADDCMD(VDENC_CONTROL_STATE, m_vdencItf, &cmdBuffer);
+        }
+
         CODECHAL_DEBUG_TOOL(
             if (m_mmcState) {
                 m_mmcState->UpdateUserFeatureKey(&(m_basicFeature->m_reconSurface));
@@ -637,87 +678,6 @@ namespace encode
         //TBD
     }
 
-    MOS_STATUS Av1VdencPktXe_M_Base::ReadAvpStatus(MHW_VDBOX_NODE_IND vdboxIndex, MediaStatusReport * statusReport, MOS_COMMAND_BUFFER & cmdBuffer)
-    {
-        ENCODE_FUNC_CALL();
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
-        CODEC_HW_FUNCTION_ENTER;
-
-        ENCODE_CHK_NULL_RETURN(statusReport);
-        ENCODE_CHK_NULL_RETURN(m_hwInterface);
-
-        MOS_RESOURCE *osResource    = nullptr;
-        uint32_t     offset         = 0;
-
-        EncodeStatusReadParams params;
-        MOS_ZeroMemory(&params, sizeof(params));
-
-        ENCODE_CHK_STATUS_RETURN(statusReport->GetAddress(encode::statusReportMfxBitstreamByteCountPerFrame, osResource, offset));
-        params.resBitstreamByteCountPerFrame    = osResource;
-        params.bitstreamByteCountPerFrameOffset = offset;
-
-        ENCODE_CHK_STATUS_RETURN(statusReport->GetAddress(encode::statusReportQPStatusCount, osResource, offset));
-        params.resQpStatusCount    = osResource;
-        params.qpStatusCountOffset = offset;
-
-        ENCODE_CHK_STATUS_RETURN(statusReport->GetAddress(encode::statusReportImageStatusMask, osResource, offset));
-        params.resImageStatusMask    = osResource;
-        params.imageStatusMaskOffset = offset;
-
-        ENCODE_CHK_STATUS_RETURN(statusReport->GetAddress(encode::statusReportImageStatusCtrl, osResource, offset));
-        params.resImageStatusCtrl    = osResource;
-        params.imageStatusCtrlOffset = offset;
-
-        //hwInterfaceG12->ReadAvpStatus
-        //auto hwInterfaceG12 = dynamic_cast<CodechalHwInterfaceG12 *>(m_hwInterface);
-        //ENCODE_CHK_NULL_RETURN(hwInterfaceG12);
-        //ENCODE_CHK_STATUS_RETURN(hwInterfaceG12->ReadAvpStatus(vdboxIndex, params, &cmdBuffer));
-        CODECHAL_HW_CHK_COND_RETURN((vdboxIndex > m_hwInterface->GetMaxVdboxIndex()), "ERROR - vdbox index exceed the maximum");
-
-        auto &flushDwParams = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
-        flushDwParams       = {};
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
-
-        CODECHAL_HW_CHK_NULL_RETURN(m_avpItf);
-        auto mmioRegisters = m_avpItf->GetMmioRegisters(vdboxIndex);
-
-        auto &miStoreRegMemParams           = m_miItf->MHW_GETPAR_F(MI_STORE_REGISTER_MEM)();
-        miStoreRegMemParams                 = {};
-        miStoreRegMemParams.presStoreBuffer = params.resBitstreamByteCountPerFrame;
-        miStoreRegMemParams.dwOffset        = params.bitstreamByteCountPerFrameOffset;
-        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1BitstreamByteCountTileRegOffset;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
-
-        miStoreRegMemParams                 = {};
-        miStoreRegMemParams.presStoreBuffer = params.resQpStatusCount;
-        miStoreRegMemParams.dwOffset        = params.qpStatusCountOffset;
-        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1QpStatusCountRegOffset;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
-
-        //ENCODE_CHK_STATUS_RETURN(hwInterfaceG12->ReadImageStatusForAvp(vdboxIndex, params, &cmdBuffer));
-        //std::shared_ptr<mhw::vdbox::avp::Itf> m_avpItf = GetAvpInterfaceNext();
-        //CODECHAL_HW_CHK_NULL_RETURN(m_avpItf);
-        //auto mmioRegisters = m_avpItf->GetMmioRegisters(vdboxIndex);
-
-        miStoreRegMemParams                 = {};
-        miStoreRegMemParams.presStoreBuffer = params.resImageStatusMask;
-        miStoreRegMemParams.dwOffset        = params.imageStatusMaskOffset;
-        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1ImageStatusMaskRegOffset;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
-
-        miStoreRegMemParams                 = {};
-        miStoreRegMemParams.presStoreBuffer = params.resImageStatusCtrl;
-        miStoreRegMemParams.dwOffset        = params.imageStatusCtrlOffset;
-        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1ImageStatusControlRegOffset;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
-
-        flushDwParams       = {};
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
-
-        return eStatus;
-    }
-
     MHW_SETPAR_DECL_SRC(AVP_IND_OBJ_BASE_ADDR_STATE, Av1VdencPktXe_M_Base)
     {
         params.mvObjectOffset = m_mvOffset;
@@ -809,90 +769,6 @@ namespace encode
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS Av1VdencPktXe_M_Base::AddAllCmds_AVP_PAK_INSERT_OBJECT(PMOS_COMMAND_BUFFER cmdBuffer) const
-    {
-        ENCODE_FUNC_CALL();
-
-        ENCODE_CHK_NULL_RETURN(m_osInterface);
-        auto& params = m_avpItf->MHW_GETPAR_F(AVP_PAK_INSERT_OBJECT)();
-        params      = {};
-
-        auto GetExtraData = [&]() { return params.bsBuffer->pBase + params.offset; };
-        auto GetExtraSize = [&]() { return (params.bitSize + 7) >> 3; };
-
-        // First, Send all other OBU bit streams other than tile group OBU when it's first tile in frame
-        uint32_t tileIdx    = 0;
-        bool     tgOBUValid = m_basicFeature->m_slcData[0].BitSize > 0 ? true : false;
-
-        RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileIdx, tileIdx);
-        auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
-        ENCODE_CHK_NULL_RETURN(brcFeature);
-
-        if (tileIdx == 0)
-        {
-            uint32_t nalNum = 0;
-            for (uint32_t i = 0; i < MAX_NUM_OBU_TYPES && m_nalUnitParams[i]->uiSize > 0; i++)
-            {
-                nalNum = i;
-            }
-
-            params.bsBuffer             = &m_basicFeature->m_bsBuffer;
-            params.endOfHeaderInsertion = false;
-
-            // Support multiple packed header buffer
-            for (uint32_t i = 0; i <= nalNum; i++)
-            {
-                uint32_t nalUnitSize   = m_nalUnitParams[i]->uiSize;
-                uint32_t nalUnitOffset = m_nalUnitParams[i]->uiOffset;
-
-                ENCODE_ASSERT(nalUnitSize < CODECHAL_ENCODE_AV1_PAK_INSERT_UNCOMPRESSED_HEADER);
-
-                params.bitSize    = nalUnitSize * 8;
-                params.offset     = nalUnitOffset;
-                params.lastHeader = !tgOBUValid && (i == nalNum);
-
-                if (IsFrameHeader(*(m_basicFeature->m_bsBuffer.pBase + nalUnitOffset)))
-                {
-                    if (brcFeature->IsBRCEnabled())
-                    {
-                        auto pakInsertOutputBatchBuffer = brcFeature->GetPakInsertOutputBatchBuffer(m_pipeline->m_currRecycledBufIdx);
-                        ENCODE_CHK_NULL_RETURN(pakInsertOutputBatchBuffer);
-                        // send pak insert obj cmds after back annotation
-                        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(cmdBuffer, pakInsertOutputBatchBuffer));
-                    }
-                    else
-                    {
-                        m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
-                        m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
-                    }
-                }
-                else
-                {
-                    m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
-                    m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
-                }
-            }
-        }
-
-        // Second, Send tile group OBU when it is first tile in tile group
-        if (tgOBUValid)
-        {
-            ENCODE_CHK_NULL_RETURN(m_featureManager);
-
-            auto tileFeature = dynamic_cast<Av1EncodeTile *>(m_featureManager->GetFeature(Av1FeatureIDs::encodeTile));
-            ENCODE_CHK_NULL_RETURN(tileFeature);
-
-            MHW_CHK_STATUS_RETURN(tileFeature->MHW_SETPAR_F(AVP_PAK_INSERT_OBJECT)(params));
-            if (params.bitSize)
-            {
-                m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
-                m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
-            }
-        }
-
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS Av1VdencPktXe_M_Base::CalculateAvpPictureStateCommandSize(uint32_t * commandsSize, uint32_t * patchListSize)
     {
         ENCODE_FUNC_CALL();
