@@ -31,6 +31,7 @@
 #include "encode_av1_vdenc_packet_xe_lpm_plus.h"
 #include "encode_av1_brc_init_packet.h"
 #include "encode_av1_brc_update_packet.h"
+#include "encode_av1_pak_integrate_packet.h"
 #include "codechal_debug.h"
 #include "encode_av1_vdenc_feature_manager_xe_lpm_plus_base.h"
 #include "encode_preenc_packet.h"
@@ -56,6 +57,15 @@ MOS_STATUS Av1VdencPipelineXe_LPM_Plus::Init(void *settings)
         EncodePreEncPacket* av1PreEncPkt = MOS_New(EncodePreEncPacket, this, task, m_hwInterface);
         ENCODE_CHK_STATUS_RETURN(RegisterPacket(encodePreEncPacket, av1PreEncPkt));
         ENCODE_CHK_STATUS_RETURN(av1PreEncPkt->Init());
+
+#if USE_CODECHAL_DEBUG_TOOL
+        uint32_t encodeMode = 0;
+        RUN_FEATURE_INTERFACE_RETURN(Av1VdencPreEnc, Av1FeatureIDs::preEncFeature, GetEncodeMode, encodeMode);
+        if (encodeMode == MediaEncodeMode::MANUAL_RES_PRE_ENC || encodeMode == MediaEncodeMode::AUTO_RES_PRE_ENC)
+        {
+            return MOS_STATUS_SUCCESS;
+        }
+#endif
     }
 
     Av1BrcInitPkt *brcInitpkt = MOS_New(Av1BrcInitPkt, this, task, m_hwInterface);
@@ -74,6 +84,13 @@ MOS_STATUS Av1VdencPipelineXe_LPM_Plus::Init(void *settings)
     RegisterPacket(Av1VdencPacket, av1Vdencpkt);
     ENCODE_CHK_STATUS_RETURN(av1Vdencpkt->Init());
 
+    if (m_dualEncEnable)
+    {
+        Av1PakIntegratePkt* av1PakIntPkt = MOS_New(Av1PakIntegratePkt, this, task, m_hwInterface);
+        RegisterPacket(Av1PakIntegrate, av1PakIntPkt);
+        ENCODE_CHK_STATUS_RETURN(av1PakIntPkt->Init());
+    }
+
     auto av1BackAnnotationpkt = MOS_New(Av1BackAnnotationPkt, this, task, m_hwInterface);
     RegisterPacket(Av1BackAnnotation, av1BackAnnotationpkt);
     ENCODE_CHK_STATUS_RETURN(av1BackAnnotationpkt->Init());
