@@ -34,16 +34,10 @@ namespace decode
     {
         for (uint8_t i = 0; i < av1DefaultCdfTableNum; i++)
         {
-            if (!m_allocator->ResourceIsNull(&m_tmpCdfBuffers[i]->OsResource))
-            {
-                m_allocator->Destroy(m_tmpCdfBuffers[i]);
-            }
-
             if (!m_allocator->ResourceIsNull(&m_defaultCdfBuffers[i]->OsResource))
             {
                 m_allocator->Destroy(m_defaultCdfBuffers[i]);
             }
-
         }
         if (m_usingDummyWl == true)
         {
@@ -110,6 +104,11 @@ namespace decode
         m_av1PicParams  = static_cast<CodecAv1PicParams*>(decodeParams->m_picParams);
         DECODE_CHK_NULL(m_av1PicParams);
 
+        if (decodeParams->m_destSurface->OsResource.Format == Format_P010)
+        {
+            m_bitDepth = 10;
+        }
+
         // Do error detection and concealment
         DECODE_CHK_STATUS(ErrorDetectAndConceal());
 
@@ -170,6 +169,20 @@ namespace decode
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS Av1BasicFeature::CheckBitdepth()
+    {
+        DECODE_FUNC_CALL();
+
+        if ((m_av1PicParams->m_bitDepthIdx == 0 && m_bitDepth != 8) ||
+            (m_av1PicParams->m_bitDepthIdx == 1 && m_bitDepth != 10))
+        {
+            DECODE_ASSERTMESSAGE("Bit depth not align!");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     MOS_STATUS Av1BasicFeature::ErrorDetectAndConceal()
     {
         DECODE_FUNC_CALL()
@@ -177,13 +190,28 @@ namespace decode
 
         DECODE_CHK_STATUS(CheckProfileAndSubsampling());
 
+        DECODE_CHK_STATUS(CheckBitdepth());
+
+        // Frame Width/Frame Height, valid range is [15, 16383]
+        if (m_av1PicParams->m_frameWidthMinus1 < 15 || m_av1PicParams->m_frameHeightMinus1 < 15)
+        {
+            DECODE_ASSERTMESSAGE("Frame Width/Height is invalid, out of [15, 16383].");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
+        if (!m_av1PicParams->m_seqInfoFlags.m_fields.m_enableOrderHint &&
+            (m_av1PicParams->m_orderHint != 0))
+        {
+            DECODE_ASSERTMESSAGE("orderHint Conflict with AV1 Spec!");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
         if(m_av1PicParams->m_picInfoFlags.m_fields.m_allowIntrabc &&
             (!(m_av1PicParams->m_picInfoFlags.m_fields.m_frameType == keyFrame ||
                 m_av1PicParams->m_picInfoFlags.m_fields.m_frameType == intraOnlyFrame) ||
                 !m_av1PicParams->m_picInfoFlags.m_fields.m_allowScreenContentTools ||
                 m_av1PicParams->m_picInfoFlags.m_fields.m_useSuperres))
         {
-            DECODE_ASSERTMESSAGE("Conflict with AV1 Spec.");
+            DECODE_ASSERTMESSAGE("Superres use Conflict with AV1 Spec.");
             return MOS_STATUS_INVALID_PARAMETER;
         }
 
@@ -355,6 +383,16 @@ namespace decode
             m_av1PicParams->m_loopRestorationFlags.m_value = 0;
         }
 
+        // LRU Luma Size cannot < Superblock Size. If Superblock Size is 128x128, LRU Luma Size cannot be 64x64.
+        if (m_av1PicParams->m_seqInfoFlags.m_fields.m_use128x128Superblock)
+        {
+            if (m_av1PicParams->m_loopRestorationFlags.m_fields.m_lrUnitShift == 0)
+            {
+                DECODE_ASSERTMESSAGE("Superblock use Conflict with AV1 Spec!");
+                m_av1PicParams->m_loopRestorationFlags.m_value = 0;
+            }
+        }
+
         // Error Concealment for DeltaLF and DeltaQ
         if (m_av1PicParams->m_baseQindex == 0)
         {
@@ -388,6 +426,12 @@ namespace decode
             memset(&m_av1PicParams->m_filmGrainParams, 0, sizeof(CodecAv1FilmGrainParams));
         }
 
+        // Error Concealment for Reference List
+        if (m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != keyFrame && m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != intraOnlyFrame)
+        {
+            DECODE_CHK_STATUS(m_refFrames.ErrorConcealment(*m_av1PicParams));
+        }
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -823,20 +867,16 @@ namespace decode
         {
             for (uint8_t index = 0; index < av1DefaultCdfTableNum; index++)
             {
-                m_tmpCdfBuffers[index] = m_allocator->AllocateBuffer(
+                m_defaultCdfBuffers[index] = m_allocator->AllocateBuffer(
                     MOS_ALIGN_CEIL(m_cdfMaxNumBytes, CODECHAL_PAGE_SIZE), "TempCdfTableBuffer",
                     resourceInternalRead, lockableVideoMem);
-                DECODE_CHK_NULL(m_tmpCdfBuffers[index]);
+                DECODE_CHK_NULL(m_defaultCdfBuffers[index]);
 
-                auto data = (uint16_t *)m_allocator->LockResourceForWrite(&m_tmpCdfBuffers[index]->OsResource);
+                auto data = (uint16_t *)m_allocator->LockResourceForWrite(&m_defaultCdfBuffers[index]->OsResource);
                 DECODE_CHK_NULL(data);
 
                 // reset all CDF tables to default values
                 DECODE_CHK_STATUS(InitDefaultFrameContextBuffer(data, index));
-                m_defaultCdfBuffers[index] = m_allocator->AllocateBuffer(
-                    MOS_ALIGN_CEIL(m_cdfMaxNumBytes, CODECHAL_PAGE_SIZE), "m_defaultCdfBuffers",
-                    resourceInternalRead, notLockableVideoMem);
-                DECODE_CHK_NULL(m_defaultCdfBuffers[index]);
             }
 
             m_defaultFcInitialized = true;//set only once, won't set again
