@@ -154,7 +154,7 @@ MOS_STATUS JpegDecodePicPkt::CalculateCommandSize(uint32_t &commandBufferSize, u
 MHW_SETPAR_DECL_SRC(MFX_PIPE_MODE_SELECT, JpegDecodePicPkt)
 {
     params.Mode                                           = m_jpegBasicFeature->m_mode;
-    params.streamOutEnabled                               = false;
+    params.streamOutEnable                                = false;
     params.deblockerStreamOutEnable                       = false;
     params.preDeblockingOutputEnablePredeblockoutenable   = true;
     params.postDeblockingOutputEnablePostdeblockoutenable = false;
@@ -319,10 +319,22 @@ MOS_STATUS JpegDecodePicPkt::AddAllCmds_MFX_QM_STATE(PMOS_COMMAND_BUFFER cmdBuff
     {
         bJpegQMRotation = false;
     }
+
+    if (m_jpegPicParams->m_numCompInFrame > jpegNumComponent)
+    {
+        DECODE_ASSERTMESSAGE("Unsupported Component Number in JPEG Picture parameter.");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
     for (uint16_t scanCount = 0; scanCount < m_jpegPicParams->m_numCompInFrame; scanCount++)
     {
         // Using scanCount here because the same command is used for JPEG decode and encode
         uint32_t quantTableSelector                             = m_jpegPicParams->m_quantTableSelector[scanCount];
+        if (quantTableSelector >= JPEG_MAX_NUM_OF_QUANTMATRIX)
+        {
+            DECODE_ASSERTMESSAGE("Unsupported QuantTableSelector in JPEG Picture parameter.");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
         pJpegQuantMatrix->m_jpegQMTableType[quantTableSelector] = scanCount;
         auto JpegQMTableSelector                                = quantTableSelector;
 
@@ -362,10 +374,22 @@ MOS_STATUS JpegDecodePicPkt::AddAllCmds_MFX_JPEG_HUFF_TABLE_STATE(PMOS_COMMAND_B
     uint32_t dcCurHuffTblIndex[2] = {0xff, 0xff};
     uint32_t acCurHuffTblIndex[2] = {0xff, 0xff};
 
+    if (m_jpegBasicFeature->m_jpegScanParams->NumScans > jpegNumComponent)
+    {
+        DECODE_ASSERTMESSAGE("Unsupported Components Number in JPEG scan parameter.");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
     for (uint16_t scanCount = 0; scanCount < m_jpegBasicFeature->m_jpegScanParams->NumScans; scanCount++)
     {
         // MFX_JPEG_HUFF_TABLE
         uint16_t numComponents = m_jpegBasicFeature->m_jpegScanParams->ScanHeader[scanCount].NumComponents;
+        if (numComponents > jpegNumComponent)
+        {
+            DECODE_ASSERTMESSAGE("Unsupported Components Number in JPEG scan parameter.");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
         for (uint16_t scanComponent = 0; scanComponent < numComponents; scanComponent++)
         {
             // Determine which huffman table we will be writing to
@@ -420,6 +444,7 @@ MOS_STATUS JpegDecodePicPkt::AddAllCmds_MFD_JPEG_BSD_OBJECT(PMOS_COMMAND_BUFFER
     for (uint16_t scanCount = 0; scanCount < m_jpegBasicFeature->m_jpegScanParams->NumScans; scanCount++)
     {
         uint16_t numComponents = m_jpegBasicFeature->m_jpegScanParams->ScanHeader[scanCount].NumComponents;
+        MOS_ZeroMemory(&params, sizeof(params));
 
         params.indirectDataLength     = m_jpegBasicFeature->m_jpegScanParams->ScanHeader[scanCount].DataLength;
         params.dataStartAddress       = m_jpegBasicFeature->m_jpegScanParams->ScanHeader[scanCount].DataOffset;
