@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020, Intel Corporation
+* Copyright (c) 2020-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -41,6 +41,7 @@ DecodeMemComp::DecodeMemComp(CodechalHwInterfaceNext *hwInterface, PMOS_INTERFAC
     if (hwInterface == nullptr)
     {
         CODEC_HW_ASSERT(hwInterface);
+        return;
     }
     else
     {
@@ -71,6 +72,19 @@ MOS_STATUS DecodeMemComp::UpdateUserFeatureKey(PMOS_SURFACE surface)
 
     return MOS_STATUS_SUCCESS;
 }
+
+MOS_STATUS DecodeMemComp::ReportSurfaceMmcMode(PMOS_SURFACE surface)
+{
+    if (!surface)
+        return MOS_STATUS_NULL_POINTER;
+
+    MOS_MEMCOMP_STATE mmcMode = MOS_MEMCOMP_DISABLED;
+    MediaMemComp::GetSurfaceMmcState(surface, &mmcMode);
+
+    DECODE_NORMALMESSAGE("Decode RT Compress Mode is: %d", mmcMode);
+
+    return MOS_STATUS_SUCCESS;
+}
 #endif
 
 void DecodeMemComp::InitDecodeMmc(CodechalHwInterfaceNext *hwInterface)
@@ -91,12 +105,6 @@ void DecodeMemComp::InitDecodeMmc(CodechalHwInterfaceNext *hwInterface)
 
         m_mmcEnabledForDecode = m_mmcEnabled && decodeMmcEnabled;
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (m_mmcEnabledForDecode)
-    {
-        MOS_TraceEvent(EVENT_DECODE_FEATURE_MMC, EVENT_TYPE_INFO, NULL, 0, NULL, 0);
-    }
-#endif
         MOS_USER_FEATURE_VALUE_WRITE_DATA userFeatureWriteData;
         MOS_ZeroMemory(&userFeatureWriteData, sizeof(userFeatureWriteData));
         userFeatureWriteData.Value.i32Data = m_mmcEnabledForDecode;
