@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2020, Intel Corporation
+* Copyright (c) 2018-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -30,7 +30,7 @@
 
 #include "media_pipeline.h"
 
-#include "codechal_hw.h"
+#include "codec_hw_next.h"
 #include "codechal_debug.h"
 #include "codec_def_decode.h"
 #include "decode_allocator.h"
@@ -41,26 +41,10 @@
 #include "decode_cp_bitstream.h"
 #include "decode_mem_compression.h"
 #include "decode_downsampling_feature.h"
+#include "codechal_oca_debug.h"
 
 namespace decode {
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    typedef struct _DECODE_EVENTDATA_YUV_SURFACE_INFO
-    {
-        uint32_t PicFlags;
-        uint32_t dwOffset;
-        int32_t  YPlaneOffset_iYOffset;
-        uint32_t dwPitch;
-        uint32_t dwWidth;
-        uint32_t dwHeight;
-        uint32_t Format;
-        int32_t  UPlaneOffset_iLockSurfaceOffset;
-        int32_t  VPlaneOffset_iLockSurfaceOffset;
-        int32_t  UPlaneOffset_iSurfaceOffset;
-        int32_t  VPlaneOffset_iSurfaceOffset;
-    } DECODE_EVENTDATA_YUV_SURFACE_INFO;
-#endif
-
 enum DecodePipeMode
 {
     decodePipeModeBegin = 0,
@@ -88,10 +72,13 @@ public:
     //!         Pointer to CodechalDebugInterface
     //!
     DecodePipeline(
-        CodechalHwInterface *   hwInterface,
+        CodechalHwInterfaceNext *hwInterface,
         CodechalDebugInterface *debugInterface);
 
-    virtual ~DecodePipeline() { };
+    virtual ~DecodePipeline()
+    {
+        MOS_Delete(m_pCodechalOcaDumper);
+    };
 
     //!
     //! \brief  Prepare interal parameters, should be invoked for each frame
@@ -149,7 +136,7 @@ public:
     //! \return CodechalHwInterface *
     //!         pointer of m_hwInterface
     //!
-    CodechalHwInterface *GetHwInterface() const { return m_hwInterface; }
+    CodechalHwInterfaceNext *GetHwInterface() const { return m_hwInterface; }
 
     //!
     //! \brief    Help function to get pipe number
@@ -244,9 +231,9 @@ public:
     //!
     //! \return   True if guc submission mode, otherwise return false
     //!
-    virtual bool IsGucSubmission()
+    virtual bool IsParallelSubmission()
     {
-        return m_osInterface->bGucSubmission;
+        return m_osInterface->bParallelSubmission;
     }
 
 #ifdef _DECODE_PROCESSING_SUPPORTED
@@ -304,6 +291,12 @@ public:
     //! \return decode context
     //!
     MOS_GPU_CONTEXT GetDecodeContext() { return m_decodeContext; }
+
+    //!
+    //! \brief  Get decode context handle
+    //! \return decode context handle
+    //!
+    GPU_CONTEXT_HANDLE GetDecodeContextHandle() { return m_decodeContextHandle; }
     
     //!
     //! \brief  Indicates whether current process pipe is first process pipe of current frame
@@ -312,6 +305,20 @@ public:
     //!
     bool IsFirstProcessPipe(const DecodePipelineParams &pipelineParams);
 
+    //!
+    //! \brief    Gets oca dump interface.
+    //! \return   CodechalOcaDumper
+    //!           return oca debug interface
+    //!
+    CodechalOcaDumper *GetCodechalOcaDumper() { return m_pCodechalOcaDumper; }
+
+    //!
+    //! \brief    Set decode short/long format during runtime.
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS SetDecodeFormat(bool isShortFormat ){ return MOS_STATUS_UNIMPLEMENTED; };
+
 protected:
     //!
     //! \brief  Initialize the decode pipeline
@@ -373,7 +380,7 @@ protected:
     //! \return MOS_STATUS
     //!         MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    MOS_STATUS CreatePostSubPipeLines(DecodeSubPipelineManager &subPipelineManager);
+    virtual MOS_STATUS CreatePostSubPipeLines(DecodeSubPipelineManager &subPipelineManager);
 
     //!
     //! \brief  Create sub packets
@@ -385,13 +392,37 @@ protected:
     //!         MOS_STATUS_SUCCESS if success, else fail reason
     //!
     virtual MOS_STATUS CreateSubPackets(DecodeSubPacketManager& subPacketManager, CodechalSetting &codecSettings);
-
+    //!
+    //! \brief  Declare Regkeys in the scope of decode
+    //! \return MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    virtual MOS_STATUS InitUserSetting(MediaUserSettingSharedPtr userSettingPtr) override;
 
 #if USE_CODECHAL_DEBUG_TOOL
 #ifdef _DECODE_PROCESSING_SUPPORTED
     MOS_STATUS DumpDownSamplingParams(DecodeDownSamplingFeature &downSamplingParams);
 #endif
 
+    //!
+    //! \brief  Dump Bitstream
+    //! \param  [in] pBitstream
+    //!         Bitstream Resource
+    //! \param  [in] size
+    //!         Bitstream Size
+    //! \param  [in] offset
+    //!         Bitstream Offset 
+    //! \return MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS DumpBitstream(PMOS_RESOURCE pBitstream, uint32_t size, uint32_t offset);
+
+    //!
+    //! \brief  Add delay for dump render targets
+    //! \return MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS DelayForDumpOutput();
+
     //!
     //! \brief  Dump render targets
     //! \param  [in] reportData
@@ -402,11 +433,6 @@ protected:
     virtual MOS_STATUS DumpOutput(const DecodeStatusReportData& reportData);
 #endif
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    MOS_STATUS TraceDataDumpOutput(const DecodeStatusReportData &reportData);
-    MOS_STATUS TraceDataDump2ndLevelBB(PMHW_BATCH_BUFFER batchBuffer);
-#endif
-
 #if (_DEBUG || _RELEASE_INTERNAL)
     //!
     //! \brief  User feature key report for Vdbox IDs
@@ -448,7 +474,7 @@ protected:
     MOS_STATUS StatusCheck();
 #endif
 
-private:
+protected:
     //!
     //! \brief  Create sub pipeline manager
     //! \param  [in] codecSettings
@@ -467,10 +493,10 @@ private:
     //!
     MOS_STATUS CreateSubPacketManager(CodechalSetting* codecSettings);
 
-protected:
     friend class DecodeSubPipelineManager;
 
-    CodechalHwInterface*    m_hwInterface    = nullptr; //!< Codechal HwInterface
+    CodechalHwInterfaceNext *m_hwInterface        = nullptr;  //!< Codechal HwInterface
+    CodechalOcaDumper      *m_pCodechalOcaDumper = nullptr;
     CodechalDebugInterface* m_debugInterface = nullptr; //!< Debug Interface
     MediaTask *             m_task           = nullptr; //!< Command task
 
@@ -491,14 +517,16 @@ protected:
     bool                    m_singleTaskPhaseSupported = true; //!< Indicates whether sumbit packets in single phase
 
     MOS_GPU_CONTEXT         m_decodeContext = MOS_GPU_CONTEXT_INVALID_HANDLE;    //!< decode context inuse
+    GPU_CONTEXT_HANDLE      m_decodeContextHandle = MOS_GPU_CONTEXT_INVALID_HANDLE;    //!< handle of decode context inuse
 
 #if (_DEBUG || _RELEASE_INTERNAL)
     uint32_t                m_statusCheckCount = 0;     //!< count for status check
+    uint32_t                m_delayMiliseconds = 0;     //!< miliseconds delay after each frame
 #endif
 
     PMOS_SURFACE            m_tempOutputSurf = nullptr;
 
-MEDIA_CLASS_DEFINE_END(DecodePipeline)
+MEDIA_CLASS_DEFINE_END(decode__DecodePipeline)
 };
 
 }//decode
