@@ -28,7 +28,7 @@
 
 #include "media_feature.h"
 #include "encode_allocator.h"
-#include "codechal_hw.h"
+#include "codec_hw_next.h"
 #include "encode_basic_feature.h"
 
 namespace encode
@@ -36,7 +36,7 @@ namespace encode
 class HevcEncodeCqp : public MediaFeature, public mhw::vdbox::hcp::Itf::ParSetting
 {
 public:
-    HevcEncodeCqp(MediaFeatureManager *featureManager, EncodeAllocator *allocator, CodechalHwInterface *hwInterface, void *constSettings);
+    HevcEncodeCqp(MediaFeatureManager *featureManager, EncodeAllocator *allocator, CodechalHwInterfaceNext *hwInterface, void *constSettings);
 
     ~HevcEncodeCqp() {}
 
@@ -137,7 +137,7 @@ protected:
     uint16_t m_rdoqIntraTuThresholdOverride = 0;      //!< Override RDOQ intra TU threshold
 #endif
 
-MEDIA_CLASS_DEFINE_END(HevcEncodeCqp)
+MEDIA_CLASS_DEFINE_END(encode__HevcEncodeCqp)
 };
 
 }  // namespace encode
