@@ -454,7 +454,16 @@ namespace encode
         m_hevcSliceParams = static_cast<PCODEC_HEVC_ENCODE_SLICE_PARAMS>(encodeParams->pSliceParams);
         ENCODE_CHK_STATUS_RETURN(SetupForceIntraStreamIn());
 
-        m_numValidLaRecords++;
+        if (!m_lastPicInStream)
+        {
+            m_numValidLaRecords++;
+        }
+
+        if (m_lastPicInStream && m_bLastPicFlagFirstIn)
+        {
+            m_currLaDataIdx -= 1;
+            m_bLastPicFlagFirstIn = false;
+        }
 
         return eStatus;
     }
@@ -479,32 +488,6 @@ namespace encode
             encodeStatusMfx->lookaheadStatus.targetFrameSize = (uint32_t)((targetFrameSize + (32 * 8)) / (64 * 8));  // Convert bits to bytes. 64 is normalized average frame size used in lookahead analysis kernel
             uint64_t targetBufferFulness = (uint64_t)encodeStatusMfx->lookaheadStatus.targetBufferFulness * m_averageFrameSize;
             encodeStatusMfx->lookaheadStatus.targetBufferFulness = (uint32_t)((targetBufferFulness + 32) / 64);  // 64 is normalized average frame size used in lookahead analysis kernel
-            // Apply rounding error to targetFrameSize to align target buffer fullness between lookahead pass and encode pass
-            if (m_prevTargetFrameSize > 0)
-            {
-                int64_t encTargetBufferFulness = (int64_t)m_targetBufferFulness;
-                encTargetBufferFulness += (int64_t)(m_prevTargetFrameSize << 3) - (int64_t)m_averageFrameSize;
-                m_targetBufferFulness = encTargetBufferFulness < 0 ? 0 : (encTargetBufferFulness > 0xFFFFFFFF ? 0xFFFFFFFF : (uint32_t)encTargetBufferFulness);
-                int32_t deltaBits     = (int32_t)((int64_t)(encodeStatusMfx->lookaheadStatus.targetBufferFulness) + m_bufferFulnessError - (int64_t)(m_targetBufferFulness));
-                deltaBits /= 64;
-                if (deltaBits > 8)
-                {
-                    if ((uint32_t)deltaBits > encodeStatusMfx->lookaheadStatus.targetFrameSize)
-                    {
-                        deltaBits = (int32_t)(encodeStatusMfx->lookaheadStatus.targetFrameSize);
-                    }
-                    encodeStatusMfx->lookaheadStatus.targetFrameSize += (uint32_t)(deltaBits >> 3);
-                }
-                else if (deltaBits < -8)
-                {
-                    if ((-deltaBits) > (int32_t)(encodeStatusMfx->lookaheadStatus.targetFrameSize))
-                    {
-                        deltaBits = -(int32_t)(encodeStatusMfx->lookaheadStatus.targetFrameSize);
-                    }
-                    encodeStatusMfx->lookaheadStatus.targetFrameSize -= (uint32_t)((-deltaBits) >> 3);
-                }
-            }
-            m_prevTargetFrameSize = encodeStatusMfx->lookaheadStatus.targetFrameSize;
 
             if (encodeStatusMfx->lookaheadStatus.miniGopSize == 2)
             {
@@ -807,7 +790,10 @@ namespace encode
         ENCODE_FUNC_CALL();
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-        m_currLaDataIdx  = (m_currLaDataIdx + 1) % m_numLaDataEntry;
+        if (!m_lastPicInStream)
+        {
+            m_currLaDataIdx = (m_currLaDataIdx + 1) % m_numLaDataEntry;
+        }
 
         return eStatus;
     }
@@ -820,7 +806,7 @@ namespace encode
         // Setup LAInit DMEM
         auto hucVdencLaInitDmem = (VdencHevcHucLaDmem *)m_allocator->LockResourceForWrite(m_vdencLaInitDmemBuffer);
         ENCODE_CHK_NULL_RETURN(hucVdencLaInitDmem);
-        MOS_ZeroMemory(hucVdencLaInitDmem, sizeof(hucVdencLaInitDmem));
+        MOS_ZeroMemory(hucVdencLaInitDmem, sizeof(VdencHevcHucLaDmem));
 
         uint32_t initVbvFullness = MOS_MIN(m_hevcSeqParams->InitVBVBufferFullnessInBit, m_hevcSeqParams->VBVBufferSizeInBit);
         uint8_t downscaleRatioIndicator = 2;  // 4x downscaling
@@ -877,7 +863,7 @@ namespace encode
         // Setup LAUpdate DMEM
         auto hucVdencLaUpdateDmem = (VdencHevcHucLaDmem *)m_allocator->LockResourceForWrite(m_vdencLaUpdateDmemBuffer[currRecycledBufIdx][curPass]);
         ENCODE_CHK_NULL_RETURN(hucVdencLaUpdateDmem);
-        MOS_ZeroMemory(hucVdencLaUpdateDmem, sizeof(hucVdencLaUpdateDmem));
+        MOS_ZeroMemory(hucVdencLaUpdateDmem, sizeof(VdencHevcHucLaDmem));
 
         hucVdencLaUpdateDmem->lookAheadFunc = 1;
         hucVdencLaUpdateDmem->validStatsRecords = numValidLaRecords;
@@ -927,7 +913,8 @@ namespace encode
     {
         ENCODE_FUNC_CALL();
 
-        if (blastPass && m_numValidLaRecords >= m_lookaheadDepth)
+        if ((blastPass && m_numValidLaRecords >= m_lookaheadDepth) ||
+            (m_lastPicInStream && m_numValidLaRecords))
         {
             m_numValidLaRecords--;
             m_lookaheadReport = true;
