@@ -30,11 +30,10 @@
 namespace encode {
 
 HevcPipeline::HevcPipeline(
-    CodechalHwInterface *   hwInterface,
+    CodechalHwInterfaceNext *   hwInterface,
     CodechalDebugInterface *debugInterface)
     : EncodePipeline(hwInterface, debugInterface)
 {
-
 }
 
 MOS_STATUS HevcPipeline::Initialize(void *settings)
@@ -42,6 +41,10 @@ MOS_STATUS HevcPipeline::Initialize(void *settings)
     ENCODE_FUNC_CALL();
     ENCODE_CHK_STATUS_RETURN(EncodePipeline::Initialize(settings));
 
+#if MHW_HWCMDPARSER_ENABLED
+    mhw::HwcmdParser::InitInstance(m_osInterface, mhw::HwcmdParser::AddOnMode::HEVCe);
+#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -56,17 +59,18 @@ MOS_STATUS HevcPipeline::UserFeatureReport()
     ENCODE_FUNC_CALL();
     ENCODE_CHK_STATUS_RETURN(EncodePipeline::UserFeatureReport());
 
-#if (_DEBUG || _RELEASE_INTERNAL)
     ReportUserSetting(
         m_userSettingPtr,
         "HEVC Encode Mode",
         m_codecFunction,
         MediaUserSetting::Group::Sequence);
+
+#if (_DEBUG || _RELEASE_INTERNAL)
     ReportUserSettingForDebug(
         m_userSettingPtr,
-        "Simulation In Use",
+        __MEDIA_USER_FEATURE_VALUE_SIM_IN_USE,
         m_osInterface->bSimIsActive,
-        MediaUserSetting::Group::Sequence);
+        MediaUserSetting::Group::Device);
 #endif
 
     return MOS_STATUS_SUCCESS;
@@ -88,20 +92,44 @@ MOS_STATUS HevcPipeline::Prepare(void *params)
         m_debugInterface->m_frameType          = basicFeature->m_pictureCodingType;
 
         if (basicFeature->m_newSeq) {
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(DumpSeqParams(
+            ENCODE_CHK_STATUS_RETURN(DumpSeqParams(
                 basicFeature->m_hevcSeqParams));
         }
         
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(DumpPicParams(
+        ENCODE_CHK_STATUS_RETURN(DumpPicParams(
             basicFeature->m_hevcPicParams));
         
         for (uint32_t i = 0; i < basicFeature->m_numSlices; i++) {
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(DumpSliceParams(
+            ENCODE_CHK_STATUS_RETURN(DumpSliceParams(
                 &basicFeature->m_hevcSliceParams[i],
                 basicFeature->m_hevcPicParams));
         }
     )
 
+#if MHW_HWCMDPARSER_ENABLED
+    {
+        char frameType;
+        switch (basicFeature->m_hevcPicParams->CodingType)
+        {
+        case I_TYPE:
+            frameType = 'I';
+            break;
+        case P_TYPE:
+            frameType = 'P';
+            break;
+        case B_TYPE:
+            frameType = basicFeature->m_hevcSeqParams->LowDelayMode ? 'G' : 'B';
+            break;
+        }
+
+        auto instance = mhw::HwcmdParser::GetInstance();
+        if (instance)
+        {
+            instance->Update(frameType, (void *)m_featureManager);
+        }
+    }
+#endif
+
     return MOS_STATUS_SUCCESS;
 }
 
