@@ -321,6 +321,7 @@ struct _MHW_PAR_T(GPGPU_CSR_BASE_ADDRESS)
 
 struct _MHW_PAR_T(_3DSTATE_BINDING_TABLE_POOL_ALLOC)
 {
+    uint32_t mocs4SurfaceState = 0;
 };
 
 struct _MHW_PAR_T(CFE_STATE)
@@ -370,6 +371,7 @@ struct _MHW_PAR_T(COMPUTE_WALKER)
     bool                      bGlobalBarrierEnable          = false;   //! Enable Global Barrier (SKL+)
     uint32_t                  dwNumberofThreadsInGPGPUGroup = 0;       //! Number of threads per group
     uint32_t                  dwSharedLocalMemorySize       = 0;       //! Size of SharedLocalMemory (SLM)
+    int32_t                   forcePreferredSLMZero         = 0;       //! force preferredSLM value as 0
     int32_t                   iCrsThdConDataRdLn            = 0;
     PMHW_STATE_HEAP           pGeneralStateHeap             = 0;       //! General state heap in use
     MemoryBlock               *memoryBlock                  = nullptr; //! Memory block associated with the state heap
