@@ -68,24 +68,18 @@ public:
         m_indexofSfc              = 0;
         m_numofSfc                = 1;
 
-        if (osItf == nullptr)
-        {
-            MHW_ASSERTMESSAGE("Invalid Input Parameter: m_osInterface is nullptr");
-            return;
-        }
-
         // Get Memory control object directly from MOS.
         // If any override is needed, something like pfnOverrideMemoryObjectCtrl() / pfnComposeSurfaceCacheabilityControl()
         // will need to be implemented.
         m_outputSurfCtrl.Value = osItf->pfnCachePolicyGetMemoryObject(
-            MOS_MHW_RESOURCE_USAGE_Sfc_CurrentOutputSurface,
+            MOS_HW_RESOURCE_USAGE_VP_OUTPUT_PICTURE_FF,
             osItf->pfnGetGmmClientContext(osItf)).DwordValue;
 
         m_avsLineBufferCtrl.Value = osItf->pfnCachePolicyGetMemoryObject(
-            MOS_MHW_RESOURCE_USAGE_Sfc_AvsLineBufferSurface,
+            MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_FF,
             osItf->pfnGetGmmClientContext(osItf)).DwordValue;
         m_iefLineBufferCtrl.Value = osItf->pfnCachePolicyGetMemoryObject(
-            MOS_MHW_RESOURCE_USAGE_Sfc_IefLineBufferSurface,
+            MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_FF,
             osItf->pfnGetGmmClientContext(osItf)).DwordValue;
 
         m_sfdLineBufferCtrl.Value = osItf->pfnCachePolicyGetMemoryObject(
@@ -224,7 +218,7 @@ public:
         uint32_t &heightAlignUnit,
         bool bVdbox,
         CODECHAL_STANDARD codecStandard,
-        CodecDecodeJpegChromaType jpegChromaType)
+        CodecDecodeJpegChromaType jpegChromaType) override
     {
         if (bVdbox)
         {
@@ -264,12 +258,47 @@ public:
     }
 
     MOS_STATUS SetSfcAVSScalingMode(
-        MHW_SCALING_MODE ScalingMode)
+        MHW_SCALING_MODE ScalingMode) override
     {
         m_scalingMode = ScalingMode;
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS GetInputMinWidthHeightInfo(uint32_t &width, uint32_t &height) override
+    {
+        width  = m_inputMinWidth;
+        height = m_inputMinHeight;
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MOS_STATUS GetOutputMinWidthHeightInfo(uint32_t &width, uint32_t &height) override
+    {
+        width  = m_outputMinWidth;
+        height = m_outputMinHeight;
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MOS_STATUS GetMinWidthHeightInfo(uint32_t &width, uint32_t &height) override
+    {
+        width = m_minWidth;
+        height = m_minHeight;
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MOS_STATUS GetMaxWidthHeightInfo(uint32_t &width, uint32_t &height) override
+    {
+        width  = m_maxWidth;
+        height = m_maxHeight;
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MOS_STATUS GetScalingRatioLimit(float &minScalingRatio, float &maxScalingRatio) override
+    {
+        minScalingRatio = m_minScalingRatio;
+        maxScalingRatio = m_maxScalingRatio;
+        return MOS_STATUS_SUCCESS;
+    }
+
     MOS_STATUS SetSfcSamplerTable(
         SFC_AVS_LUMA_Coeff_Table_PAR   *pLumaTable,
         SFC_AVS_CHROMA_Coeff_Table_PAR *pChromaTable,
@@ -280,8 +309,10 @@ public:
         uint32_t                  dwChromaSiting,
         bool                      bUse8x8Filter,
         float                     fHPStrength,
-        float                     fLanczosT)
+        float                     fLanczosT) override
     {
+        MHW_FUNCTION_ENTER;
+
         int32_t * piYCoefsX, *piYCoefsY;
         int32_t * piUVCoefsX, *piUVCoefsY;
         MHW_PLANE Plane;
@@ -301,6 +332,8 @@ public:
             fScaleX == pAvsParams->fScaleX &&
             fScaleY == pAvsParams->fScaleY)
         {
+            MHW_NORMALMESSAGE("Skip calculation since no changes to AVS parameters. srcFormat %d, fScaleX %f, fScaleY %f",
+                srcFormat, fScaleX, fScaleY);
             return MOS_STATUS_SUCCESS;
         }
 
@@ -318,6 +351,9 @@ public:
             pAvsParams->fScaleY = fScaleY;
         }
 
+        MHW_NORMALMESSAGE("srcFormat %d, pAvsParams->Format %d, fScaleX %f, fScaleY %f, pAvsParams->fScaleX %f, pAvsParams->fScaleY %f, pAvsParams->bUse8x8Filter %d, bUse8x8Filter %d, m_scalingMode %d, bForcePolyPhaseCoefs %d",
+            srcFormat, pAvsParams->Format, fScaleX, fScaleY, pAvsParams->fScaleX, pAvsParams->fScaleY, pAvsParams->bUse8x8Filter, bUse8x8Filter, m_scalingMode, (pAvsParams->bForcePolyPhaseCoefs ? 1 : 0));
+
         // Recalculate Horizontal scaling table
         if (srcFormat != pAvsParams->Format || fScaleX != pAvsParams->fScaleX || pAvsParams->bUse8x8Filter != bUse8x8Filter)
         {
@@ -518,7 +554,7 @@ public:
     //!           MOS_STATUS_SUCCESS if success, else fail reason
     MOS_STATUS SetSfcIndex(
         uint32_t dwSfcIndex,
-        uint32_t dwSfcCount)
+        uint32_t dwSfcCount) override
     {
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
@@ -531,7 +567,7 @@ public:
         return eStatus;
     }
 
-    void IsOutPutCenterEnable(bool inputEnable)
+    void IsOutPutCenterEnable(bool inputEnable) override
     {
         m_outputCenteringEnable = inputEnable;
     }
@@ -697,6 +733,10 @@ protected:
     uint32_t                           m_maxHeight             = MHW_SFC_MAX_HEIGHT;
     uint32_t                           m_minWidth              = MHW_SFC_MIN_WIDTH;
     uint32_t                           m_minHeight             = MHW_SFC_MIN_HEIGHT;
+    uint32_t                           m_inputMinWidth         = MHW_SFC_MIN_WIDTH;             // SFC input min width size for ve+sfc
+    uint32_t                           m_inputMinHeight        = MHW_SFC_MIN_HEIGHT;            // SFC input min height size for ve+sfc
+    uint32_t                           m_outputMinWidth        = MHW_SFC_OUTPUT_MIN_WIDTH;      // SFC output min width size for ve+sfc
+    uint32_t                           m_outputMinHeight       = MHW_SFC_OUTPUT_MIN_HEIGHT;     // SFC output min height size for ve+sfc
 
     float                              m_maxScalingRatio       = MHW_SFC_MAX_SCALINGFACTOR;
     float                              m_minScalingRatio       = MHW_SFC_MIN_SCALINGFACTOR;
