@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2022, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -404,6 +404,27 @@ protected:
         SetCacheabilitySettings();
     }
 
+    virtual ~Impl()
+    {
+        MHW_FUNCTION_ENTER;
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+        if (m_intraRowstoreCache.enabled ||
+            m_deblockingFilterRowstoreCache.enabled ||
+            m_bsdMpcRowstoreCache.enabled ||
+            m_mprRowstoreCache.enabled)
+        {
+            // Report rowstore cache usage status to regkey
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_IS_CODEC_ROW_STORE_CACHE_ENABLED,
+                1,
+                MediaUserSetting::Group::Device);
+        }
+#endif
+
+    }
+
     MOS_STATUS InitRowstoreUserFeatureSettings()
     {
         MHW_FUNCTION_ENTER;
@@ -1228,14 +1249,10 @@ protected:
         }
         else
         {
-            for (auto i = 0, j = 0; i < (CODEC_MAX_NUM_REF_FRAME / 2); i++, j++)
-            {
-                cmd.Viewidlist1616Bits[i] = 0;
-            }
-        }
-        for (auto i = 0, j = 0; i < (CODEC_MAX_NUM_REF_FRAME / 4); i++, j++)
-        {
-            cmd.Vieworderlistl1168Bits[i] = 0;  //FirstEntry
+            // non-MVC usage
+            MOS_ZeroMemory(cmd.Viewidlist1616Bits, sizeof(cmd.Viewidlist1616Bits));
+            MOS_FillMemory(cmd.Vieworderlistl0168Bits, sizeof(cmd.Vieworderlistl0168Bits), 0xF);
+            MOS_FillMemory(cmd.Vieworderlistl1168Bits, sizeof(cmd.Vieworderlistl1168Bits), 0xF);
         }
 
         #define DO_FIELDS()                                                               \
@@ -1329,13 +1346,12 @@ protected:
 
         auto MBType = params.pMBParams->MBType;
         
-        #define DO_FIELDS()                                              \
-            DO_FIELD(DW0, MacroblockIntraType, 1);                       \
-            DO_FIELD(DW0, DctType, MBType.m_fieldResidual);              \
-            DO_FIELD(DW0, CodedBlockPattern, params.CodedBlockPattern);  \
-            DO_FIELD(DW1, Horzorigin, params.Horzorigin);                \
-            DO_FIELD(DW1, Vertorigin, params.Vertorigin);                \
-            DO_FIELD(DW0, Lastmbinrow, params.Lastmbinrow);
+        cmd.DW0.MacroblockIntraType = 1;
+        cmd.DW0.DctType             = MBType.m_fieldResidual;
+        cmd.DW0.CodedBlockPattern   = params.CodedBlockPattern;
+        cmd.DW0.Lastmbinrow         = params.Lastmbinrow;
+        cmd.DW1.Horzorigin          = params.Horzorigin;
+        cmd.DW1.Vertorigin          = params.Vertorigin;
 
         if (params.CodingType != I_TYPE)
         {
@@ -1349,18 +1365,12 @@ protected:
             if (MBType.m_intraMb == 0)
             {
                 uint32_t *point = (uint32_t *)(params.sPackedMVs0);
-
-                cmd.DW2.MotionVectorsField0ForwardHorizontalComponent  = *point++;
-                cmd.DW2.MotionVectorsField0ForwardVerticalComponent    = *point++;
-                cmd.DW3.MotionVectorsField0BackwardHorizontalComponent = *point++;
-                cmd.DW3.MotionVectorsField0BackwardVerticalComponent   = *point++;
+                cmd.DW2.Value   = *point++;
+                cmd.DW3.Value   = *point++;
 
                 point = (uint32_t *)(params.sPackedMVs1);
-
-                cmd.DW4.MotionVectorsField1ForwardHorizontalComponent  = *point++;
-                cmd.DW4.MotionVectorsField1ForwardVerticalComponent    = *point++;
-                cmd.DW5.MotionVectorsField1BackwardHorizontalComponent = *point++;
-                cmd.DW5.MotionVectorsField1BackwardVerticalComponent   = *point++;
+                cmd.DW4.Value = *point++;
+                cmd.DW5.Value = *point++;
             }
         }
 
