@@ -43,9 +43,6 @@ extern MhwCpInterface* Create_MhwCpInterface(PMOS_INTERFACE osInterface);
 extern void Delete_MhwCpInterface(MhwCpInterface* mhwInterface);
 
 #if !EMUL
-extern CpCopyInterface* Create_CpCopyInterface(MOS_CONTEXT_HANDLE osDriverContext, MOS_STATUS& status);
-extern void Delete_CpCopyInterface(CpCopyInterface* cpCopyInterface);
-
 extern CodechalSecureDecodeInterface* Create_SecureDecodeInterface(CodechalSetting* codechalSettings, CodechalHwInterface* hwInterfaceInput);
 extern void Delete_SecureDecodeInterface(CodechalSecureDecodeInterface* codechalSecureDecodeInterface);
 #endif
@@ -657,19 +654,19 @@ MOS_STATUS Mos_InitOsInterface(
     pOsInterface->pfnGetResourceHandle                  = Mos_GetResourceHandle;
     pOsInterface->pfnGetRtLogResourceInfo               = Mos_GetRtLogResourceInfo;
     pOsInterface->pfnResetResource                      = Mos_ResetMosResource;
+    pOsInterface->pfnVerifyMosSurface                   = Mos_VerifyMosSurface;
 
     pOsInterface->pfnCreateMhwCpInterface               = Create_MhwCpInterface;
     pOsInterface->pfnDeleteMhwCpInterface               = Delete_MhwCpInterface;
-#if !EMUL
-    pOsInterface->pfnCreateCpCopyInterface              = Create_CpCopyInterface;
-    pOsInterface->pfnDeleteCpCopyInterface              = Delete_CpCopyInterface;
 
+#if !EMUL
     pOsInterface->pfnCreateSecureDecodeInterface        = Create_SecureDecodeInterface;
     pOsInterface->pfnDeleteSecureDecodeInterface        = Delete_SecureDecodeInterface;
 #endif
 #if (_DEBUG || _RELEASE_INTERNAL)
     pOsInterface->pfnGetVeEngineCount                   = Mos_GetVeEngineCount;
     pOsInterface->pfnGetEngineLogicIdByIdx              = Mos_GetEngineLogicId;
+    pOsInterface->pfnSetGpuVirtualAddress               = MOS_SetGpuVirtualAddress;
 #endif
 
     pOsInterface->Component                 = component;
@@ -912,12 +909,6 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
             MediaUserSetting::Group::Device);
         osInterface->bSupportVirtualEngine = value ? true : false;
 #endif
-        // force bSupportVirtualEngine to false when virtual engine not enabled by default
-        if ((!veDefaultEnable || !osInterface->veDefaultEnable) &&
-            (eStatus == MOS_STATUS_USER_FEATURE_KEY_OPEN_FAILED))
-        {
-            osInterface->bSupportVirtualEngine = false;
-        }
 
         auto skuTable = osInterface->pfnGetSkuTable(osInterface);
         MOS_OS_CHK_NULL_RETURN(skuTable);
@@ -958,11 +949,6 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
             MediaUserSetting::Group::Device);
         osInterface->bSupportVirtualEngine = value ? true : false;
 #endif
-        // force bSupportVirtualEngine to false when virtual engine not enabled by default
-        if (!osInterface->veDefaultEnable && (eStatus == MOS_STATUS_USER_FEATURE_KEY_READ_FAILED || eStatus == MOS_STATUS_USER_FEATURE_KEY_OPEN_FAILED))
-        {
-            osInterface->bSupportVirtualEngine = false;
-        }
 
         auto skuTable = osInterface->pfnGetSkuTable(osInterface);
         MOS_OS_CHK_NULL_RETURN(skuTable);
@@ -1119,12 +1105,19 @@ uint64_t Mos_GetResourceHandle(
     return MosInterface::GetResourceHandle(streamState, osResource);
 }
 
+MOS_STATUS Mos_VerifyMosSurface(
+    PMOS_SURFACE            mosSurface,
+    bool&                   bIsValid)
+{
+    return MosInterface::VerifyMosSurface(mosSurface, bIsValid);
+}
+
 void Mos_GetRtLogResourceInfo(
-    MOS_STREAM_HANDLE       streamState,
+    PMOS_INTERFACE          osInterface,
     PMOS_RESOURCE           &osResource,
     uint32_t                &size)
 {
-    return MosInterface::GetRtLogResourceInfo(streamState, osResource, size);
+    return MosInterface::GetRtLogResourceInfo(osInterface, osResource, size);
 }
 
 void Mos_ResetMosResource(
@@ -1146,6 +1139,14 @@ uint8_t Mos_GetEngineLogicId(
 {
     return MosInterface::GetEngineLogicId(streamState, instanceIdx);
 }
+
+MOS_STATUS MOS_SetGpuVirtualAddress(
+    PMOS_RESOURCE          pResource,
+    uint64_t               address)
+{
+    return MosInterface::SetGpuVirtualAddress(pResource, address);
+}
+
 #endif
 
 void *MosStreamState::pvSoloContext = nullptr; 
