@@ -1450,7 +1450,7 @@ private:
     std::map<VP_COMPOSITE_PARAMS *, VP_COMPOSITE_PARAMS *> m_inuse;
     std::map<VP_COMPOSITE_PARAMS *, VP_COMPOSITE_PARAMS *> m_idle;
 
-MEDIA_CLASS_DEFINE_END(VpCompositeParamsPool)
+MEDIA_CLASS_DEFINE_END(vp__VpCompositeParamsPool)
 };
 
 }
