@@ -28,6 +28,7 @@
 #include "vp_platform_interface.h"
 #include <vector>
 #include <map>
+#include <set>
 
 class RenderCmdPacket;
 
@@ -62,14 +63,14 @@ typedef struct _KERNEL_SURFACE_STATE_PARAM
         MOS_TILE_TYPE                  tileType;
         bool                           bufferResource;
         bool                           bindedKernel;        // true if bind index is hardcoded by bindIndex.
-        uint32_t                       bindIndex;
         bool                           updatedRenderSurfaces; // true if renderSurfaceParams be used.
         RENDERHAL_SURFACE_STATE_PARAMS renderSurfaceParams;  // default can be skip. for future usages, if surface configed by kernel, use it directlly
     } surfaceOverwriteParams;
 
-    bool                                renderTarget;        // true for render target
+    bool                                isOutput;        // true for render target
     PRENDERHAL_SURFACE_STATE_ENTRY      *surfaceEntries;
     uint32_t                            *sizeOfSurfaceEntries;
+    uint32_t                             iCapcityOfSurfaceEntry = 0;
 } KERNEL_SURFACE_STATE_PARAM;
 
 using KERNEL_CONFIGS = std::map<VpKernelID, void *>; // Only for legacy/non-cm kernels
@@ -78,7 +79,7 @@ using KERNEL_SAMPLER_STATE_GROUP = std::map<SamplerIndex, MHW_SAMPLER_STATE_PARA
 using KERNEL_SAMPLER_STATES = std::vector<MHW_SAMPLER_STATE_PARAM>;
 using KERNEL_SAMPLER_INDEX = std::vector<SamplerIndex>;
 using KERNEL_SURFACE_CONFIG = std::map<SurfaceType, KERNEL_SURFACE_STATE_PARAM>;
-using KERNEL_SURFACE_BINDING_INDEX = std::map<SurfaceType, uint32_t>;
+using KERNEL_SURFACE_BINDING_INDEX = std::map<SurfaceType, std::set<uint32_t>>;
 
 typedef struct _KERNEL_PARAMS
 {
@@ -86,6 +87,7 @@ typedef struct _KERNEL_PARAMS
     KERNEL_ARGS          kernelArgs;
     KERNEL_THREAD_SPACE  kernelThreadSpace;
     bool                 syncFlag;
+    bool                 flushL1;
 } KERNEL_PARAMS;
 
 struct MEDIA_OBJECT_KA2_INLINE_DATA
@@ -350,6 +352,11 @@ public:
         return m_kernelId;
     }
 
+    DelayLoadedKernelType GetKernelType()
+    {
+        return m_kernelType;
+    }
+
     virtual bool IsKernelCached()
     {
         return false;
@@ -366,7 +373,8 @@ public:
         KERNEL_PARAMS& kernelParams,
         VP_SURFACE_GROUP& surfaces,
         KERNEL_SAMPLER_STATE_GROUP& samplerStateGroup,
-        KERNEL_CONFIGS& kernelConfigs);
+        KERNEL_CONFIGS& kernelConfigs,
+        VP_PACKET_SHARED_CONTEXT* sharedContext);
 
     virtual MOS_STATUS GetScoreboardParams(PMHW_VFE_SCOREBOARD &scoreboardParams)
     {
@@ -434,29 +442,29 @@ public:
         auto it = m_surfaceBindingIndex.find(surface);
         if (it != m_surfaceBindingIndex.end())
         {
-            it->second = index;
+            it->second.insert(index);
         }
         else
         {
-            m_surfaceBindingIndex.insert(std::make_pair(surface, index));
+            std::set<uint32_t> bindingMap;
+            bindingMap.insert(index);
+            m_surfaceBindingIndex.insert(std::make_pair(surface, bindingMap));
         }
 
         return MOS_STATUS_SUCCESS;
     }
 
-    uint32_t GetSurfaceBindingIndex(SurfaceType surface)
+    std::set<uint32_t>& GetSurfaceBindingIndex(SurfaceType surface)
     {
         auto it = m_surfaceBindingIndex.find(surface);
 
-        if (it != m_surfaceBindingIndex.end())
-        {
-            return it->second;
-        }
-        else
+        if (it == m_surfaceBindingIndex.end())
         {
             VP_RENDER_ASSERTMESSAGE("No surface index created for current surface");
-            return 0;
+            std::set<uint32_t> bindingMap;
+            it = m_surfaceBindingIndex.insert(std::make_pair(surface, bindingMap)).first;
         }
+        return it->second;
     }
 
     MOS_STATUS InitKernel(void* binary, uint32_t size, KERNEL_CONFIGS& kernelConfigs,
@@ -479,6 +487,11 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    virtual MOS_STATUS SetPerfTag()
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
     virtual MOS_STATUS InitRenderHalSurface(
         SurfaceType             type,
         VP_SURFACE              *surf,
@@ -491,20 +504,17 @@ public:
 
 protected:
 
-    virtual MOS_STATUS SetWalkerSetting(KERNEL_THREAD_SPACE& threadSpace, bool bSyncFlag);
+    virtual MOS_STATUS SetWalkerSetting(KERNEL_THREAD_SPACE &threadSpace, bool bSyncFlag, bool flushL1 = false);
 
-    virtual MOS_STATUS SetKernelArgs(KERNEL_ARGS& kernelArgs);
+    virtual MOS_STATUS SetKernelArgs(KERNEL_ARGS &kernelArgs, VP_PACKET_SHARED_CONTEXT *sharedContext);
 
     virtual MOS_STATUS SetupSurfaceState() = 0;
 
     virtual MOS_STATUS SetKernelConfigs(KERNEL_CONFIGS& kernelConfigs);
 
-    MOS_STATUS SetProcessSurfaceGroup(VP_SURFACE_GROUP& surfaces)
-    {
-        m_surfaceGroup = &surfaces;
-        VP_RENDER_CHK_STATUS_RETURN(SetupSurfaceState());
-        return MOS_STATUS_SUCCESS;
-    }
+    virtual MOS_STATUS SetProcessSurfaceGroup(VP_SURFACE_GROUP &surfaces);
+
+    virtual MOS_STATUS CpPrepareResources();
 
     virtual MOS_STATUS GetCurbeState(void *&curbe, uint32_t &curbeLength) = 0;
 
@@ -521,6 +531,7 @@ protected:
     KERNEL_SURFACE_CONFIG                                   m_surfaceState;             // surfaces processed pool where the surface state will generated here, if KERNEL_SURFACE_STATE_PARAM 
     KERNEL_SURFACE_BINDING_INDEX                            m_surfaceBindingIndex;      // store the binding index for processed surface
     PVpAllocator                                            m_allocator = nullptr;
+    MediaUserSettingSharedPtr                               m_userSettingPtr = nullptr;  // usersettingInstance
 
     // kernel attribute 
     std::string                                             m_kernelName = "";
@@ -528,11 +539,14 @@ protected:
     uint32_t                                                m_kernelBinaryID = 0;
     uint32_t                                                m_kernelSize = 0;
     VpKernelID                                              m_kernelId = kernelCombinedFc;
+    DelayLoadedKernelType                                   m_kernelType     = KernelNone;
     KernelIndex                                             m_kernelIndex = 0;          // index of current kernel in KERNEL_PARAMS_LIST
 
     bool                                                    m_isAdvKernel = false;      // true mean multi kernel can be submitted in one workload.
 
-MEDIA_CLASS_DEFINE_END(VpRenderKernelObj)
+    std::shared_ptr<mhw::vebox::Itf>                        m_veboxItf = nullptr;
+
+MEDIA_CLASS_DEFINE_END(vp__VpRenderKernelObj)
 };
 }
 #endif // __VP_RENDER_KERNEL_OBJ_H__
