@@ -33,6 +33,7 @@
 #include "vp_filter.h"
 #include "mhw_mi_itf.h"
 #include "vp_render_sfc_base.h"
+#include "hal_oca_interface_next.h"
 
 #define VP_MAX_NUM_FFDI_SURFACES     4                                       //!< 2 for ADI plus additional 2 for parallel execution on HSW+
 #define VP_NUM_FFDN_SURFACES         2                                       //!< Number of FFDN surfaces
@@ -928,6 +929,14 @@ public:
 
     mhw::vebox::MHW_VEBOX_CHROMA_PARAMS veboxChromaParams = {};
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    virtual MOS_STATUS StallBatchBuffer(
+        PMOS_COMMAND_BUFFER cmdBuffer)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+#endif
+
 protected:
 
     //!
@@ -1109,7 +1118,7 @@ protected:
         mhw::vebox::VEBOX_STATE_PAR &veboxStateCmdParams);
     virtual MOS_STATUS Init3DLutTable(PVP_SURFACE surf3DLut);
     void    UpdateCpPrepareResources();
-    MOS_STATUS SetupVebox3DLutForHDR(
+    virtual MOS_STATUS SetupVebox3DLutForHDR(
         mhw::vebox::VEBOX_STATE_PAR &veboxStateCmdParams);
 
 private:
