@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -29,9 +29,11 @@
 #ifndef __VP_FEATURE_REPORT_H__
 #define __VP_FEATURE_REPORT_H__
 
-#include "vphal_common.h"
-#include "vphal_common_tools.h"
+#include <stdint.h>
+#include "vp_common.h"
+#include "vp_common_tools.h"
 #include "media_class_trace.h"
+#include "vp_common_hdr.h"
 
 //!
 //! Class VphalFeatureReport
@@ -66,6 +68,13 @@ public:
         bool                          veFeatureInUse      = false;                        //!< If any VEBOX feature is in use, excluding pure bypass for SFC
         bool                          diScdMode           = false;                        //!< Scene change detection
         VPHAL_HDR_MODE                hdrMode             = VPHAL_HDR_MODE_NONE;          //!< HDR mode
+        bool                          packetReused        = false;                        //!< true if packet reused.
+        uint8_t                       rtCacheSetting      = 0;                            //!< Render Target cache usage
+#if (_DEBUG || _RELEASE_INTERNAL)
+        uint8_t                       rtOldCacheSetting   = 0;                            //!< Render Target old cache usage
+#endif
+        bool                          VeboxScalability    = false;                        //!< Vebox Scalability flag
+        bool                          VPApogeios          = false;                        //!< VP Apogeios flag
     };
 
     virtual ~VpFeatureReport(){};
@@ -91,7 +100,7 @@ public:
     //!
     virtual void SetConfigValues(
         PVP_CONFIG configValues,
-        uint32_t   &laceInUse);
+        bool       traceEvent = true);
 
     VP_FEATURES &GetFeatures()
     {
