@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -99,6 +99,10 @@ VpPipeline::~VpPipeline()
         MOS_Delete(m_userFeatureControl);
         m_vpMhwInterface.m_userFeatureControl = nullptr;
     }
+    if (m_pipelineParamFactory)
+    {
+        MOS_Delete(m_pipelineParamFactory);
+    }
 }
 
 MOS_STATUS VpPipeline::GetStatusReport(void *status, uint16_t numStatus)
@@ -136,10 +140,26 @@ MOS_STATUS VpPipeline::ReportIFNCC(bool bStart)
     //INTER_FRAME_MEMORY_NINJA_START_COUNTER will be reported in Prepare function
     //INTER_FRAME_MEMORY_NINJA_END_COUNTER will be reported in UserFeatureReport() function which runs in Execute()
     VP_FUNC_CALL();
-    if (m_userFeatureControl->EnableIFNCC())
+    int32_t memninjaCounter = 0;
+    memninjaCounter         = *MosUtilities::m_mosMemAllocCounter + *MosUtilities::m_mosMemAllocCounterGfx - *MosUtilities::m_mosMemAllocFakeCounter;
+    if (MOS_IS_MEMORY_FOOT_PRINT_ENABLED())
+    {
+        if (bStart)
+        {
+            MT_LOG2(MT_MOS_MEMORY_NINJA_COUNTER, MT_NORMAL, MT_MEMORY_NINJA_IS_START, bStart, MT_MEMORY_NINJA_START_COUNTER, memninjaCounter);
+            VP_PUBLIC_NORMALMESSAGE("MT_MOS_MEMORY_NINJA_COUNTER, MT_MEMORY_NINJA_IS_START :%d, MT_MEMORY_NINJA_START_COUNTER: %d", bStart, memninjaCounter);
+        }
+        else
+        {
+            MT_LOG2(MT_MOS_MEMORY_NINJA_COUNTER, MT_NORMAL, MT_MEMORY_NINJA_IS_START, bStart, MT_MEMORY_NINJA_END_COUNTER, memninjaCounter);
+            VP_PUBLIC_NORMALMESSAGE("MT_MOS_MEMORY_NINJA_COUNTER, MT_MEMORY_NINJA_IS_START :%d, MT_MEMORY_NINJA_END_COUNTER: %d", bStart, memninjaCounter);
+        }
+    }
+    if (m_userFeatureControl->EnableIFNCC() &&
+        MosUtilities::m_mosMemAllocCounter &&
+        MosUtilities::m_mosMemAllocCounterGfx &&
+        MosUtilities::m_mosMemAllocFakeCounter)
     {
-        int32_t memninjaCounter = 0;
-        memninjaCounter         = MosUtilities::m_mosMemAllocCounter + MosUtilities::m_mosMemAllocCounterGfx - MosUtilities::m_mosMemAllocFakeCounter;
         ReportUserSettingForDebug(
             m_userSettingPtr,
             bStart ? __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_START_COUNTER : __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_END_COUNTER,
@@ -184,27 +204,27 @@ MOS_STATUS VpPipeline::UserFeatureReport()
                 m_reporting->GetFeatures().rtCompressible = true;
                 m_reporting->GetFeatures().rtCompressMode = (uint8_t)(params->pTarget[0]->CompressionMode);
             }
+            
+            m_reporting->GetFeatures().rtCacheSetting = (uint8_t)(params->pTarget[0]->CacheSetting);
+#if (_DEBUG || _RELEASE_INTERNAL)
+            if (m_reporting->GetFeatures().outputPipeMode == VPHAL_OUTPUT_PIPE_MODE_SFC)
+            {
+                if (m_vpMhwInterface.m_sfcInterface)
+                {
+                    m_reporting->GetFeatures().rtOldCacheSetting = (uint8_t)((m_vpMhwInterface.m_sfcInterface->m_outputSurfCtrl.Value >> 1) & 0x0000003f);
+                }
+            }
+            else if (m_vpMhwInterface.m_renderHal)
+            {
+                m_reporting->GetFeatures().rtOldCacheSetting = (uint8_t)(m_vpMhwInterface.m_renderHal->oldCacheSettingForTargetSurface);
+            }
+#endif
         }
-    }
 
+        m_reporting->GetFeatures().VPApogeios = m_currentFrameAPGEnabled;
+    }
     MediaPipeline::UserFeatureReport();
 
-    if (m_currentFrameAPGEnabled)
-    {
-        ReportUserSetting(
-            m_userSettingPtr,
-            __MEDIA_USER_FEATURE_VALUE_VPP_APOGEIOS_ENABLE,
-            uint32_t(1),
-            MediaUserSetting::Group::Sequence);
-    }
-    else
-    {
-        ReportUserSetting(
-            m_userSettingPtr,
-            __MEDIA_USER_FEATURE_VALUE_VPP_APOGEIOS_ENABLE,
-            uint32_t(0),
-            MediaUserSetting::Group::Sequence);
-    }
 
 #if (_DEBUG || _RELEASE_INTERNAL)
     //INTER_FRAME_MEMORY_NINJA_START_COUNTER will be reported in ReportIFNCC(true) function which runs in VpPipeline::Prepare()
@@ -260,6 +280,10 @@ MOS_STATUS VpPipeline::Init(void *mhwInterface)
         VP_PUBLIC_CHK_STATUS_RETURN(CreateUserFeatureControl());
         m_vpMhwInterface.m_userFeatureControl = m_userFeatureControl;
     }
+    if (m_userFeatureControl && m_vpMhwInterface.m_settings)
+    {
+        m_userFeatureControl->SetClearVideoViewMode(((VP_SETTINGS *)m_vpMhwInterface.m_settings)->clearVideoViewMode);
+    }
 
     VP_PUBLIC_CHK_STATUS_RETURN(m_vpMhwInterface.m_vpPlatformInterface->ConfigVirtualEngine());
 
@@ -321,10 +345,9 @@ MOS_STATUS VpPipeline::Init(void *mhwInterface)
     VP_PUBLIC_CHK_STATUS_RETURN(SetVideoProcessingSettings(m_vpMhwInterface.m_settings));
 
     m_vpMhwInterface.m_settings = m_vpSettings;
-
     if (m_vpMhwInterface.m_vpPlatformInterface->IsGpuContextCreatedInPipelineInit())
     {
-        if (m_numVebox > 0)
+        if (m_numVebox > 0 && !(m_vpSettings && m_vpSettings->clearVideoViewMode))
         {
             VP_PUBLIC_NORMALMESSAGE("Create GpuContext for Vebox.");
             VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(VP_PIPELINE_PACKET_VEBOX, m_scalability,
@@ -368,12 +391,15 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
 
     VP_PUBLIC_CHK_NULL_RETURN(featureManagerNext);
     VP_PUBLIC_CHK_NULL_RETURN(m_pPacketPipeFactory);
+    VP_PUBLIC_CHK_NULL_RETURN(m_osInterface);
 
     if (m_vpPipeContexts.size() < 1 || m_vpPipeContexts[0] == nullptr)
     {
         VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
     }
 
+    MT_LOG2(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_START, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(), MT_VP_FEATURE_GRAPH_FILTER_FRAMEID,m_vpPipeContexts[0]->GetFrameCounter());
+
     if (PIPELINE_PARAM_TYPE_LEGACY == m_pvpParams.type)
     {
         params = m_pvpParams.renderParams;
@@ -392,7 +418,8 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
                 params->pSrc[uiLayer],
                 m_vpPipeContexts[0]->GetFrameCounter(),
                 uiLayer,
-                VPHAL_DUMP_TYPE_PRE_ALL);
+                VPHAL_DUMP_TYPE_PRE_ALL,
+                VPHAL_SURF_DUMP_DDI_VP_BLT);
         }
 #endif
         // Predication
@@ -402,16 +429,26 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
         VP_PUBLIC_CHK_STATUS_RETURN(eStatus);
         if (isBypassNeeded)
         {
+            MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
+                    MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS, isBypassNeeded);
             return MOS_STATUS_SUCCESS;
         }
-
     }
 
     VP_PUBLIC_CHK_STATUS_RETURN(CreateSwFilterPipe(m_pvpParams, swFilterPipes));
 
+    // Increment frame ID for performance measurement
+    m_osInterface->pfnIncPerfFrameID(m_osInterface);
+
     for (uint32_t pipeIdx = 0; pipeIdx < swFilterPipes.size(); pipeIdx++)
     {
+        MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_START, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
+                MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPEID, pipeIdx);
         auto &pipe = swFilterPipes[pipeIdx];
+        if (pipe)
+        {
+            pipe->AddRTLog();
+        }
         if (pipeIdx >= m_vpPipeContexts.size())
         {
             VP_PUBLIC_CHK_STATUS_RETURN(CreateSinglePipeContext());
@@ -422,8 +459,12 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
         VP_PUBLIC_CHK_STATUS_RETURN(m_vpInterface->SwitchResourceManager(singlePipeCtx->GetVpResourceManager()));
 
         VP_PUBLIC_CHK_STATUS_RETURN(ExecuteSingleswFilterPipe(singlePipeCtx, pipe, pPacketPipe, featureManagerNext));
+        MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_END, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
+                MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPEID, pipeIdx);
     }
 
+    MT_LOG3(MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)swFilterPipes.size(),
+            MT_VP_FEATURE_GRAPH_FILTER_FRAMEID, m_vpPipeContexts[0]->GetFrameCounter(), MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS, isBypassNeeded);
     return eStatus;
 }
 
@@ -475,7 +516,7 @@ MOS_STATUS VpPipeline::ExecuteSingleswFilterPipe(VpSinglePipeContext *singlePipe
     if (isPacketPipeReused)
     {
         VP_PUBLIC_NORMALMESSAGE("Packet reused.");
-
+        MT_LOG(MT_VP_FEATURE_GRAPH_FEATUREPIPE_REUSE, MT_NORMAL);
         singlePipeCtx->SetPacketReused(true);
 
         PacketPipe *pipeReused = packetReuseMgr->GetPacketPipeReused();
@@ -484,10 +525,10 @@ MOS_STATUS VpPipeline::ExecuteSingleswFilterPipe(VpSinglePipeContext *singlePipe
         // Update output pipe mode.
         singlePipeCtx->SetOutputPipeMode(pipeReused->GetOutputPipeMode());
         singlePipeCtx->SetIsVeboxFeatureInuse(pipeReused->IsVeboxFeatureInuse());
-
         // MediaPipeline::m_statusReport is always nullptr in VP APO path right now.
         eStatus = pipeReused->Execute(MediaPipeline::m_statusReport, m_scalability, m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox);
-
+        MT_LOG1(MT_VP_HAL_VEBOXNUM_CHECK, MT_NORMAL, MT_VP_HAL_VEBOX_NUMBER, m_numVebox)
+        VP_PUBLIC_NORMALMESSAGE("Vebox Number for check %d", m_numVebox);
         if (MOS_SUCCEEDED(eStatus))
         {
             VP_PUBLIC_CHK_STATUS_RETURN(chkStatusHandler(UpdateExecuteStatus(frameCounter)));
@@ -520,7 +561,8 @@ MOS_STATUS VpPipeline::ExecuteSingleswFilterPipe(VpSinglePipeContext *singlePipe
 
     // MediaPipeline::m_statusReport is always nullptr in VP APO path right now.
     eStatus = pPacketPipe->Execute(MediaPipeline::m_statusReport, m_scalability, m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox);
-
+    MT_LOG1(MT_VP_HAL_VEBOXNUM_CHECK, MT_NORMAL, MT_VP_HAL_VEBOX_NUMBER, m_numVebox)
+    VP_PUBLIC_NORMALMESSAGE("Vebox Number for check %d", m_numVebox);
     if (MOS_SUCCEEDED(eStatus))
     {
         VP_PUBLIC_CHK_STATUS_RETURN(chkStatusHandler(packetReuseMgr->UpdatePacketPipeConfig(pPacketPipe)));
@@ -538,7 +580,7 @@ MOS_STATUS VpPipeline::UpdateExecuteStatus(uint32_t frameCnt)
     VP_FUNC_CALL();
 
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-#if ((_DEBUG || _RELEASE_INTERNAL) && !EMUL)
+#if ((_DEBUG || _RELEASE_INTERNAL))
     if (PIPELINE_PARAM_TYPE_LEGACY == m_pvpParams.type)
     {
         PVP_PIPELINE_PARAMS params = m_pvpParams.renderParams;
@@ -548,7 +590,8 @@ MOS_STATUS VpPipeline::UpdateExecuteStatus(uint32_t frameCnt)
             VPHAL_MAX_TARGETS,
             params->uDstCount,
             frameCnt,
-            VPHAL_DUMP_TYPE_POST_ALL);
+            VPHAL_DUMP_TYPE_POST_ALL,
+            params->uSrcCount > 0 ? VPHAL_SURF_DUMP_DDI_VP_BLT : VPHAL_SURF_DUMP_DDI_CLEAR_VIEW);
 
         // Decompre output surface for debug
         bool uiForceDecompressedOutput = false;
@@ -568,18 +611,16 @@ finish:
 MOS_STATUS VpPipeline::CreateSwFilterPipe(VP_PARAMS &params, std::vector<SwFilterPipe*> &swFilterPipe)
 {
     VP_FUNC_CALL();
-
     switch (m_pvpParams.type)
     {
     case PIPELINE_PARAM_TYPE_LEGACY:
-        VP_PUBLIC_CHK_STATUS_RETURN(m_vpInterface->GetSwFilterPipeFactory().Create(m_pvpParams.renderParams, swFilterPipe));
+        VP_PUBLIC_CHK_STATUS_RETURN(m_vpInterface->GetSwFilterPipeFactory().Create(m_pvpParams.renderParams, swFilterPipe, m_pipelineParamFactory));
         break;
     case PIPELINE_PARAM_TYPE_MEDIA_SFC_INTERFACE:
         VP_PUBLIC_CHK_STATUS_RETURN(m_vpInterface->GetSwFilterPipeFactory().Create(m_pvpParams.sfcParams, swFilterPipe));
         break;
     default:
         VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
-        break;
     }
 
     if (swFilterPipe.size() == 0)
@@ -689,9 +730,17 @@ MOS_STATUS VpPipeline::CreateSinglePipeContext()
     VP_FUNC_CALL();
     VpSinglePipeContext *singlePipeCtx = MOS_New(VpSinglePipeContext);
     VP_PUBLIC_CHK_NULL_RETURN(singlePipeCtx);
-    VP_PUBLIC_CHK_STATUS_RETURN(singlePipeCtx->Init(m_osInterface, m_allocator, m_reporting, m_vpMhwInterface.m_vpPlatformInterface, m_pPacketPipeFactory, m_userFeatureControl, m_mediaCopyWrapper));
-    m_vpPipeContexts.push_back(singlePipeCtx);
-    return MOS_STATUS_SUCCESS;
+    MOS_STATUS status = singlePipeCtx->Init(m_osInterface, m_allocator, m_reporting, m_vpMhwInterface.m_vpPlatformInterface, m_pPacketPipeFactory, m_userFeatureControl, m_mediaCopyWrapper);
+    if (MOS_FAILED(status))
+    {
+        MOS_Delete(singlePipeCtx);
+        VP_PUBLIC_CHK_STATUS_RETURN(status);
+    }
+    else
+    {
+        m_vpPipeContexts.push_back(singlePipeCtx);
+    }
+    return status;
 }
 
 MOS_STATUS VpPipeline::CreateFeatureManager(VpResourceManager *vpResourceManager)
@@ -717,6 +766,9 @@ MOS_STATUS VpPipeline::CreateFeatureManager(VpResourceManager *vpResourceManager
 
     VP_PUBLIC_CHK_STATUS_RETURN(((VpFeatureManagerNext *)m_featureManager)->Init(nullptr));
 
+    m_pipelineParamFactory = MOS_New(VpPipelineParamFactory);
+    VP_PUBLIC_CHK_NULL_RETURN(m_pipelineParamFactory);
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -918,7 +970,7 @@ MOS_STATUS VpPipeline::PrepareVpPipelineParams(PVP_PIPELINE_PARAMS params)
 
     if (params->uSrcCount>0)
     {
-        if (params->pSrc[0]->pBwdRef)
+        if (params->pSrc[0]->pBwdRef && params->pSrc[0]->uBwdRefCount > 0)
         {
             MOS_ZeroMemory(&info, sizeof(VPHAL_GET_SURFACE_INFO));
 
@@ -994,6 +1046,70 @@ MOS_STATUS VpPipeline::PrepareVpPipelineParams(PVP_PIPELINE_PARAMS params)
     return MOS_STATUS_SUCCESS;
 }
 
+//!
+//! \brief  prepare execution params for vp scalability pipeline
+//! \param  [in] params
+//!         src and dst surface's width and height
+//! \return MOS_STATUS
+//!         MOS_STATUS_SUCCESS if success, else fail reason
+//!
+MOS_STATUS VpPipeline::PrepareVpPipelineScalabilityParams(uint32_t srcWidth, uint32_t srcHeight, uint32_t dstWidth, uint32_t dstHeight)
+{
+    VP_FUNC_CALL();
+    VP_PUBLIC_NORMALMESSAGE("Reset m_numVebox %d -> %d", m_numVebox, m_numVeboxOriginal);
+    m_numVebox = m_numVeboxOriginal;
+    MT_LOG1(MT_VP_HAL_VEBOXNUM_RESET, MT_NORMAL, MT_VP_HAL_VEBOX_NUMBER, m_numVebox)
+
+    // Disable vesfc scalability when reg key "Enable Vebox Scalability" was set to zero
+    if (m_forceMultiplePipe == (MOS_SCALABILITY_ENABLE_MODE_USER_FORCE | MOS_SCALABILITY_ENABLE_MODE_FALSE))
+    {
+        m_numVebox = 1;
+    }
+    else
+    {
+        if (((srcWidth > m_scalability_threshWidth) &&
+             (srcHeight > m_scalability_threshHeight)) ||
+            ((dstWidth > m_scalability_threshWidth) &&
+             (dstHeight > m_scalability_threshHeight)))
+        {
+            // Enable vesfc scalability only with 4k+ clips
+        }
+        else
+        {
+            // disable vesfc scalability with 4k- resolution clips if reg "Enable Vebox Scalability" was not set as true
+            if (m_forceMultiplePipe != (MOS_SCALABILITY_ENABLE_MODE_USER_FORCE | MOS_SCALABILITY_ENABLE_MODE_DEFAULT))
+            {
+                m_numVebox = 1;
+            }
+        }
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
+//!
+//! \brief  prepare execution params for vp scalability pipeline
+//! \param  [in] params
+//!         Pointer to VP scalability pipeline params
+//! \return MOS_STATUS
+//!         MOS_STATUS_SUCCESS if success, else fail reason
+//!
+MOS_STATUS VpPipeline::PrepareVpPipelineScalabilityParams(VEBOX_SFC_PARAMS* params)
+{
+    VP_FUNC_CALL();
+    VP_PUBLIC_CHK_NULL_RETURN(params);
+    VP_PUBLIC_CHK_NULL_RETURN(params->input.surface);
+    VP_PUBLIC_CHK_NULL_RETURN(params->output.surface);
+    
+    VP_PUBLIC_CHK_STATUS_RETURN(PrepareVpPipelineScalabilityParams(
+        MOS_MIN(params->input.surface->dwWidth, (uint32_t)params->input.rcSrc.right),
+        MOS_MIN(params->input.surface->dwHeight, (uint32_t)params->input.rcSrc.bottom),
+        MOS_MIN(params->output.surface->dwWidth, (uint32_t)params->output.rcDst.right),
+        MOS_MIN(params->output.surface->dwHeight, (uint32_t)params->output.rcDst.bottom)));
+
+    return MOS_STATUS_SUCCESS;
+}
+
 //!
 //! \brief  prepare execution params for vp scalability pipeline
 //! \param  [in] params
@@ -1013,41 +1129,20 @@ MOS_STATUS VpPipeline::PrepareVpPipelineScalabilityParams(PVP_PIPELINE_PARAMS pa
 
     VP_PUBLIC_CHK_NULL_RETURN(params->pTarget[0]);
 
-    VP_PUBLIC_NORMALMESSAGE("Reset m_numVebox %d -> %d", m_numVebox, m_numVeboxOriginal);
-    m_numVebox = m_numVeboxOriginal;
+    VP_PUBLIC_CHK_STATUS_RETURN(PrepareVpPipelineScalabilityParams(
+        MOS_MIN(params->pSrc[0]->dwWidth, (uint32_t)params->pSrc[0]->rcSrc.right),
+        MOS_MIN(params->pSrc[0]->dwHeight, (uint32_t)params->pSrc[0]->rcSrc.bottom),
+        MOS_MIN(params->pTarget[0]->dwWidth, (uint32_t)params->pTarget[0]->rcSrc.right),
+        MOS_MIN(params->pTarget[0]->dwHeight, (uint32_t)params->pTarget[0]->rcSrc.bottom)));
 
-    // Disable vesfc scalability when reg key "Enable Vebox Scalability" was set to zero
-    if (m_forceMultiplePipe == (MOS_SCALABILITY_ENABLE_MODE_USER_FORCE | MOS_SCALABILITY_ENABLE_MODE_FALSE))
+    // Disable DN when vesfc scalability was enabled for output mismatch issue
+    if (IsMultiple())
     {
-        m_numVebox = 1;
-    }
-    else
-    {
-        if (((MOS_MIN(params->pSrc[0]->dwWidth, (uint32_t)params->pSrc[0]->rcSrc.right) > m_scalability_threshWidth) &&
-                (MOS_MIN(params->pSrc[0]->dwHeight, (uint32_t)params->pSrc[0]->rcSrc.bottom) > m_scalability_threshHeight)) ||
-            ((MOS_MIN(params->pTarget[0]->dwWidth, (uint32_t)params->pTarget[0]->rcSrc.right) > m_scalability_threshWidth) &&
-                (MOS_MIN(params->pTarget[0]->dwHeight, (uint32_t)params->pTarget[0]->rcSrc.bottom) > m_scalability_threshHeight)))
+        if (params->pSrc[0]->pDenoiseParams)
         {
-            // Enable vesfc scalability only with 4k+ clips
-        }
-        else
-        {
-            // disable vesfc scalability with 4k- resolution clips if reg "Enable Vebox Scalability" was not set as true
-            if (m_forceMultiplePipe != (MOS_SCALABILITY_ENABLE_MODE_USER_FORCE | MOS_SCALABILITY_ENABLE_MODE_DEFAULT))
-            {
-                m_numVebox = 1;
-            }
-        }
-
-        // Disable DN when vesfc scalability was enabled for output mismatch issue
-        if (IsMultiple())
-        {
-            if (params->pSrc[0]->pDenoiseParams)
-            {
-                params->pSrc[0]->pDenoiseParams->bAutoDetect   = false;
-                params->pSrc[0]->pDenoiseParams->bEnableChroma = false;
-                params->pSrc[0]->pDenoiseParams->bEnableLuma   = false;
-            }
+            params->pSrc[0]->pDenoiseParams->bAutoDetect   = false;
+            params->pSrc[0]->pDenoiseParams->bEnableChroma = false;
+            params->pSrc[0]->pDenoiseParams->bEnableLuma   = false;
         }
     }
 
@@ -1095,6 +1190,13 @@ MOS_STATUS VpPipeline::Prepare(void * params)
             }
         }
     }
+    else if (PIPELINE_PARAM_TYPE_MEDIA_SFC_INTERFACE == m_pvpParams.type)
+    {
+        VEBOX_SFC_PARAMS *sfcParams = m_pvpParams.sfcParams;
+        VP_PUBLIC_CHK_NULL_RETURN(sfcParams);
+
+        VP_PUBLIC_CHK_STATUS_RETURN(PrepareVpPipelineScalabilityParams(sfcParams));
+    }
 
     return MOS_STATUS_SUCCESS;
 }
@@ -1150,7 +1252,7 @@ MOS_STATUS VpSinglePipeContext::CreateResourceManager(PMOS_INTERFACE osInterface
     VP_FUNC_CALL();
     if (nullptr == m_resourceManager)
     {
-        m_resourceManager = MOS_New(VpResourceManager, *osInterface, *allocator, *reporting, *vpPlatformInterface, mediaCopyWrapper);
+        m_resourceManager = MOS_New(VpResourceManager, *osInterface, *allocator, *reporting, *vpPlatformInterface, mediaCopyWrapper, userFeatureControl);
         VP_PUBLIC_CHK_NULL_RETURN(m_resourceManager);
     }
     
@@ -1167,4 +1269,4 @@ MOS_STATUS VpSinglePipeContext::CreatePacketReuseManager(PacketPipeFactory *pPac
         VP_PUBLIC_CHK_STATUS_RETURN(m_packetReuseMgr->RegisterFeatures());
     }
     return MOS_STATUS_SUCCESS;
-}
\ No newline at end of file
+}
