@@ -50,9 +50,12 @@ public:
         bool eufusionBypassWaEnabled        = false;
         bool disableDn                      = false;
         bool cscCosffPatchModeDisabled      = false;
+        bool ForceEnableVeboxOutputSurf     = false;
+        bool veboxTypeH                     = false;
 
 #if (_DEBUG || _RELEASE_INTERNAL)
         bool forceDecompressedOutput        = false;
+        uint32_t force3DLutInterpolation    = 0;
         uint32_t enabledSFCNv12P010LinearOutput = 0;
         uint32_t enabledSFCRGBPRGB24Output  = 0;
         bool     enableIFNCC                    = false;
@@ -63,7 +66,9 @@ public:
         VPHAL_HDR_LUT_MODE globalLutMode      = VPHAL_HDR_LUT_MODE_NONE;  //!< Global LUT mode control for debugging purpose
         bool               gpuGenerate3DLUT   = false;                        //!< Flag for per frame GPU generation of 3DLUT
         bool               disableAutoMode    = false;
+        bool               clearVideoViewMode = false;
         uint32_t           splitFramePortions = 1;
+        bool               decompForInterlacedSurfWaEnabled = false;
     };
 
 #if (_DEBUG || _RELEASE_INTERNAL)
@@ -72,6 +77,11 @@ public:
         return m_ctrlVal.forceDecompressedOutput;
     }
 
+    uint32_t Force3DLutInterpolation()
+    {
+        return m_ctrlVal.force3DLutInterpolation;
+    }
+
     uint32_t EnabledSFCNv12P010LinearOutput()
     {
         return m_ctrlVal.enabledSFCNv12P010LinearOutput;
@@ -82,7 +92,8 @@ public:
         return m_ctrlVal.enabledSFCRGBPRGB24Output;
     }
 
-    bool EnableIFNCC() {
+    bool EnableIFNCC() 
+    {
         return m_ctrlVal.enableIFNCC;
     }
 #endif
@@ -91,6 +102,11 @@ public:
 
     virtual MOS_STATUS Update(PVP_PIPELINE_PARAMS params);
 
+    bool IsVeboxOutputSurfEnabled()
+    {
+        return m_ctrlVal.ForceEnableVeboxOutputSurf;
+    }
+
     bool IsVeboxOutputDisabled()
     {
         return m_ctrlVal.disableVeboxOutput;
@@ -146,6 +162,27 @@ public:
         return m_ctrlVal.disableAutoMode;
     }
 
+    bool IsClearVideoViewMode()
+    {
+        return m_ctrlVal.clearVideoViewMode;
+    }
+
+    bool IsDecompForInterlacedSurfWaEnabled()
+    {
+        return m_ctrlVal.decompForInterlacedSurfWaEnabled;
+    }
+
+    bool IsVeboxTypeHMode()
+    {
+        return m_ctrlVal.veboxTypeH;
+    }
+
+    MOS_STATUS SetClearVideoViewMode(bool mode)
+    {
+        m_ctrlVal.clearVideoViewMode = mode;
+        return MOS_STATUS_SUCCESS;
+    }
+
     uint32_t GetSplitFramePortions()
     {
         return m_ctrlVal.splitFramePortions;
@@ -161,6 +198,8 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    virtual PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO GetOcaFeautreControlInfo();
+
     const void *m_owner = nullptr; // The object who create current instance.
 
 protected:
@@ -170,6 +209,7 @@ protected:
     CONTROL_VALUES m_ctrlValDefault = {};
     CONTROL_VALUES m_ctrlVal        = {};
     MediaUserSettingSharedPtr m_userSettingPtr = nullptr;  //!< usersettingInstance
+    PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO m_pOcaFeatureControlInfo = nullptr;
 
     MEDIA_CLASS_DEFINE_END(vp__VpUserFeatureControl)
 };
