@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2022, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -122,6 +122,13 @@ finish:
     return eStatus;
 }
 
+bool VpUtils::IsVerticalRotation(VPHAL_ROTATION rotation) {
+    return (rotation != VPHAL_ROTATION_IDENTITY &&
+            rotation != VPHAL_ROTATION_180 &&
+            rotation != VPHAL_MIRROR_VERTICAL &&
+            rotation != VPHAL_MIRROR_HORIZONTAL);
+}
+
 bool VpUtils::IsSyncFreeNeededForMMCSurface(PVPHAL_SURFACE surface, PMOS_INTERFACE osInterface)
 {
     if (nullptr == surface || nullptr == osInterface)
@@ -282,3 +289,119 @@ void VpUtils::GetCscMatrixForVeSfc8Bit(
         VP_PUBLIC_NORMALMESSAGE("Unsupported Output ColorSpace for Vebox %d.", (uint32_t)dstCspace);
     }
 }
+
+bool VpUtils::GetCscMatrixForRender8Bit(
+    VPHAL_COLOR_SAMPLE_8 *output,
+    VPHAL_COLOR_SAMPLE_8 *input,
+    VPHAL_CSPACE          srcCspace,
+    VPHAL_CSPACE          dstCspace)
+{
+    float   pfCscMatrix[12] = {0};
+    int32_t iCscMatrix[12]  = {0};
+    bool    bResult         = false;
+    int32_t i               = 0;
+
+    KernelDll_GetCSCMatrix(srcCspace, dstCspace, pfCscMatrix);
+
+    // convert float to fixed point format for the 3x4 matrix
+    for (i = 0; i < 12; i++)
+    {
+        // multiply by 2^20 and round up
+        iCscMatrix[i] = (int32_t)((pfCscMatrix[i] * 1048576.0f) + 0.5f);
+    }
+
+    bResult = GetCscMatrixForRender8BitWithCoeff(output, input, srcCspace, dstCspace, iCscMatrix);
+
+    return bResult;
+}
+
+bool VpUtils::GetCscMatrixForRender8BitWithCoeff(
+    VPHAL_COLOR_SAMPLE_8 *output,
+    VPHAL_COLOR_SAMPLE_8 *input,
+    VPHAL_CSPACE          srcCspace,
+    VPHAL_CSPACE          dstCspace,
+    int32_t              *iCscMatrix)
+{
+    bool    bResult = true;
+    int32_t a = 0, r = 0, g = 0, b = 0;
+    int32_t y1 = 0, u1 = 0, v1 = 0;
+
+    y1 = r = input->YY;
+    u1 = g = input->Cb;
+    v1 = b = input->Cr;
+    a      = input->Alpha;
+
+    if (srcCspace == dstCspace)
+    {
+        // no conversion needed
+        if ((dstCspace == CSpace_sRGB) || (dstCspace == CSpace_stRGB) || IS_COLOR_SPACE_BT2020_RGB(dstCspace))
+        {
+            output->A = (uint8_t)a;
+            output->R = (uint8_t)r;
+            output->G = (uint8_t)g;
+            output->B = (uint8_t)b;
+        }
+        else
+        {
+            output->a = (uint8_t)a;
+            output->Y = (uint8_t)y1;
+            output->U = (uint8_t)u1;
+            output->V = (uint8_t)v1;
+        }
+    }
+    else
+    {
+        // conversion needed
+        r = (y1 * iCscMatrix[0] + u1 * iCscMatrix[1] +
+                v1 * iCscMatrix[2] + iCscMatrix[3] + 0x00080000) >>
+            20;
+        g = (y1 * iCscMatrix[4] + u1 * iCscMatrix[5] +
+                v1 * iCscMatrix[6] + iCscMatrix[7] + 0x00080000) >>
+            20;
+        b = (y1 * iCscMatrix[8] + u1 * iCscMatrix[9] +
+                v1 * iCscMatrix[10] + iCscMatrix[11] + 0x00080000) >>
+            20;
+
+        switch (dstCspace)
+        {
+        case CSpace_sRGB:
+            output->A = (uint8_t)a;
+            output->R = MOS_MIN(MOS_MAX(0, r), 255);
+            output->G = MOS_MIN(MOS_MAX(0, g), 255);
+            output->B = MOS_MIN(MOS_MAX(0, b), 255);
+            break;
+
+        case CSpace_stRGB:
+            output->A = (uint8_t)a;
+            output->R = MOS_MIN(MOS_MAX(16, r), 235);
+            output->G = MOS_MIN(MOS_MAX(16, g), 235);
+            output->B = MOS_MIN(MOS_MAX(16, b), 235);
+            break;
+
+        case CSpace_BT601:
+        case CSpace_BT709:
+            output->a = (uint8_t)a;
+            output->Y = MOS_MIN(MOS_MAX(16, r), 235);
+            output->U = MOS_MIN(MOS_MAX(16, g), 240);
+            output->V = MOS_MIN(MOS_MAX(16, b), 240);
+            break;
+
+        case CSpace_xvYCC601:
+        case CSpace_xvYCC709:
+        case CSpace_BT601_FullRange:
+        case CSpace_BT709_FullRange:
+            output->a = (uint8_t)a;
+            output->Y = MOS_MIN(MOS_MAX(0, r), 255);
+            output->U = MOS_MIN(MOS_MAX(0, g), 255);
+            output->V = MOS_MIN(MOS_MAX(0, b), 255);
+            break;
+
+        default:
+            VP_PUBLIC_NORMALMESSAGE("Unsupported Output ColorSpace %d.", (uint32_t)dstCspace);
+            bResult = false;
+            break;
+        }
+    }
+
+    return bResult;
+}
