@@ -396,7 +396,21 @@ VAStatus DdiEncodeAV1::ParseSeqParams(void *ptr)
     av1SeqParams->GopPicSize    = seqParams->intra_period;
     av1SeqParams->GopRefDist    = seqParams->ip_period;
  
-    av1SeqParams->RateControlMethod = VARC2HalRC(m_encodeCtx->uiRCMethod);
+    switch ((uint32_t)m_encodeCtx->uiRCMethod)
+    {
+    case VA_RC_TCBRC:
+    case VA_RC_VBR:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_VBR;
+        break;
+    case VA_RC_CQP:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CQP;
+        break;
+    case VA_RC_ICQ:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CQL;
+        break;
+    default:
+        av1SeqParams->RateControlMethod = (uint8_t)RATECONTROL_CBR;
+    }
 
     /* the bits_per_second is only used when the target bit_rate is not initialized */
     if (av1SeqParams->TargetBitRate[0] == 0)
@@ -632,6 +646,8 @@ VAStatus DdiEncodeAV1::ParsePicParams(DDI_MEDIA_CONTEXT *mediaCtx, void *ptr)
 
     DDI_CODEC_CHK_RET(CheckCDEF(picParams, mediaCtx->platform.eProductFamily), "invalid CDEF Paramter");
 
+    DDI_CODEC_CHK_RET(CheckTile(picParams), "invalid Tile Paramter");
+    
     av1PicParams->context_update_tile_id = picParams->context_update_tile_id;
     av1PicParams->temporal_id            = picParams->temporal_id;
 
@@ -902,7 +918,10 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
 
     if (VA_RC_CBR == m_encodeCtx->uiRCMethod)
     {
-        seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        if(vaEncMiscParamRC->target_percentage != 0)
+            seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        else
+            seqParams->TargetBitRate[temporalId] = bitRate;
         seqParams->MaxBitRate                = seqParams->TargetBitRate[temporalId];
         seqParams->MinBitRate                = seqParams->TargetBitRate[temporalId];
         seqParams->RateControlMethod         = RATECONTROL_CBR;
@@ -917,7 +936,10 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
     }
     else if (VA_RC_VBR == m_encodeCtx->uiRCMethod)
     {
-        seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100; //VBR target bits;
+        if(vaEncMiscParamRC->target_percentage != 0)
+            seqParams->TargetBitRate[temporalId] = bitRate * vaEncMiscParamRC->target_percentage / 100;
+        else
+            seqParams->TargetBitRate[temporalId] = bitRate;
         seqParams->MaxBitRate = bitRate;
         seqParams->MinBitRate = 0;
         seqParams->RateControlMethod = RATECONTROL_VBR;
@@ -933,6 +955,19 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
             savedMaxBitRate[temporalId] = bitRate;
         }
     }
+    else if (VA_RC_ICQ == m_encodeCtx->uiRCMethod)
+    {   
+        seqParams->RateControlMethod = RATECONTROL_CQL;
+        seqParams->ICQQualityFactor = vaEncMiscParamRC->quality_factor;
+        if (savedQualityFactor != seqParams->ICQQualityFactor)
+        {
+            if (savedQualityFactor != 0)
+            {
+                seqParams->SeqFlags.fields.ResetBRC |= 0x01;
+            }
+            savedQualityFactor = seqParams->ICQQualityFactor;
+        }
+    }
 
     /* the reset flag in RC will be considered. */
     seqParams->SeqFlags.fields.ResetBRC |= vaEncMiscParamRC->rc_flags.bits.reset;
@@ -1042,6 +1077,31 @@ VAStatus DdiEncodeAV1::CheckCDEF(const VAEncPictureParameterBufferAV1 *picParams
     return VA_STATUS_SUCCESS;
 }
 
+VAStatus DdiEncodeAV1::CheckTile(const VAEncPictureParameterBufferAV1 *picParams)
+{
+    int minTileHeightInSB = picParams->height_in_sbs_minus_1[0] + 1;
+    int minTileWidthInSB = picParams->width_in_sbs_minus_1[0] + 1;
+
+    for(int i = 1;i < picParams->tile_cols;i++)
+    {
+        minTileWidthInSB = MOS_MIN(minTileWidthInSB, picParams->width_in_sbs_minus_1[i] + 1);
+    }
+    for(int i = 1;i < picParams->tile_rows;i++)
+    {
+        minTileHeightInSB = MOS_MIN(minTileHeightInSB, picParams->height_in_sbs_minus_1[i] + 1);
+    }
+
+    if(minTileWidthInSB * minTileHeightInSB < 4 ||
+        minTileWidthInSB < 2 ||
+        minTileHeightInSB < 2)
+    {
+        DDI_CODEC_ASSERTMESSAGE("Unsupported Tile Size");
+        return VA_STATUS_ERROR_INVALID_PARAMETER;
+    }
+
+    return VA_STATUS_SUCCESS;
+}
+
 void DdiEncodeAV1::SetupCodecPicture(
     DDI_MEDIA_CONTEXT             *mediaCtx,
     DDI_CODEC_RENDER_TARGET_TABLE *rtTbl,
@@ -1094,10 +1154,10 @@ uint32_t DdiEncodeAV1::getSliceParameterBufferSize()
 }
 
 
-CODECHAL_FUNCTION DdiEncodeAV1::GetEncodeCodecFunction(VAProfile profile, VAEntrypoint entrypoint)
+CODECHAL_FUNCTION DdiEncodeAV1::GetEncodeCodecFunction(VAProfile profile, VAEntrypoint entrypoint, bool bVDEnc)
 {
     CODECHAL_FUNCTION codecFunction = CODECHAL_FUNCTION_INVALID;
-   if (entrypoint == VAEntrypointEncSliceLP)
+    if (bVDEnc)
     {
         codecFunction = CODECHAL_FUNCTION_ENC_VDENC_PAK;
     }
