@@ -574,13 +574,6 @@ VAStatus DdiEncodeAvc::ParseMiscParamQualityLevel(void *data)
         DDI_CODEC_ASSERTMESSAGE("Quality Level setting from application is not correct, should be in (0,%d].", TARGETUSAGE_BEST_SPEED);
     }
 
-#ifdef _FULL_OPEN_SOURCE
-    if (!GFX_IS_PRODUCT(m_encodeCtx->pMediaCtx->platform, IGFX_ICELAKE_LP) && m_encodeCtx->targetUsage <= 3)
-    {
-        m_encodeCtx->targetUsage = 4;
-    }
-#endif
-
     return VA_STATUS_SUCCESS;
 }
 
@@ -1196,7 +1189,7 @@ VAStatus DdiEncodeAvc::Qmatrix(void *ptr)
         return VA_STATUS_ERROR_INVALID_PARAMETER;
     }
 
-    MOS_SecureMemcpy((void *)&m_scalingLists8x8,
+    status = MOS_SecureMemcpy((void *)&m_scalingLists8x8,
         2 * 64 * sizeof(uint8_t),
         (void *)&qm->ScalingList8x8,
         2 * 64 * sizeof(uint8_t));
@@ -1371,9 +1364,10 @@ VAStatus DdiEncodeAvc::ParsePicParams(
 
     if (pic->CurrPic.picture_id != VA_INVALID_SURFACE)
     {
-        RegisterRTSurfaces(&(m_encodeCtx->RTtbl),
-            MediaLibvaCommonNext::GetSurfaceFromVASurfaceID(mediaCtx,
-                pic->CurrPic.picture_id));
+        DDI_CHK_RET(RegisterRTSurfaces(&(m_encodeCtx->RTtbl),
+                        MediaLibvaCommonNext::GetSurfaceFromVASurfaceID(mediaCtx,
+                            pic->CurrPic.picture_id)),
+                    "RegisterRTSurfaces failed!");
     }
 
     // Curr Recon Pic
@@ -1904,9 +1898,6 @@ MOS_STATUS DdiEncodeAvc::CheckPackedSlcHeaderData(
     *ppOutSlcHdr = NULL;
     OutBitSize = 0;
 
-    if (VAEntrypointEncSliceLP != m_encodeCtx->vaEntrypoint)
-        return MOS_STATUS_SUCCESS;
-
     if (0 == InBitSize || NULL == pInSlcHdr)
         return MOS_STATUS_SUCCESS;
 
@@ -2011,19 +2002,20 @@ VAStatus DdiEncodeAvc::ParsePackedHeaderData(void *ptr)
             bsBuffer->BufferSize - bsBuffer->SliceOffset,
             (uint8_t *)(temp_ptr ? temp_ptr : ptr),
             hdrDataSize);
-        if (MOS_STATUS_SUCCESS != status)
-        {
-            DDI_CODEC_ASSERTMESSAGE("DDI:packed slice header size is too large to be supported!");
-            return VA_STATUS_ERROR_INVALID_PARAMETER;
-        }
 
-        if (temp_size && temp_ptr)
+        if (temp_ptr)
         {
             MOS_FreeMemory(temp_ptr);
             temp_size = 0;
             temp_ptr = NULL;
         }
 
+        if (MOS_STATUS_SUCCESS != status)
+        {
+            DDI_CODEC_ASSERTMESSAGE("DDI:packed slice header size is too large to be supported!");
+            return VA_STATUS_ERROR_INVALID_PARAMETER;
+        }
+
         m_encodeCtx->pSliceHeaderData[m_encodeCtx->uiSliceHeaderCnt].SliceOffset = bsBuffer->pCurrent - bsBuffer->pBase;
 
         // correct SkipEmulationByteCount
@@ -2284,10 +2276,10 @@ void DdiEncodeAvc::ClearPicParams()
     }
 }
 
-CODECHAL_FUNCTION DdiEncodeAvc::GetEncodeCodecFunction(VAProfile profile, VAEntrypoint entrypoint)
+CODECHAL_FUNCTION DdiEncodeAvc::GetEncodeCodecFunction(VAProfile profile, VAEntrypoint entrypoint, bool bVDEnc)
 {
     CODECHAL_FUNCTION codecFunction = CODECHAL_FUNCTION_INVALID;
-   if (entrypoint == VAEntrypointEncSliceLP)
+    if (bVDEnc)
     {
         codecFunction = CODECHAL_FUNCTION_ENC_VDENC_PAK;
     }
