@@ -45,11 +45,11 @@
     (fourcc_mod_code(INTEL, (val)) | INTEL_PRELIM_ID_FLAG)
 
 /* this definition is to avoid duplicate drm_fourcc.h this file is updated seldom */
-#ifndef PRELIM_I915_FORMAT_MOD_4_TILED_MTL_MC_CCS
-#define PRELIM_I915_FORMAT_MOD_4_TILED_MTL_MC_CCS    intel_prelim_fourcc_mod_code(17)
+#ifndef I915_FORMAT_MOD_4_TILED_MTL_MC_CCS
+#define I915_FORMAT_MOD_4_TILED_MTL_MC_CCS    fourcc_mod_code(INTEL, 14)
 #endif
-#ifndef PRELIM_I915_FORMAT_MOD_4_TILED_MTL_RC_CCS
-#define PRELIM_I915_FORMAT_MOD_4_TILED_MTL_RC_CCS    intel_prelim_fourcc_mod_code(16)
+#ifndef I915_FORMAT_MOD_4_TILED_MTL_RC_CCS_CC
+#define I915_FORMAT_MOD_4_TILED_MTL_RC_CCS_CC    fourcc_mod_code(INTEL, 15)
 #endif
 
 // default protected surface tag
@@ -69,7 +69,7 @@ VAStatus MediaLibvaUtilNext::SetDefaultTileFormat(
     )
 {
     VAStatus status        = VA_STATUS_SUCCESS;
-    uint32_t tileFormat    = I915_TILING_Y;
+    uint32_t tileFormat    = TILING_Y;
     DDI_FUNC_ENTER;
     DDI_CHK_NULL(skuTable, "skuTable is nullptr", VA_STATUS_ERROR_INVALID_PARAMETER);
 
@@ -93,7 +93,7 @@ VAStatus MediaLibvaUtilNext::SetDefaultTileFormat(
             if (VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER != surfaceUsageHint   &&
                 !(surfaceUsageHint & VA_SURFACE_ATTRIB_USAGE_HINT_VPP_WRITE))
             {
-                tileFormat = I915_TILING_NONE;
+                tileFormat = TILING_NONE;
             }
             break;
         case Media_Format_RGBP:
@@ -103,7 +103,7 @@ VAStatus MediaLibvaUtilNext::SetDefaultTileFormat(
             {
                 if(!(surfaceUsageHint & VA_SURFACE_ATTRIB_USAGE_HINT_DECODER))
                 {
-                    tileFormat = I915_TILING_NONE;
+                    tileFormat = TILING_NONE;
                     break;
                 }
                 //Planar type surface align 32 to improve performance.
@@ -118,7 +118,7 @@ VAStatus MediaLibvaUtilNext::SetDefaultTileFormat(
                     params.alignedHeight = MOS_ALIGN_CEIL(params.height, 32);
                 }
             }
-            tileFormat = I915_TILING_Y;
+            tileFormat = TILING_Y;
             break;
         case Media_Format_A8R8G8B8:
             if (VA_SURFACE_ATTRIB_USAGE_HINT_ENCODER != surfaceUsageHint     &&
@@ -127,7 +127,7 @@ VAStatus MediaLibvaUtilNext::SetDefaultTileFormat(
                 !(MEDIA_IS_SKU(skuTable, FtrRenderCompressionOnly)           &&
                   MEDIA_IS_SKU(skuTable, FtrE2ECompression)))
             {
-                tileFormat = I915_TILING_NONE;
+                tileFormat = TILING_NONE;
             }
             break;
         case Media_Format_NV12:
@@ -177,13 +177,13 @@ VAStatus MediaLibvaUtilNext::SetDefaultTileFormat(
                     params.alignedHeight = MOS_ALIGN_CEIL(params.height, 32);
                 }
             }
-            tileFormat = I915_TILING_Y;
+            tileFormat = TILING_Y;
             break;
         case Media_Format_Buffer:
-            tileFormat = I915_TILING_NONE;
+            tileFormat = TILING_NONE;
             break;
         default:
-            tileFormat = I915_TILING_NONE;
+            tileFormat = TILING_NONE;
             DDI_ASSERTMESSAGE("Unsupported format");
             status = VA_STATUS_ERROR_UNSUPPORTED_RT_FORMAT;
     }
@@ -207,7 +207,7 @@ void MediaLibvaUtilNext::InitSurfaceAllocateParams(
 {
     DDI_FUNC_ENTER;
     params.pitch          = 0;
-    params.tileFormat     = I915_TILING_NONE;
+    params.tileFormat     = TILING_NONE;
     params.alignedWidth   = params.width = width;
     params.alignedHeight  = params.height = height;
     params.format         = format;
@@ -230,39 +230,39 @@ VAStatus MediaLibvaUtilNext::SetSurfaceParameterFromModifier(
     switch (modifier)
     {
         case I915_FORMAT_MOD_4_TILED:
-            params.tileFormat = I915_TILING_Y;
+            params.tileFormat = TILING_Y;
             params.bMemCompEnable = false;
             break;
-        case PRELIM_I915_FORMAT_MOD_4_TILED_MTL_RC_CCS:
-            params.tileFormat = I915_TILING_Y;
+        case I915_FORMAT_MOD_4_TILED_MTL_RC_CCS_CC:
+            params.tileFormat = TILING_Y;
             params.bMemCompEnable = true;
             params.bMemCompRC = true;
             break;
-        case PRELIM_I915_FORMAT_MOD_4_TILED_MTL_MC_CCS:
-            params.tileFormat = I915_TILING_Y;
+        case I915_FORMAT_MOD_4_TILED_MTL_MC_CCS:
+            params.tileFormat = TILING_Y;
             params.bMemCompEnable = true;
             params.bMemCompRC = false;
             break;
         case DRM_FORMAT_MOD_LINEAR:
-            params.tileFormat = I915_TILING_NONE;
+            params.tileFormat = TILING_NONE;
             params.bMemCompEnable = false;
             break;
         case I915_FORMAT_MOD_X_TILED:
-            params.tileFormat = I915_TILING_X;
+            params.tileFormat = TILING_X;
             params.bMemCompEnable = false;
             break;
         case I915_FORMAT_MOD_Y_TILED:
         case I915_FORMAT_MOD_Yf_TILED:
-            params.tileFormat = I915_TILING_Y;
+            params.tileFormat = TILING_Y;
             params.bMemCompEnable = false;
             break;
         case I915_FORMAT_MOD_Y_TILED_GEN12_RC_CCS:
-            params.tileFormat = I915_TILING_Y;
+            params.tileFormat = TILING_Y;
             params.bMemCompEnable = true;
             params.bMemCompRC = true;
             break;
         case I915_FORMAT_MOD_Y_TILED_GEN12_MC_CCS:
-            params.tileFormat = I915_TILING_Y;
+            params.tileFormat = TILING_Y;
             params.bMemCompEnable = true;
             params.bMemCompRC = false;
             break;
@@ -306,7 +306,20 @@ VAStatus MediaLibvaUtilNext::GenerateGmmParamsForNoneCompressionExternalSurface(
     MosUtilities::MosZeroMemory(&gmmCustomParams, sizeof(gmmCustomParams));
     gmmCustomParams.Type          = RESOURCE_2D;
     gmmCustomParams.Format        = ConvertMediaFmtToGmmFmt(params.format);
-    gmmCustomParams.BaseWidth64   = params.width;
+    if ((params.format == Media_Format_YV12) || \
+        (params.format == Media_Format_I420) || \
+        (params.format == Media_Format_IYUV) || \
+        (params.format == Media_Format_NV12) || \
+        (params.format == Media_Format_P010) || \
+        (params.format == Media_Format_P012) || \
+        (params.format == Media_Format_P016) || \
+        (params.format == Media_Format_NV21)) {
+        // Align width to 2 for specific planar formats to handle
+        // odd dimensions for external non-compressible surfaces
+        gmmCustomParams.BaseWidth64 = MOS_ALIGN_CEIL(params.width, 2);
+    } else {
+        gmmCustomParams.BaseWidth64 = params.width;
+    }
     gmmCustomParams.BaseHeight    = baseHeight;
     gmmCustomParams.Pitch         = params.pitch;
     gmmCustomParams.Size          = mediaSurface->pSurfDesc->uiSize;
@@ -315,13 +328,13 @@ VAStatus MediaLibvaUtilNext::GenerateGmmParamsForNoneCompressionExternalSurface(
     gmmCustomParams.CpTag         = params.cpTag;
     switch (params.tileFormat)
     {
-        case I915_TILING_Y:
+        case TILING_Y:
             gmmCustomParams.Flags.Info.TiledY = true;
             break;
-        case I915_TILING_X:
+        case TILING_X:
             gmmCustomParams.Flags.Info.TiledX = true;
             break;
-        case I915_TILING_NONE:
+        case TILING_NONE:
         default:
             gmmCustomParams.Flags.Info.Linear = true;
     }
@@ -369,48 +382,62 @@ VAStatus MediaLibvaUtilNext::GenerateGmmParamsForNoneCompressionExternalSurface(
 }
 
 VAStatus MediaLibvaUtilNext::GenerateGmmParamsForCompressionExternalSurface(
-    GMM_RESCREATE_PARAMS         &gmmParams,
+    GMM_RESCREATE_CUSTOM_PARAMS_2 &gmmCustomParams,
     MEDIA_SURFACE_ALLOCATE_PARAM &params,
+    PDDI_MEDIA_SURFACE           mediaSurface,
     PDDI_MEDIA_CONTEXT           mediaDrvCtx)
 {
     DDI_FUNC_ENTER;
+    DDI_CHK_NULL(mediaSurface,            "mediaSurface is nullptr",      VA_STATUS_ERROR_INVALID_BUFFER);
+    DDI_CHK_NULL(mediaSurface->pSurfDesc, "mediaSurface desc is nullptr", VA_STATUS_ERROR_INVALID_BUFFER);
     DDI_CHK_NULL(mediaDrvCtx, "media context is nullptr", VA_STATUS_ERROR_INVALID_CONTEXT);
-
-    MosUtilities::MosZeroMemory(&gmmParams, sizeof(gmmParams));
-    gmmParams.BaseWidth         = params.width;
-    gmmParams.BaseHeight        = params.height;
-    gmmParams.ArraySize         = 1;
-    gmmParams.Type              = RESOURCE_2D;
-    gmmParams.CpTag             = params.cpTag;
-    gmmParams.Format            = ConvertMediaFmtToGmmFmt(params.format);
-
-    DDI_CHK_CONDITION(gmmParams.Format == GMM_FORMAT_INVALID, "Unsupported format", VA_STATUS_ERROR_UNSUPPORTED_RT_FORMAT);
-
+    // Create GmmResourceInfo
+    MOS_ZeroMemory(&gmmCustomParams, sizeof(gmmCustomParams));
+    gmmCustomParams.Type          = RESOURCE_2D;
+    gmmCustomParams.Format        = ConvertMediaFmtToGmmFmt(params.format);
+    if ((params.format == Media_Format_YV12) || \
+        (params.format == Media_Format_I420) || \
+        (params.format == Media_Format_IYUV) || \
+        (params.format == Media_Format_NV12) || \
+        (params.format == Media_Format_NV21)) {
+        // Align width to 2 for specific planar formats to handle
+        // odd dimensions for external non-compressible surfaces
+        gmmCustomParams.BaseWidth64 = MOS_ALIGN_CEIL(params.alignedWidth, 2);
+    } else {
+        gmmCustomParams.BaseWidth64 = params.alignedWidth;
+    }
+    gmmCustomParams.BaseHeight    = params.alignedHeight;
+    gmmCustomParams.Pitch         = params.pitch;
+    gmmCustomParams.Size          = mediaSurface->pSurfDesc->uiSize;
+    gmmCustomParams.BaseAlignment = 4096;
+    gmmCustomParams.NoOfPlanes    = mediaSurface->pSurfDesc->uiPlanes;
+    gmmCustomParams.CpTag         = params.cpTag;
     switch (params.tileFormat)
     {
         case I915_TILING_Y:
-            gmmParams.Flags.Gpu.MMC   = false;
-            if (MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrE2ECompression)  &&
-                (!MEDIA_IS_WA(&mediaDrvCtx->WaTable, WaDisableVPMmc)     &&
-                !MEDIA_IS_WA(&mediaDrvCtx->WaTable,  WaDisableCodecMmc)) &&
+            gmmCustomParams.Flags.Info.TiledY = true;
+            gmmCustomParams.Flags.Gpu.MMC    = false;
+            if (MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrE2ECompression) &&
+                (!MEDIA_IS_WA(&mediaDrvCtx->WaTable, WaDisableVPMmc)    &&
+                !MEDIA_IS_WA(&mediaDrvCtx->WaTable, WaDisableCodecMmc)) &&
                 params.bMemCompEnable)
             {
-                gmmParams.Flags.Gpu.MMC               = true;
-                gmmParams.Flags.Info.MediaCompressed  = 1;
-                gmmParams.Flags.Info.RenderCompressed = 0;
-                gmmParams.Flags.Gpu.CCS               = 1;
-                gmmParams.Flags.Gpu.RenderTarget      = 1;
-                gmmParams.Flags.Gpu.UnifiedAuxSurface = 1;
+                gmmCustomParams.Flags.Gpu.MMC               = true;
+                gmmCustomParams.Flags.Info.MediaCompressed  = 1;
+                gmmCustomParams.Flags.Info.RenderCompressed = 0;
+                gmmCustomParams.Flags.Gpu.CCS               = 1;
+                gmmCustomParams.Flags.Gpu.RenderTarget      = 1;
+                gmmCustomParams.Flags.Gpu.UnifiedAuxSurface = 1;
 
                 if (params.bMemCompRC)
                 {
-                    gmmParams.Flags.Info.MediaCompressed  = 0;
-                    gmmParams.Flags.Info.RenderCompressed = 1;
+                    gmmCustomParams.Flags.Info.MediaCompressed  = 0;
+                    gmmCustomParams.Flags.Info.RenderCompressed = 1;
                 }
 
                 if(MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrRenderCompressionOnly))
                 {
-                    gmmParams.Flags.Info.MediaCompressed = 0;
+                    gmmCustomParams.Flags.Info.MediaCompressed = 0;
 
                     if (params.format == Media_Format_X8R8G8B8 ||
                         params.format == Media_Format_X8B8G8R8 ||
@@ -418,26 +445,80 @@ VAStatus MediaLibvaUtilNext::GenerateGmmParamsForCompressionExternalSurface(
                         params.format == Media_Format_A8R8G8B8 ||
                         params.format == Media_Format_R8G8B8A8)
                     {
-                        gmmParams.Flags.Info.MediaCompressed  = 0;
-                        gmmParams.Flags.Info.RenderCompressed = 1;
+                        gmmCustomParams.Flags.Info.MediaCompressed  = 0;
+                        gmmCustomParams.Flags.Info.RenderCompressed = 1;
                     }
                 }
 
                 if(MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrFlatPhysCCS))
                 {
-                    gmmParams.Flags.Gpu.UnifiedAuxSurface = 0;
+                    gmmCustomParams.Flags.Gpu.UnifiedAuxSurface = 0;
                 }
             }
             break;
         case I915_TILING_X:
-            gmmParams.Flags.Info.TiledX    = true;
+            gmmCustomParams.Flags.Info.TiledX = true;
             break;
         case I915_TILING_NONE:
         default:
-            gmmParams.Flags.Info.Linear    = true;
+            gmmCustomParams.Flags.Info.Linear = true;
+    }
+
+        gmmCustomParams.AuxSurf.BaseAlignment = {0};
+        gmmCustomParams.NoOfPlanes = mediaSurface->pSurfDesc->uiPlanes/2;
+        gmmCustomParams.Size = (gmmCustomParams.NoOfPlanes == 1) ? mediaSurface->pSurfDesc->uiOffsets[1]:mediaSurface->pSurfDesc->uiOffsets[2];
+    switch(gmmCustomParams.NoOfPlanes)
+    {
+        case 1:
+            gmmCustomParams.PlaneOffset.X[GMM_PLANE_Y] = 0;
+            gmmCustomParams.PlaneOffset.Y[GMM_PLANE_Y] = mediaSurface->pSurfDesc->uiOffsets[0] / params.pitch;
+            gmmCustomParams.AuxSurf.Size = mediaSurface->pSurfDesc->uiSize - gmmCustomParams.Size;
+            gmmCustomParams.AuxSurf.Pitch = mediaSurface->pSurfDesc->uiPitches[1];
+            gmmCustomParams.AuxSurf.PlaneOffset.X[GMM_PLANE_Y] = 0;
+            gmmCustomParams.AuxSurf.PlaneOffset.Y[GMM_PLANE_Y] = 0;
+            break;
+        case 2:
+            gmmCustomParams.PlaneOffset.X[GMM_PLANE_Y] = 0;
+            gmmCustomParams.PlaneOffset.Y[GMM_PLANE_Y] = mediaSurface->pSurfDesc->uiOffsets[0] / params.pitch;
+            gmmCustomParams.PlaneOffset.X[GMM_PLANE_U] = 0;
+            gmmCustomParams.PlaneOffset.Y[GMM_PLANE_U] = mediaSurface->pSurfDesc->uiOffsets[1] / params.pitch;
+            gmmCustomParams.PlaneOffset.X[GMM_PLANE_V] = 0;
+            gmmCustomParams.PlaneOffset.Y[GMM_PLANE_V] = mediaSurface->pSurfDesc->uiOffsets[1] / params.pitch;
+            gmmCustomParams.AuxSurf.Size = (mediaSurface->pSurfDesc->uiOffsets[3] - mediaSurface->pSurfDesc->uiOffsets[2]) * 2;
+            gmmCustomParams.AuxSurf.Pitch = mediaSurface->pSurfDesc->uiPitches[2];
+            gmmCustomParams.AuxSurf.PlaneOffset.X[GMM_PLANE_Y] = 0;
+            gmmCustomParams.AuxSurf.PlaneOffset.Y[GMM_PLANE_Y] = 0;
+            gmmCustomParams.AuxSurf.PlaneOffset.X[GMM_PLANE_U] = (mediaSurface->pSurfDesc->uiOffsets[3]
+                                                            - mediaSurface->pSurfDesc->uiOffsets[2]);
+            gmmCustomParams.AuxSurf.PlaneOffset.Y[GMM_PLANE_U] = 0;
+            gmmCustomParams.AuxSurf.PlaneOffset.X[GMM_PLANE_V] = (mediaSurface->pSurfDesc->uiOffsets[3]
+                                                            - mediaSurface->pSurfDesc->uiOffsets[2]);
+            gmmCustomParams.AuxSurf.PlaneOffset.Y[GMM_PLANE_V] = 0;
+            break;
+        case 3:
+            if (mediaSurface->format == Media_Format_YV12)
+            {
+                gmmCustomParams.PlaneOffset.X[GMM_PLANE_Y] = 0;
+                gmmCustomParams.PlaneOffset.Y[GMM_PLANE_Y] = mediaSurface->pSurfDesc->uiOffsets[0] / params.pitch;
+                gmmCustomParams.PlaneOffset.X[GMM_PLANE_U] = 0;
+                gmmCustomParams.PlaneOffset.Y[GMM_PLANE_U] = mediaSurface->pSurfDesc->uiOffsets[2] / params.pitch;
+                gmmCustomParams.PlaneOffset.X[GMM_PLANE_V] = 0;
+                gmmCustomParams.PlaneOffset.Y[GMM_PLANE_V] = mediaSurface->pSurfDesc->uiOffsets[1] / params.pitch;
+            }
+            else
+            {
+                gmmCustomParams.PlaneOffset.X[GMM_PLANE_Y] = 0;
+                gmmCustomParams.PlaneOffset.Y[GMM_PLANE_Y] = mediaSurface->pSurfDesc->uiOffsets[0] / params.pitch;
+                gmmCustomParams.PlaneOffset.X[GMM_PLANE_U] = 0;
+                gmmCustomParams.PlaneOffset.Y[GMM_PLANE_U] = mediaSurface->pSurfDesc->uiOffsets[1] / params.pitch;
+                gmmCustomParams.PlaneOffset.X[GMM_PLANE_V] = 0;
+                gmmCustomParams.PlaneOffset.Y[GMM_PLANE_V] = mediaSurface->pSurfDesc->uiOffsets[2] / params.pitch;
+            }
+            break;
+        default:
+            DDI_ASSERTMESSAGE("Invalid plane number.");
+            return VA_STATUS_ERROR_ALLOCATION_FAILED;
     }
-    gmmParams.Flags.Gpu.Video = true;
-    gmmParams.Flags.Info.LocalOnly = MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrLocalMemory);
 
     return VA_STATUS_SUCCESS;
 }
@@ -469,22 +550,25 @@ VAStatus MediaLibvaUtilNext::CreateExternalSurface(
     switch (mediaSurface->pSurfDesc->uiVaMemType)
     {
         case VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM:
-            bo = mos_bo_gem_create_from_name(mediaDrvCtx->pDrmBufMgr, "MEDIA", mediaSurface->pSurfDesc->ulBuffer);
+            bo = mos_bo_create_from_name(mediaDrvCtx->pDrmBufMgr, "MEDIA", mediaSurface->pSurfDesc->ulBuffer);
             break;
         case VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME:
-            bo = mos_bo_gem_create_from_prime(mediaDrvCtx->pDrmBufMgr, mediaSurface->pSurfDesc->ulBuffer, mediaSurface->pSurfDesc->uiSize);
+            bo = mos_bo_create_from_prime(mediaDrvCtx->pDrmBufMgr, mediaSurface->pSurfDesc->ulBuffer, mediaSurface->pSurfDesc->uiSize);
             break;
         case VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2:
-            bo = mos_bo_gem_create_from_prime(mediaDrvCtx->pDrmBufMgr, mediaSurface->pSurfDesc->ulBuffer, mediaSurface->pSurfDesc->uiSize);
+            bo = mos_bo_create_from_prime(mediaDrvCtx->pDrmBufMgr, mediaSurface->pSurfDesc->ulBuffer, mediaSurface->pSurfDesc->uiSize);
             break;
         case VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR:
-#ifdef DRM_IOCTL_I915_GEM_USERPTR
-            bo = mos_bo_alloc_userptr(mediaDrvCtx->pDrmBufMgr, "SysSurface", (void *)mediaSurface->pSurfDesc->ulBuffer, mediaSurface->pSurfDesc->uiTile,
-                                      params.pitch, mediaSurface->pSurfDesc->uiBuffserSize, I915_USERPTR_UNSYNCHRONIZED);
-#else
-            bo = mos_bo_alloc_vmap(mediaDrvCtx->pDrmBufMgr, "SysSurface", (void *)mediaSurface->pSurfDesc->ulBuffer, mediaSurface->pSurfDesc->uiTile,
-                                   params.pitch, mediaSurface->pSurfDesc->uiBuffserSize, 0);
-#endif
+        {
+            struct mos_drm_bo_alloc_userptr alloc_uptr;
+            alloc_uptr.name = "SysSurface";
+            alloc_uptr.addr = (void *)mediaSurface->pSurfDesc->ulBuffer;
+            alloc_uptr.tiling_mode = mediaSurface->pSurfDesc->uiTile;
+            alloc_uptr.stride = params.pitch;
+            alloc_uptr.size = mediaSurface->pSurfDesc->uiBuffserSize;
+
+            bo = mos_bo_alloc_userptr(mediaDrvCtx->pDrmBufMgr, &alloc_uptr);
+        }
             break;
         default:
             DDI_ASSERTMESSAGE("Unsupported external surface memory type.");
@@ -500,7 +584,7 @@ VAStatus MediaLibvaUtilNext::CreateExternalSurface(
             mos_bo_get_tiling(bo, &params.tileFormat, &swizzle_mode);
             if(params.tileFormat == 0)
             {
-                params.tileFormat = mediaSurface->pSurfDesc->uiFlags & VA_SURFACE_EXTBUF_DESC_ENABLE_TILING ? I915_TILING_Y : I915_TILING_NONE;
+                params.tileFormat = mediaSurface->pSurfDesc->uiFlags & VA_SURFACE_EXTBUF_DESC_ENABLE_TILING ? TILING_Y : TILING_NONE;
             }
             break;
         case VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2:
@@ -528,14 +612,14 @@ VAStatus MediaLibvaUtilNext::CreateExternalSurface(
 
     if (params.bMemCompEnable)
     {
-        GMM_RESCREATE_PARAMS gmmParams = {};
-        status = GenerateGmmParamsForCompressionExternalSurface(gmmParams, params, mediaDrvCtx);
+        GMM_RESCREATE_CUSTOM_PARAMS_2 gmmParams = {};
+        status = GenerateGmmParamsForCompressionExternalSurface(gmmParams, params, mediaSurface, mediaDrvCtx);
         if(status != VA_STATUS_SUCCESS)
         {
             DDI_ASSERTMESSAGE("Generate gmmParams for compression external surface failed.");
             return status;
         }
-        gmmResourceInfo = mediaDrvCtx->pGmmClientContext->CreateResInfoObject(&gmmParams);
+        gmmResourceInfo = mediaDrvCtx->pGmmClientContext->CreateCustomResInfoObject_2(&gmmParams);
     }
     else
     {
@@ -561,7 +645,7 @@ VAStatus MediaLibvaUtilNext::CreateExternalSurface(
     mediaSurface->iRefCount        = 0;
     mediaSurface->bo               = bo;
     mediaSurface->TileType         = params.tileFormat;
-    mediaSurface->isTiled          = (params.tileFormat != I915_TILING_NONE) ? 1 : 0;
+    mediaSurface->isTiled          = (params.tileFormat != TILING_NONE) ? 1 : 0;
     mediaSurface->pData            = (uint8_t*) bo->virt;
     DDI_VERBOSEMESSAGE("Allocate external surface %7d bytes (%d x %d resource).", mediaSurface->pSurfDesc->uiSize, params.width, params.height);
     uint32_t event[] = {bo->handle, params.format, params.width, params.height, params.pitch, bo->size, params.tileFormat, params.cpTag};
@@ -589,7 +673,7 @@ VAStatus MediaLibvaUtilNext::GenerateGmmParamsForInternalSurface(
 
     switch (params.tileFormat)
     {
-        case I915_TILING_Y:
+        case TILING_Y:
             // Disable MMC for application required surfaces, because some cases' output streams have corruption.
             gmmParams.Flags.Gpu.MMC    = false;
             if (MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrE2ECompression)             &&
@@ -634,8 +718,17 @@ VAStatus MediaLibvaUtilNext::GenerateGmmParamsForInternalSurface(
                     }
                 }
             }
+            // For ARGB surface, always allocate it as tile4.
+            // This is a WA for ExportSurfaceHandle because modifer for tile64 isn't defined.
+            if ((params.format == Media_Format_A8R8G8B8 || 
+                params.format == Media_Format_B10G10R10A2 || 
+                params.format == Media_Format_A8B8G8R8 ||
+                params.format == Media_Format_X8R8G8B8) && !MEDIA_IS_SKU(&mediaDrvCtx->SkuTable, FtrTileY))
+            {
+                gmmParams.Flags.Info.Tile4 = true;
+            }
             break;
-        case I915_TILING_X:
+        case TILING_X:
             gmmParams.Flags.Info.TiledX    = true;
             break;
         default:
@@ -665,11 +758,11 @@ VAStatus MediaLibvaUtilNext::CreateInternalSurface(
     {
         if (mediaSurface->pSurfDesc->uiFlags & VA_SURFACE_EXTBUF_DESC_ENABLE_TILING )
         {
-            params.tileFormat = I915_TILING_Y;
+            params.tileFormat = TILING_Y;
         }
         else if (mediaSurface->pSurfDesc->uiVaMemType == VA_SURFACE_ATTRIB_MEM_TYPE_VA)
         {
-            params.tileFormat = I915_TILING_NONE;
+            params.tileFormat = TILING_NONE;
             params.alignedHeight = params.height;
         }
     }
@@ -697,16 +790,16 @@ VAStatus MediaLibvaUtilNext::CreateInternalSurface(
     switch (gmmResourceInfo->GetTileType())
     {
         case GMM_TILED_Y:
-            params.tileFormat = I915_TILING_Y;
+            params.tileFormat = TILING_Y;
             break;
         case GMM_TILED_X:
-            params.tileFormat = I915_TILING_X;
+            params.tileFormat = TILING_X;
             break;
         case GMM_NOT_TILED:
-            params.tileFormat = I915_TILING_NONE;
+            params.tileFormat = TILING_NONE;
             break;
         default:
-            params.tileFormat = I915_TILING_Y;
+            params.tileFormat = TILING_Y;
             break;
     }
 
@@ -721,17 +814,36 @@ VAStatus MediaLibvaUtilNext::CreateInternalSurface(
 
     params.memType = MemoryPolicyManager::UpdateMemoryPolicy(&memPolicyPar);
 
-    if ( params.tileFormat == I915_TILING_NONE )
+    unsigned int patIndex = MosInterface::GetPATIndexFromGmm(mediaDrvCtx->pGmmClientContext, gmmResourceInfo);
+    bool isCpuCacheable   = gmmResourceInfo->GetResFlags().Info.Cacheable;
+
+    if ( params.tileFormat == TILING_NONE )
     {
-        bo = mos_bo_alloc(mediaDrvCtx->pDrmBufMgr, "MEDIA", gmmSize, 4096, params.memType);
+        struct mos_drm_bo_alloc alloc;
+        alloc.name = "Media";
+        alloc.size = gmmSize;
+        alloc.alignment = 4096;
+        alloc.ext.tiling_mode = TILING_NONE;
+        alloc.ext.mem_type = params.memType;
+        alloc.ext.pat_index = patIndex;
+        alloc.ext.cpu_cacheable = isCpuCacheable;
+        bo = mos_bo_alloc(mediaDrvCtx->pDrmBufMgr, &alloc);
         params.pitch = gmmPitch;
     }
     else
     {
-        unsigned long  ulPitch = 0;
-        bo = mos_bo_alloc_tiled(mediaDrvCtx->pDrmBufMgr, "MEDIA", gmmPitch, (gmmSize + gmmPitch -1)/gmmPitch, 1, &params.tileFormat, 
-            (unsigned long *)&ulPitch, 0, params.memType);
-        params.pitch = ulPitch;
+        struct mos_drm_bo_alloc_tiled alloc_tiled;
+        alloc_tiled.name = "MEDIA";
+        alloc_tiled.x = gmmPitch;
+        alloc_tiled.y = (gmmSize + gmmPitch -1)/gmmPitch;
+        alloc_tiled.cpp = 1;
+        alloc_tiled.ext.tiling_mode = params.tileFormat;
+        alloc_tiled.ext.mem_type = params.memType;;
+        alloc_tiled.ext.pat_index = patIndex;
+        alloc_tiled.ext.cpu_cacheable = isCpuCacheable;
+
+        bo = mos_bo_alloc_tiled(mediaDrvCtx->pDrmBufMgr, &alloc_tiled);
+        params.pitch = alloc_tiled.pitch;
     }
 
     mediaSurface->bMapped = false;
@@ -745,7 +857,7 @@ VAStatus MediaLibvaUtilNext::CreateInternalSurface(
     mediaSurface->iRefCount   = 0;
     mediaSurface->bo          = bo;
     mediaSurface->TileType    = params.tileFormat;
-    mediaSurface->isTiled     = (params.tileFormat != I915_TILING_NONE) ? 1 : 0;
+    mediaSurface->isTiled     = (params.tileFormat != TILING_NONE) ? 1 : 0;
     mediaSurface->pData       = (uint8_t*) bo->virt;
     DDI_VERBOSEMESSAGE("Alloc %7d bytes (%d x %d resource, gmmTiledType %d)).",gmmSize, params.width, params.height, gmmResourceInfo->GetTileType());
     uint32_t event[] = {bo->handle, params.format, params.width, params.height, params.pitch, bo->size, params.tileFormat, params.cpTag};
@@ -1141,11 +1253,11 @@ void* MediaLibvaUtilNext::LockSurfaceInternal(DDI_MEDIA_SURFACE  *surface, uint3
 
     if (surface->pMediaCtx->bIsAtomSOC)
     {
-        mos_gem_bo_map_gtt(surface->bo);
+        mos_bo_map_gtt(surface->bo);
     }
     else
     {
-        if (surface->TileType == I915_TILING_NONE)
+        if (surface->TileType == TILING_NONE)
         {
             mos_bo_map(surface->bo, flag & MOS_LOCKFLAG_WRITEONLY);
         }
@@ -1154,7 +1266,7 @@ void* MediaLibvaUtilNext::LockSurfaceInternal(DDI_MEDIA_SURFACE  *surface, uint3
             DDI_CHK_NULL(surface->pGmmResourceInfo, "nullptr surface->pGmmResourceInfo", nullptr);
 
             surfSize = surface->pGmmResourceInfo->GetSizeMainSurface();
-            DDI_CHK_CONDITION((surface->TileType != I915_TILING_Y), "Unsupported tile type", nullptr);
+            DDI_CHK_CONDITION((surface->TileType != TILING_Y), "Unsupported tile type", nullptr);
             DDI_CHK_CONDITION((surfSize <= 0 || surface->iPitch <= 0), "Invalid surface size or pitch", nullptr);
 
             if (MEDIA_IS_SKU(&surface->pMediaCtx->SkuTable, FtrLocalMemory))
@@ -1207,12 +1319,12 @@ void* MediaLibvaUtilNext::LockSurfaceInternal(DDI_MEDIA_SURFACE  *surface, uint3
         }
         else if (flag & MOS_LOCKFLAG_WRITEONLY)
         {
-            mos_gem_bo_map_gtt(surface->bo);
+            mos_bo_map_gtt(surface->bo);
         }
         else
         {
-            mos_gem_bo_map_unsynchronized(surface->bo);     // only call mmap_gtt ioctl
-            mos_gem_bo_start_gtt_access(surface->bo, 0);    // set to GTT domain,0 means readonly
+            mos_bo_map_unsynchronized(surface->bo);     // only call mmap_gtt ioctl
+            mos_bo_start_gtt_access(surface->bo, 0);    // set to GTT domain,0 means readonly
         }
     }
     surface->uiMapFlag = flag;
@@ -1248,11 +1360,11 @@ void MediaLibvaUtilNext::UnlockSurface(DDI_MEDIA_SURFACE  *surface)
     {
         if (surface->pMediaCtx->bIsAtomSOC)
         {
-            mos_gem_bo_unmap_gtt(surface->bo);
+            mos_bo_unmap_gtt(surface->bo);
         }
         else
         {
-            if (surface->TileType == I915_TILING_NONE)
+            if (surface->TileType == TILING_NONE)
             {
                mos_bo_unmap(surface->bo);
             }
@@ -1287,7 +1399,7 @@ void MediaLibvaUtilNext::UnlockSurface(DDI_MEDIA_SURFACE  *surface)
             }
             else
             {
-               mos_gem_bo_unmap_gtt(surface->bo);
+               mos_bo_unmap_gtt(surface->bo);
             }
         }
         surface->pData       = nullptr;
@@ -1352,17 +1464,17 @@ void* MediaLibvaUtilNext::LockBuffer(DDI_MEDIA_BUFFER *buf, uint32_t flag)
         {
             if (buf->pMediaCtx->bIsAtomSOC)
             {
-                mos_gem_bo_map_gtt(buf->bo);
+                mos_bo_map_gtt(buf->bo);
             }
             else
             {
-                if (buf->TileType == I915_TILING_NONE)
+                if (buf->TileType == TILING_NONE)
                 {
                     mos_bo_map(buf->bo, ((MOS_LOCKFLAG_READONLY | MOS_LOCKFLAG_WRITEONLY) & flag));
                 }
                 else
                 {
-                    mos_gem_bo_map_gtt(buf->bo);
+                    mos_bo_map_gtt(buf->bo);
                 }
              }
 
@@ -1403,17 +1515,17 @@ void MediaLibvaUtilNext::UnlockBuffer(DDI_MEDIA_BUFFER *buf)
         {
              if (buf->pMediaCtx->bIsAtomSOC)
              {
-                 mos_gem_bo_unmap_gtt(buf->bo);
+                 mos_bo_unmap_gtt(buf->bo);
              }
              else
              {
-                 if (buf->TileType == I915_TILING_NONE)
+                 if (buf->TileType == TILING_NONE)
                  {
                      mos_bo_unmap(buf->bo);
                  }
                  else
                  {
-                     mos_gem_bo_unmap_gtt(buf->bo);
+                     mos_bo_unmap_gtt(buf->bo);
                  }
             }
             buf->bo->virt = nullptr;
@@ -1544,8 +1656,8 @@ VAStatus MediaLibvaUtilNext::SwizzleSurfaceByHW(DDI_MEDIA_SURFACE *surface, bool
             &mosCtx,
             &source,
             &target,
-            surface->iWidth,
-            surface->iRealHeight,
+            surface->pGmmResourceInfo->GetBaseWidth(),
+            surface->pGmmResourceInfo->GetBaseHeight(),
             0,
             0,
             !isDeSwizzle,
@@ -1599,7 +1711,7 @@ VAStatus MediaLibvaUtilNext::Allocate2DBuffer(
     DDI_CHK_NULL(mediaBuffer->pMediaCtx->pGmmClientContext, "mediaBuffer->pMediaCtx->pGmmClientContext is nullptr", VA_STATUS_ERROR_INVALID_BUFFER);
 
     int32_t  size           = 0;
-    uint32_t tileformat     = I915_TILING_NONE;
+    uint32_t tileformat     = TILING_NONE;
     VAStatus hRes           = VA_STATUS_SUCCESS;
     int32_t  mem_type       = MOS_MEMPOOL_VIDEOMEMORY;
 
@@ -1645,8 +1757,20 @@ VAStatus MediaLibvaUtilNext::Allocate2DBuffer(
 
     mem_type = MemoryPolicyManager::UpdateMemoryPolicy(&memPolicyPar);
 
+    unsigned int patIndex = MosInterface::GetPATIndexFromGmm(mediaBuffer->pMediaCtx->pGmmClientContext, gmmResourceInfo);
+    bool isCpuCacheable   = gmmResourceInfo->GetResFlags().Info.Cacheable;
+
     MOS_LINUX_BO  *bo;
-    bo = mos_bo_alloc(bufmgr, "Media 2D Buffer", gmmSize, 4096, mem_type);
+    struct mos_drm_bo_alloc alloc;
+    alloc.name = "Media 2D Buffer";
+    alloc.size = gmmSize;
+    alloc.alignment = 4096;
+    alloc.ext.tiling_mode = TILING_NONE;
+    alloc.ext.mem_type = mem_type;
+    alloc.ext.pat_index = patIndex;
+    alloc.ext.cpu_cacheable = isCpuCacheable;
+
+    bo = mos_bo_alloc(bufmgr, &alloc);
 
     mediaBuffer->bMapped = false;
     if (bo)
@@ -1718,7 +1842,20 @@ VAStatus MediaLibvaUtilNext::AllocateBuffer(
     memPolicyPar.preferredMemType = mediaBuffer->bUseSysGfxMem ? MOS_MEMPOOL_SYSTEMMEMORY : 0;
 
     mem_type = MemoryPolicyManager::UpdateMemoryPolicy(&memPolicyPar);
-    MOS_LINUX_BO *bo  = mos_bo_alloc(bufmgr, "Media Buffer", size, 4096, mem_type);
+
+    unsigned int patIndex = MosInterface::GetPATIndexFromGmm(mediaBuffer->pMediaCtx->pGmmClientContext, mediaBuffer->pGmmResourceInfo);
+    bool isCpuCacheable   = mediaBuffer->pGmmResourceInfo->GetResFlags().Info.Cacheable;
+
+    struct mos_drm_bo_alloc alloc;
+    alloc.name = "Media Buffer";
+    alloc.size = size;
+    alloc.alignment = 4096;
+    alloc.ext.tiling_mode = TILING_NONE;
+    alloc.ext.mem_type = mem_type;
+    alloc.ext.pat_index = patIndex;
+    alloc.ext.cpu_cacheable = isCpuCacheable;
+
+    MOS_LINUX_BO *bo  = mos_bo_alloc(bufmgr, &alloc);
     mediaBuffer->bMapped = false;
     if (bo)
     {
@@ -1944,8 +2081,8 @@ VAStatus MediaLibvaUtilNext::GetSurfaceModifier(
         case GMM_TILED_4:
             if(mediaCtx->m_auxTableMgr && bMmcEnabled)
             {
-                modifier = gmmFlags.Info.MediaCompressed ? PRELIM_I915_FORMAT_MOD_4_TILED_MTL_MC_CCS :
-                    (gmmFlags.Info.RenderCompressed ? PRELIM_I915_FORMAT_MOD_4_TILED_MTL_RC_CCS : I915_FORMAT_MOD_4_TILED);
+                modifier = gmmFlags.Info.MediaCompressed ? I915_FORMAT_MOD_4_TILED_MTL_MC_CCS :
+                    (gmmFlags.Info.RenderCompressed ? I915_FORMAT_MOD_4_TILED_MTL_RC_CCS_CC : I915_FORMAT_MOD_4_TILED);
             }
             else
             {
@@ -1956,7 +2093,7 @@ VAStatus MediaLibvaUtilNext::GetSurfaceModifier(
             if (mediaCtx->m_auxTableMgr && bMmcEnabled)
             {
                 modifier = gmmFlags.Info.MediaCompressed ? I915_FORMAT_MOD_Y_TILED_GEN12_MC_CCS :
--                 (gmmFlags.Info.RenderCompressed ? I915_FORMAT_MOD_Y_TILED_GEN12_RC_CCS : I915_FORMAT_MOD_Y_TILED);
+                    (gmmFlags.Info.RenderCompressed ? I915_FORMAT_MOD_Y_TILED_GEN12_RC_CCS : I915_FORMAT_MOD_Y_TILED);
             }
             else
             {
@@ -1967,18 +2104,18 @@ VAStatus MediaLibvaUtilNext::GetSurfaceModifier(
             modifier = I915_FORMAT_MOD_X_TILED;
             break;
         case GMM_NOT_TILED:
-            modifier = DRM_FORMAT_MOD_NONE;
+            modifier = DRM_FORMAT_MOD_LINEAR;
             break;
         default:
             //handle other possible tile format
-            if(I915_TILING_Y == mediaSurface->TileType)
+            if(TILING_Y == mediaSurface->TileType)
             {
                 modifier = gmmFlags.Info.MediaCompressed ? I915_FORMAT_MOD_Y_TILED_GEN12_MC_CCS :
--                 (gmmFlags.Info.RenderCompressed ? I915_FORMAT_MOD_Y_TILED_GEN12_RC_CCS : I915_FORMAT_MOD_Y_TILED);
+                    (gmmFlags.Info.RenderCompressed ? I915_FORMAT_MOD_Y_TILED_GEN12_RC_CCS : I915_FORMAT_MOD_Y_TILED);
             }
             else
             {
-                modifier = DRM_FORMAT_MOD_NONE;
+                modifier = DRM_FORMAT_MOD_LINEAR;
             }
             break;
 
@@ -2111,13 +2248,13 @@ MOS_TILE_TYPE MediaLibvaUtilNext::GetTileTypeFromMediaTileType(uint32_t mediaTil
 
     switch(mediaTileType)
     {
-       case I915_TILING_Y:
+       case TILING_Y:
            tileType = MOS_TILE_Y;
            break;
-       case I915_TILING_X:
+       case TILING_X:
            tileType = MOS_TILE_X;
            break;
-       case I915_TILING_NONE:
+       case TILING_NONE:
            tileType = MOS_TILE_LINEAR;
            break;
         default:
@@ -2210,6 +2347,7 @@ void MediaLibvaUtilNext::MediaPrintFps()
         {
             pthread_mutex_unlock(&m_fpsMutex);
             DDI_ASSERTMESSAGE("Unable to open fps file.");
+            return;
         }
 
         fwrite(temp, 1, strlen(temp), fp);
