@@ -48,8 +48,6 @@
 
 namespace mhw { namespace mi { class Itf; } }
 
-std::map<uint32_t*, MOS_OCA_BUFFER_HANDLE> HalOcaInterfaceNext::s_hOcaMap;
-
 /****************************************************************************************************/
 /*                                      HalOcaInterfaceNextNext                                             */
 /****************************************************************************************************/
@@ -392,6 +390,41 @@ void HalOcaInterfaceNext::DumpVpKernelInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CO
     }
 }
 
+//!
+//! \brief  Add vp kernel info to oca log section.
+//! \param  [in] cmdBuffer
+//!         Command buffer for current BB.
+//! \param  [in] mosContext
+//!         Reference to MOS_CONTEXT.
+//! \param  [in] pControlValues
+//!         Value of user features.
+//! \return void
+//!         No return value. Handle all exception inside the function.
+//!
+void HalOcaInterfaceNext::DumpVpUserFeautreControlInfo(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT_HANDLE mosContext, PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO pControlValues)
+{
+    MosOcaInterface      *pOcaInterface = &MosOcaInterfaceSpecific::GetInstance();
+    MOS_STATUS            status        = MOS_STATUS_SUCCESS;
+    MOS_OCA_BUFFER_HANDLE hOcaBuf       = 0;
+
+    if (nullptr == pOcaInterface || (hOcaBuf = GetOcaBufferHandle(cmdBuffer, mosContext)) == MOS_OCA_INVALID_BUFFER_HANDLE)
+    {
+        // Will come here for UMD_OCA not being enabled case.
+        return;
+    }
+
+    MOS_OCA_LOG_HEADER header                           = {};
+    header.type                                         = MOS_OCA_LOG_TYPE_VP_USER_FEATURE_CONTROL_INFO;
+    header.headerSize                                   = sizeof(MOS_OCA_LOG_HEADER);
+    header.dataSize                                     = sizeof(MOS_OCA_LOG_USER_FEATURE_CONTROL_INFO);
+
+    status = pOcaInterface->DumpDataBlock(hOcaBuf, (PMOS_CONTEXT)mosContext, (PMOS_OCA_LOG_HEADER)&header, pControlValues);
+    if (MOS_FAILED(status))
+    {
+        OnOcaError(mosContext, status, __FUNCTION__, __LINE__);
+    }
+}
+
 //!
 //! \brief  Add vphal parameters to oca log section.
 //! \param  [in] mosContext
@@ -506,9 +539,15 @@ void HalOcaInterfaceNext::AddRTLogReource(MOS_COMMAND_BUFFER &cmdBuffer,
     {
         return;
     }
-    MosInterface::GetRtLogResourceInfo(osInterface.osStreamState, osResource, size);
+    osInterface.pfnGetRtLogResourceInfo(&osInterface, osResource, size);
     
     MOS_LINUX_BO *bo = cmdBuffer.OsResource.bo;
+    if (bo == nullptr ||
+        bo->virt == nullptr ||
+        bo->size <= OCA_LOG_SECTION_SIZE_MAX)
+    {
+        return;
+    }
     OCA_LOG_SECTION_HEADER *header = (OCA_LOG_SECTION_HEADER *)((uint64_t)bo->virt + bo->size - OCA_LOG_SECTION_SIZE_MAX);
     if (header->magicNum != OCA_LOG_SECTION_MAGIC_NUMBER)
     {
@@ -545,6 +584,10 @@ void HalOcaInterfaceNext::DumpCpParam(MosOcaInterface &ocaInterface, MOS_OCA_BUF
 {
 }
 
+void HalOcaInterfaceNext::DumpCpIoMsg(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT_HANDLE mosContext, void *pCpDumper, int type)
+{
+}
+
 void HalOcaInterfaceNext::OnOcaError(MOS_CONTEXT_HANDLE mosCtx, MOS_STATUS status, const char *functionName, uint32_t lineNumber)
 {
     MosOcaInterfaceSpecific::OnOcaError((PMOS_CONTEXT)mosCtx, status, functionName, lineNumber);
@@ -558,24 +601,8 @@ MOS_OCA_BUFFER_HANDLE HalOcaInterfaceNext::GetOcaBufferHandle(MOS_COMMAND_BUFFER
         OnOcaError(mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
         return MOS_OCA_INVALID_BUFFER_HANDLE;
     }
-    PMOS_MUTEX mutex = pOcaInterface->GetMutex();
-    if (mutex == nullptr)
-    {
-        return MOS_OCA_INVALID_BUFFER_HANDLE;
-    }
-    MosOcaAutoLock autoLock(mutex);
-    std::map<uint32_t*, MOS_OCA_BUFFER_HANDLE>::iterator it = s_hOcaMap.find(cmdBuffer.pCmdBase);
-    if (it == s_hOcaMap.end())
-    {
-        // May come here for workloads not enabling UMD_OCA.
-        return MOS_OCA_INVALID_BUFFER_HANDLE;
-    }
-    if (it->second >= MAX_NUM_OF_OCA_BUF_CONTEXT || it->second < 0)
-    {
-        OnOcaError(mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
-        return MOS_OCA_INVALID_BUFFER_HANDLE;
-    }
-    return it->second;
+
+    return pOcaInterface->GetOcaBufHandleFromMap(cmdBuffer.pCmdBase);
 }
 
 void HalOcaInterfaceNext::RemoveOcaBufferHandle(MOS_COMMAND_BUFFER &cmdBuffer, MOS_CONTEXT &mosContext)
@@ -586,19 +613,7 @@ void HalOcaInterfaceNext::RemoveOcaBufferHandle(MOS_COMMAND_BUFFER &cmdBuffer, M
         OnOcaError(&mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
         return;
     }
-    PMOS_MUTEX      mutex = pOcaInterface->GetMutex();
-    if (mutex == nullptr)
-    {
-        OnOcaError(&mosContext, MOS_STATUS_INVALID_PARAMETER, __FUNCTION__, __LINE__);
-        return;
-    }
-    MosOcaAutoLock autoLock(mutex);
-    std::map<uint32_t*, MOS_OCA_BUFFER_HANDLE>::iterator it = s_hOcaMap.find(cmdBuffer.pCmdBase);
-    if (it == s_hOcaMap.end())
-    {
-        return;
-    }
-    s_hOcaMap.erase(it);
+    pOcaInterface->RemoveOcaBufHandleFromMap(cmdBuffer.pCmdBase);
 }
 
 //!
@@ -625,12 +640,7 @@ void HalOcaInterfaceNext::On1stLevelBBStart(MOS_COMMAND_BUFFER &cmdBuffer, MOS_C
     {
         return;
     }
-    PMOS_MUTEX mutex = pOcaInterface->GetMutex();
-    if (mutex == nullptr)
-    {
-        OnOcaError(&mosContext, MOS_STATUS_NULL_POINTER, __FUNCTION__, __LINE__);
-        return;
-    }
+
     ocaBufHandle = GetOcaBufferHandle(cmdBuffer, (MOS_CONTEXT_HANDLE)&mosContext);
     if (ocaBufHandle != MOS_OCA_INVALID_BUFFER_HANDLE)
     {
@@ -640,18 +650,15 @@ void HalOcaInterfaceNext::On1stLevelBBStart(MOS_COMMAND_BUFFER &cmdBuffer, MOS_C
     }
     else
     {
-        MosOcaAutoLock autoLock(mutex);
         ocaBufHandle = pOcaInterface->LockOcaBufAvailable(&mosContext, gpuContextHandle);
+
         if (MOS_OCA_INVALID_BUFFER_HANDLE == ocaBufHandle)
         {
             OnOcaError(&mosContext, MOS_STATUS_INVALID_HANDLE, __FUNCTION__, __LINE__);
             return;
         }
-        auto success = s_hOcaMap.insert(std::make_pair(cmdBuffer.pCmdBase, ocaBufHandle));
-        if (!success.second)
+        if (MOS_FAILED(pOcaInterface->InsertOcaBufHandleMap(cmdBuffer.pCmdBase, ocaBufHandle)))
         {
-            // Should never come to here.
-            MOS_OS_ASSERTMESSAGE("ocaBufHandle has already been assigned to current cmdBuffer!");
             OnOcaError(&mosContext, MOS_STATUS_INVALID_HANDLE, __FUNCTION__, __LINE__);
             return;
         }
